package examples.ejb20.relationships.many2many;

import javax.ejb.CreateException;
import javax.ejb.EJBHome;
import javax.ejb.FinderException;
import java.rmi.RemoteException;
import java.util.Enumeration;

/**
 * This interface is the home interface for the EJBean CostumerBean. 
 * A home interface may support one or more create methods,
 * which must correspond to methods named "ejbCreate" in the EJBean.
 *
 * @author Copyright (c) 1998-2000 by BEA Systems, Inc. All Rights Reserved.
 */
public interface CustomerHome extends EJBHome {

  /**
   * This method corresponds to the ejbCreate method in the bean
   * "CustomerBean.java".
   * The parameter sets of the two methods are identical.  When the client calls
   * <code>AccountHome.create()</code>, the container (which in WebLogic EJB is
   * also the factory) allocates an instance of the bean and
   * calls <code>CustomerBean.ejbCreate()</code>
   */
  public Customer create(String name) 
    throws CreateException, RemoteException;

  /**
   * Given a Primary Key, refreshes the EJBean from
   * the persistent storage.
   * @param primaryKey        Primary Key
   * @return                  Customer
   * @exception               javax.ejb.FinderException
   *                          if there is an error finding the bean
   * @exception               java.rmi.RemoteException if there is
   *                          a communications or systems failure
   */
  public Customer findByPrimaryKey(String primaryKey) 
    throws FinderException, RemoteException;
       
}
