package examples.jdbc.informix4;

import java.sql.*;
import java.util.Properties;

/**
 * This simple example shows how to execute DDL and DML via JDBC.
 * 
 * <p><h3>Build the Example</h3>  
 * <ol>
 * <li> Open a new command shell. 
 * <p><li>Set up this development shell as described in 
 * <a href=../../examples.html#environment>Setting up Your Environment for 
 * Building and Running the Examples</a>.
 * <p>
 * <li> Change connection parameters to correspond to your Informix Server configuration.
 * If you need more help, check the section on connecting
 * to a database in the programming guide, <a
 * href="http://e-docs.bea.com/wls/docs60/informix4/API_jinf4.html">Using WebLogic jDriver for Informix</a>.
 * <p>
 * <li>Compile this example using the following command line:
 * <pre>  $ <b>javac -d %CLIENT_CLASSES% simplesql.java</b></pre>
 * 
 * </ol>
 * <p><h3>Run the Example</h3>
 * <ol>
 * <li>Execute the following command in your development shell: 
 * 
 * <pre><b>$ java examples.jdbc.informix4.simplesql</b></pre>
 * 
 * 
 * This example is run on the command line and is output to
 * System.out.</ol>
 * <p>
 * <h3>There's More</h3>
 *
 * For more information, see <a
 * href="http://e-docs.bea.com/wls/docs60/informix4/API_jinf4.html">Using WebLogic jDriver for Informix</a>. 
 * <p>
 * @author Copyright (c) 1996-2000 by BEA Systems, Inc.  All Rights Reserved.
 */

public class simplesql {
    
    public static void main(String argv[])
    {
      java.sql.Connection conn = null;
      java.sql.Statement stmt  = null;

      try {
       Properties props = new Properties();
        props.put("user",     "informix");
        props.put("password", "secret");
        props.put("server",   "myDBHost"); // hostname on which Informix server runs
        props.put("port",     "1493");       // port on which Informix server listens
        props.put("db",       "myDB");  // name of database on Informix server
      
      
        Driver myDriver = (Driver) Class.forName("weblogic.jdbc.informix4.Driver").newInstance();
        conn = myDriver.connect("jdbc:weblogic:informix4", props);
     
        stmt = conn.createStatement();
      
        try {
            stmt.execute("drop table empdemo");
            System.out.println("Table empdemo dropped.");
        }
        catch (SQLException e) {
          // Table empdemo doesn't need to be dropped.
        }
      
        stmt.execute("create table empdemo (empid integer, name varchar(30), dept float(4))");
        System.out.println("Table empdemo created.");
      
        int numrows = stmt.executeUpdate("insert into empdemo values (0, 'John Smith', 12)");
        System.out.println("Number of rows inserted = " + numrows);
      
        numrows = stmt.executeUpdate("delete from empdemo where empid = 0");
        System.out.println("Number of rows deleted = " + numrows);
      
        // If Database is not in AutoCommit mode, then be sure to commit work
        if (!conn.getAutoCommit()) {
            conn.commit();
        }
      } catch (Exception e) {
          System.out.println("Exception was thrown: " + e.getMessage());
      } finally {
          try {
            if (stmt != null)
              stmt.close();
            if (conn != null)
              conn.close();
          } catch (SQLException sqle) {
              System.out.println("SQLException was thrown: " + sqle.getMessage());
          }
      }
  }
}

