package examples.jdbc.mssqlserver4;

import java.sql.*;
import java.util.Properties;


/**
 * This simple example shows the alternatives for making a
 * JDBC connection to a MSSQLServer instance.
 * <p><h3>Building and running the example:</h3>
 * 
 * <ol>
 * <p>
 * <li> Open a new command shell. 
 * <p><li>Set up this development shell as described in 
 * <a href=../../examples.html#environment>Setting up Your Environment for 
 * Building and Running the Examples</a>.
 * <p>
 * <li>Change your CLASSPATH if neccessary, depending on which version of WebLogic jDriver for Microsoft SQL Server
 * you are using. If you are using Version 7.0 you do not need to make changes. If you are using
 * Version 6.5, pre-pend your classpath as follows by adding the jar file: 
 * <pre>  $ <b>set CLASSPATH=%WL_HOME%/lib/mssqlserver4v65.jar;%CLASSPATH%</b></pre>
 * <p>
 * <li> Change the database URL, login, and password connection parameters defined in the example source code
 * to correspond to your Microsoft SQL Server configuration. (Change the hostname and port number used to
 * connect to your SQL Server installation.) If you need more help, check the section on connecting
 *  to a database in the Developers Guide, <a
 * href="http://e-docs.bea.com/wls/docs60/informix4/API_jmsq4.html">Using WebLogic jDriver for Microsoft SQL Server</a>.
 *
 * <p>
 *
 * <li>Compile this example by executing the following command in your development shell:
 *
 * <p>
 *
 * <pre><font face="Courier New"><b>$ javac -d %CLIENT_CLASSES% login.java</b></font></pre>
 * <p>	
 *
 * <li>Run this example by executing the following command in your development shell:
 *
 * <p>
 *
 * <pre><font face="Courier New"><b>$ java examples.jdbc.mssqlserver4.login</b></font></pre>
 *
 * </ol><p>
 * <h3>There's More</h3>
 *
 * For more information about the WebLogic jDriver for Microsoft SQL Server, see   <a
 * href="http://e-docs.bea.com/wls/docs60/mssqlserver4/API_jmsq4.html">Using WebLogic jDriver for Microsoft SQL Server</a>. 
 * <p>
 *
 * @author       Copyright (c) 1997-2000 by BEA Systems, Inc. All Rights Reserved.
 */
public class login {
  
  public static void main(String argv[])
  {
    
    // You can connect to a database with JDBC in various ways.
    // Command line arguments and explicit Properties are both optional.
    
    //
    // Method 1 uses a connection URL that includes the host name
    // and port number of the database server. The user name and
    // password are specified in separate arguments. 
    // Change "myhost:1433" to the host name and port number of your SQL Server.
    //
    java.sql.Connection conn = null;
    try {
      Class.forName("weblogic.jdbc.mssqlserver4.Driver").newInstance();
      conn =
      DriverManager.getConnection("jdbc:weblogic:mssqlserver4:myHost:1433",
                                   "sa",
                                   "secret");
      } catch (Exception e) {
          System.out.println("Exception was thrown: " + e.getMessage());
      } finally { //all connections should be closed in a finally block
          try {
            if (conn != null)
              conn.close();
          } catch (SQLException sqle) {
              System.out.println("SQLException was thrown: " + sqle.getMessage());
          }
      }
    System.out.println("Logged in successfully using Method 1.");

    // 
    // Method 2 uses a Properties object to pass the connection information 
    // and the connection is made with the Driver.connect() method.
    // The optional "appname" and "hostname" properties are passed to MS SQL server
    // and can be read in the sysprocesses table under the column names 
    // "program_name" and "hostname". The hostname value will be prepended with "WebLogic" 
    // Change "myhost:1433" to the host name and port number of your SQL Server.
    //
    Properties props = new Properties();
    props.put("user",     "sa");
    props.put("password", "secret");
    props.put("db", "pubs");
    props.put("server",   "myHost:1433");
    props.put("appname",    "MyApplication");
    props.put("hostname",   "myhostName");

    try { 
      Driver myDriver = (Driver) Class.forName("weblogic.jdbc.mssqlserver4.Driver").newInstance();
      conn = myDriver.connect("jdbc:weblogic:mssqlserver4", props);
    } catch (Exception e) {
        System.out.println("Exception was thrown: " + e.getMessage());
    } finally {
        try { 
          if (conn != null)
            conn.close();
        } catch (SQLException sqle) {
            System.out.println("SQLException was thrown: " + sqle.getMessage());
        }
    }
    System.out.println("Logged in successfully using Method 2.");
    
    // 
    // Method 3 uses a connection URL with all of the connection information.
    //
    // Change "myhost:1433" to the host name and port number of your SQL Server.
    //
    try {
      conn = DriverManager.getConnection(
        "jdbc:weblogic:mssqlserver4:myHost:1433?db=pubs;user=sa;password=secret");
    } catch (Exception e) {
        System.out.println("Exception was thrown: " + e.getMessage());
    } finally {
        try {
          if ( conn != null)
            conn.close();
        } catch (SQLException sqle) {
            System.out.println("SQLException was thrown: " + sqle.getMessage());
        }
    }
    
    System.out.println("Logged in successfully using Method 3.");
  }
}



