package examples.jdbc.mssqlserver4;

import java.sql.*;
import java.util.Properties;

/**
 * This simple example shows how to create and execute stored
 * procedures, and get the results.
 * <p>
 * This example is run on the command line and is output to
 * System.out.
 * <p>
 * Please note that this example uses a simple method for obtaining
 * result sets, update counts, and/or the output parameter values it may
 * generate. This is always possible with simple, known queries.
 * When executing complex or unknown possibly multi-statement SQL
 * or stored procedures, you should use the example in <tt><a href="complexproc.java">complexproc.java</a></tt>
 * to ensure that all results become available.
 * <p>
 * <h3>Build the Example</h3>  
 * <ol>
 * <li> Open a new command shell. 
 * <p><li>Set up this development shell as described in 
 * <a href=../../examples.html#environment>Setting up Your Environment for 
 * Building and Running the Examples</a>.
 * <p>
 * <li>Change your CLASSPATH if neccessary, depending on which version of WebLogic jDriver for Microsoft SQL Server
 * you are using. If you are using Version 7.0 you do not need to make changes. If you are using
 * Version 6.5, pre-pend your classpath as follows by adding the jar file: 
 * <pre>  $ <b>set CLASSPATH=%WL_HOME%/lib/mssqlserver4v65.jar;%CLASSPATH%</b></pre>
 * 
 * <p>
 * <li> Change the database URL, login, and password connection parameters in the example source code 
 * to correspond to your Microsoft SQL Server configuration.
 * If you need more help, check the section on connecting
 * to a database in the programming guide, <a
 * href="http://e-docs.bea.com/wls/docs60/mssqlserver4/API_jmsq4.html">Using WebLogic jDriver for Microsoft SQL Server</a>.
 * <p>
 * <li>Compile this example using the following command line:
 * <pre>  $ <b>javac -d %CLIENT_CLASSES% storedprocs.java</b></pre>
 * 
 * </ol>
 * <p><h3>Run the Example</h3>
 * <ol>
 * <li>Execute the following command in your development shell: 
 * 
 * <pre><b>$ java examples.jdbc.mssqlserver4.storedprocs</b></pre>
 * 
 * </ol>
 * <h3>There's More</h3>
 *
 * For more information about the WebLogic jDriver for Microsoft SQL Server, see   <a
 * href="http://e-docs.bea.com/wls/docs60/mssqlserver4/API_jmsq4.html">Using WebLogic jDriver for Microsoft SQL Server</a>. 
 * <p>
 *
 * @author         Copyright (c) 1997-2000 by BEA Systems, Inc. All Rights Reserved.
 */
public class storedprocs {
  
  public static void main(String argv[])
  {
    java.sql.Connection conn         = null;
    java.sql.Statement stmt          = null;
    java.sql.CallableStatement cstmt = null;
    java.sql.ResultSet rs            = null;
    Properties props = new Properties();
    props.put("user", "sa");
    props.put("password", "secret");
    props.put("server", "myHOST:1433");

    try {
      Driver myDriver = (Driver)
          Class.forName("weblogic.jdbc.mssqlserver4.Driver").newInstance();
      conn = myDriver.connect("jdbc:weblogic:mssqlserver4", props);
    
      stmt = conn.createStatement();
      try {stmt.execute("drop procedure proc_squareInt");} catch (SQLException e) {;}
      try {stmt.execute("drop procedure func_squareInt");} catch (SQLException e) {;}
      try {stmt.execute("drop procedure proc_getResults");} catch (SQLException e) {;}
      stmt.close();
    
      // Create a stored procedure
      stmt = conn.createStatement();
      stmt.execute("create procedure proc_squareInt (@field1 int, @field2 int output) as " + 
                  "begin select @field2 = @field1 * @field1 end");
      stmt.close();
    
      cstmt = conn.prepareCall("{call proc_squareInt(?, ?)}");
    
      cstmt.registerOutParameter(2, java.sql.Types.INTEGER);
      for (int i = 0; i < 100; i++) {
        cstmt.setInt(1, i);
        cstmt.execute();
        System.out.println(i + " " + cstmt.getInt(2));
      }
      cstmt.close();
    
      // Create a procedure with a return value
      stmt = conn.createStatement();
      stmt.execute("create procedure func_squareInt (@field1 int) as " +
                  "begin return @field1 * @field1 end");
      stmt.close();
    
      cstmt = conn.prepareCall("{? = call func_squareInt(?)}");
    
      cstmt.registerOutParameter(1, java.sql.Types.INTEGER);
      for (int i = 0; i < 100; i++) {
        cstmt.setInt(2, i);
        cstmt.execute();
        System.out.println(i + " " + cstmt.getInt(1));
      }
      cstmt.close();
    
    // Create a procedure with results
      stmt = conn.createStatement();
      stmt.execute("create procedure proc_getResults as " +
                  "begin select name from sysusers \n" +
                  "select gid from sysusers end");
      stmt.close();
    
      cstmt = conn.prepareCall("{call proc_getResults()}");
    
      boolean hasResultSet = cstmt.execute();
      while (hasResultSet) {
        rs = cstmt.getResultSet();
        while (rs.next())
          System.out.println("Value: " + rs.getString(1));
        rs.close();
        hasResultSet = cstmt.getMoreResults();
      }
    } catch (Exception e) {
        System.out.println("Exception was thrown: " + e.getMessage());
    } finally {
        try {
          if (cstmt != null)
            cstmt.close();
          if (stmt != null)
            stmt.close();
          if (conn != null)
            conn.close();
         } catch (SQLException sqle) {
             System.out.println("SQLException was thrown: " + sqle.getMessage());
         }
     }
  }
}
