/**
 * SampleConfig.java
 *
 * Jaas sample configuration
 *
 * @author Copyright (c) 2000 by BEA. All Rights Reserved.
 */

package examples.security.jaas;

import java.util.Hashtable;
import javax.security.auth.login.Configuration;
import javax.security.auth.login.AppConfigurationEntry;
import java.io.File;
import java.io.FileReader;
import java.io.IOException;
import java.io.InputStream;
import java.io.BufferedReader;
import java.io.FileInputStream;
import java.io.FileNotFoundException;

/**
 * Sample configuration class for JAAS user authentication.
 */

public class SampleConfig extends Configuration
{
  String configFileName = null;

  /**
   *
   * Create a new Configuration object.
   */
  public SampleConfig()
  {
    // No Implementation
  }

  /**
   * Retrieve an entry from the Configuration object using an application name as an index.
   */
  public AppConfigurationEntry[] getAppConfigurationEntry(String applicationName)
  {

    AppConfigurationEntry[] list = new AppConfigurationEntry[1];
    AppConfigurationEntry entry = null;

    // Get the spcified configuration file
    configFileName = System.getProperty("weblogic.security.jaas.Policy");
    System.out.println("Using Configuration File: " + configFileName);

    try
    {
      FileReader fr = new FileReader(configFileName);
      BufferedReader reader = new BufferedReader(fr);
      String line;

      line = reader.readLine();
      while(line != null)
      {
        // Skip lines until the line starting with a '{'
        if(line.length() == 0 || line.charAt(0) != '{')
        {
          line = reader.readLine();
          continue;
        }
        // Read following line which contains the LoginModule configured
        line = reader.readLine();

        int i;
        for(i = 0; i < line.length(); i++)
        {
          char c = line.charAt(i);
          if(c != ' ')
            break;
        }
        int sep = line.indexOf(' ', i);

        String LMName = line.substring(0, sep).trim();
        String LMFlag = line.substring(sep + 1, line.indexOf(' ', sep + 1));

        System.out.println("Login Module Name: " + LMName);
        System.out.println("Login Module Flag: " + LMFlag);

        if(LMFlag.equalsIgnoreCase("OPTIONAL"))
        {
          entry = new AppConfigurationEntry(LMName,
                                            AppConfigurationEntry.LoginModuleControlFlag.OPTIONAL,
                                            new Hashtable());
          list[0] = entry;

        }
        else if(LMFlag.equalsIgnoreCase("REQUIRED"))
        {
          entry = new AppConfigurationEntry(LMName,
                                            AppConfigurationEntry.LoginModuleControlFlag.REQUIRED,
                                            new Hashtable());
          list[0] = entry;

        }
        else if(LMFlag.equalsIgnoreCase("REQUISITE"))
        {
          entry = new AppConfigurationEntry(LMName,
                                            AppConfigurationEntry.LoginModuleControlFlag.REQUISITE,
                                            new Hashtable());
          list[0] = entry;
        }
        else if(LMFlag.equalsIgnoreCase("SUFFICIENT"))
        {
          entry = new AppConfigurationEntry(LMName,
                                            AppConfigurationEntry.LoginModuleControlFlag.SUFFICIENT,
                                            new Hashtable());
          list[0] = entry;
        }
        else
        {
          throw new IllegalArgumentException("Invalid controlFlag");
        }
        line = reader.readLine();
      }
      reader.close();
    }
    catch(java.io.FileNotFoundException ioe)
    {
      System.out.println(ioe.toString());
    }
    catch(java.io.IOException ioe)
    {
      System.out.println(ioe.toString());
    }
    return list;
  }


  /**
   * Refresh and reload the Configuration object by reading all of the login configurations again.
   */
  public void refresh()
  {
    // No Implementation
  }
}
