package examples.servlets;

import javax.servlet.*;
import javax.servlet.http.*;
import java.io.*;

/**
 * The HelloWorldServlet demonstrates creating HTML output in a servlet class.
 *
 * <h3>Build the Example</h3>  
 * <ol>
 * <li> Open a new command shell. 
 * <p><li>Set up this development shell as described in 
 * <a href=../examples.html#environment>Setting up Your Environment for 
 * Building and Running the Examples</a>.
 * <p>
 * <li>Compile the servlet using the following command line:
 * <pre>  $ <b>javac -d %EX_WEBAPP_CLASSES% HelloWorldServlet.java</b></pre>
 * 
 * 
 * <p> <li>Start WebLogic Server with the <a
 * href=../examples.html>examples configuration</a>.  <p> 
 *
 * </ol>
 * <p><h3>Configure the Server</h3>
 * <dl>
 * <dd>Make sure that the <font face="Courier New" size=-1>examplesWebApp</font> is <a href=../examples.html#webApp>deployed on your server</a>.
 * </dl>
 * <p><h3>Run the Example</h3>
 * <dl>
 * <dd>Use a web browser to load the following URL: 
 * 
 * <pre><b>http://localhost:7001/examplesWebApp/HelloWorldServlet</b></pre>
 *
 * </dl>
 * <h3>There's More...</h3>
 *
 * For more information on servlets see  <a
 * href="http://e-docs.bea.com/wls/docs60/servlet/index.html">Programming WebLogic HTTP Servlets</a>. 
 * <p>
 * @author Copyright (c) 1996-98 by WebLogic, Inc. All Rights Reserved.
 * @author Copyright (c) 1999-2000 by BEA Systems, Inc. All Rights Reserved.  </font> 
*/

public class HelloWorldServlet extends HttpServlet {

  /**
   * A very simple implementation of the service method, 
   * which outputs the contents of a static HTML page
   */
  public void service(HttpServletRequest req, HttpServletResponse res)
       throws IOException
  {
    // Must set the content type first
    res.setContentType("text/html");
    // Now we can obtain a PrintWriter
    PrintWriter out = res.getWriter();
    
    out.println("<html><head><title>Hello World!</title></head>");
    out.println("<body>");
    out.println("<p><img src=images/BEA_Button_Final_web.gif align=right>");
    out.println("<h1>Hello World!</h1></body></html>");
    // Do not close the output stream - allow the servlet engine to close it
    // to enable better performance.
  }
}
