package examples.xml.http;

import java.util.*;
import java.io.*;
import java.net.*;
import java.util.*;
import javax.servlet.*;
import javax.servlet.http.*;
import javax.ejb.*;
import javax.naming.*;
import examples.ejb.basic.statefulSession.*;
import org.xml.sax.SAXException;
import weblogic.servlet.XMLProcessingException;

/**
 * This example shows how to pass XML data between a Java client 
 * and a servlet over HTTP. This class receives stock trade instructions 
 * from <tt>StockClient</tt> in the form of XML data. This class 
 * obtains an instance of <tt>TraderBean</tt> and perfoms the stock trades. 
 * The results of the trade are then pass back to <tt>StockClient</tt> in 
 * the form of XML data. 
 *
 * @author Copyright (c) 2000 by BEA Systems, Inc. All Rights Reserved.  
 */
public class StockServlet extends HttpServlet {

    /**
     * Handles HTTP POST requests.
     *
     * @param request         HttpServletRequest
     * @param response        HttpServletResponse
     * @exception             javax.servlet.ServletException if there is a servlet problem
     * @exception             java.io.IOException if there is an I/O problem
     */
  public final void doPost(HttpServletRequest request, HttpServletResponse response)
    throws ServletException, IOException  {

    RequestHandler rh = new RequestHandler();

    try {
      request.setAttribute("org.xml.sax.HandlerBase", rh);
    } catch(XMLProcessingException xpe) {
      System.out.println("Error in processing XML");
      xpe.printStackTrace();
      return;
    } 
 
   java.util.Hashtable trade = rh.getData();

    if (! trade.isEmpty()) {
      try {
        // Create a trader object.
        Context ctx          =  new InitialContext();
        TraderHome brokerage = (TraderHome) ctx.lookup("statefulSession.TraderHome");

        // Give this trader a name.
        Trader trader = brokerage.create();

        response.setContentType("text/xml");

        // Get writer.
        PrintWriter responseWriter = response.getWriter();
        responseWriter.println("<?xml version='1.0'?>");

        // Do trade.
        if (((String) trade.get("action")).equals("buy")) {
          TradeResult tr = trader.buy("Erin", (String) trade.get("symbol"), 
                             Integer.parseInt((String) trade.get("numShares")));

          // send result via xml
          responseWriter.println("<traderesult action='bought' symbol='"+
                                (String) trade.get("symbol")+"' numShares='"+ tr.getNumberTraded() +
                                "' price ='"+ tr.getPrice() +"' changeInAccount ='" + trader.getBalance() +"' />");
        } else if (((String) trade.get("action")).equals("sell")) {
          TradeResult tr = trader.sell("Erin", (String) trade.get("symbol"), 
                             Integer.parseInt((String) trade.get("numShares")));
          // send result via xml
          responseWriter.println("<traderesult action='sold' symbol='"+
                                (String) trade.get("symbol")+"' numShares='"+ tr.getNumberTraded() +
            "' price ='"+ tr.getPrice() +"' changeInAccount ='" + trader.getBalance() +"' />");
         }
        trader.remove();
      } catch (Exception e) {
        System.out.println(":::::::::::::: Error :::::::::::::::::");
        e.printStackTrace();
      }
    }
  }


}
