package weblogic.servlet.jsp.stdtag;

import weblogic.servlet.jsp.stdtag.Taglib;
import java.io.*;
import java.net.*;
import java.util.Hashtable;
import java.util.Locale;
import java.util.Map;
import org.w3c.dom.*;
import org.xml.sax.*;
import org.xml.sax.helpers.ParserFactory;
import weblogic.xml.dtdc.Handler;
import weblogic.xml.dtdc.NullHandler;

public class TaglibParser extends weblogic.xml.dtdc.BaseParser {

  // ============================================================
  // Parse

  public static void main(String[] args) throws Exception {
    try {
      Parser parser = ParserFactory.makeParser("weblogic.servlet.jsp.stdtag.TaglibParser");
      Handler handler = new Handler("weblogic.servlet.jsp.stdtag", true);
      handler.setClassLoader(Class.forName("weblogic.servlet.jsp.stdtag.TaglibParser").getClassLoader());
      parser.setDocumentHandler(handler);
      parser.parse(args[0]);
    } catch(SAXParseException saxpe) {
      System.out.println("Line: " + saxpe.getLineNumber() + " Column: " + saxpe.getColumnNumber());
      throw saxpe;
    }
  }

  // ============================================================
  // Generated Code

  public void parse(char[] chars) throws SAXException {
    boolean done = false;
    int startLine = currentLine;
    if(dh == null) dh = new NullHandler();
    dh.setDocumentLocator(this);
    dh.startDocument();
    while(current != chars.length && !done) {
      switch(chars[current++]) {
      case '\t':
        // Ignore whitespace
        continue;
      case '\n':
        nextLine();
        continue;
      case '\r':
        // Ignore whitespace
        continue;
      case ' ':
        // Ignore whitespace
        continue;
      case '<':
        switch(chars[current++]) {
        case '!':
          switch(chars[current++]) {
          case '-':
            match(chars, "-", "taglib", startLine);
            eatComment(chars);
            continue;
          case 'D':
            match(chars, "OCTYPE", "taglib", startLine);
            // Ignore DTD specification
            while(chars[current++] != '>');
            continue;
          default:
            throw new SAXParseException("Could not parse: taglib starting at line " + startLine, this);
          }
        case '?':
          match(chars, "xml", "taglib", startLine);
          // Ignore XML version
          while(chars[current++] != '>');
          continue;
        case 't':
          match(chars, "aglib", "taglib", startLine);
          sendCharacters(chars, 7);
          readTaglib(chars);
          continue;
        default:
          throw new SAXParseException("Could not parse: taglib starting at line " + startLine, this);
        }
      default:
        if(startCharacterData == -1) startCharacterData = current - 1;
      }

    }
    if(done) throw new SAXParseException("Could not parse (bad close tag): starting at line " + startLine, this);
    dh.endDocument();
  }

public void readName(char[] chars) throws SAXException {
  int startLine = currentLine;
  try {
    reset();
    boolean emptyTag = readNameAttributes(chars);
    dh.startElement("name", this);
    boolean done = false;
    while(!done && !emptyTag) {
    switch(chars[current++]) {
    case '\t':
      // Ignore whitespace
      continue;
    case '\n':
      nextLine();
      continue;
    case '\r':
      // Ignore whitespace
      continue;
    case ' ':
      // Ignore whitespace
      continue;
    case '&':
      handleEscapes(chars);
      continue;
    case '<':
      switch(chars[current++]) {
      case '!':
        switch(chars[current++]) {
        case '-':
          match(chars, "-", "name", startLine);
          eatComment(chars);
          continue;
        case '[':
          match(chars, "CDATA[", "name", startLine);
          handleCDATA(chars);
          continue;
        default:
          throw new SAXParseException("Could not parse: name starting at line " + startLine, this);
        }
      case '/':
        try {
          match(chars, "name>", "name", startLine);
          sendCharacters(chars, 7);
          done = true;
        } catch(Exception e) { current -= 2; sendCharacters(chars, 0); done = true; continue; }
        continue;
      default:
        current -= 2; sendCharacters(chars, 0); done = true; continue;
      }
    default:
      if(startCharacterData == -1) startCharacterData = current - 1;
    }

    }
    dh.endElement("name");
  } catch(ArrayIndexOutOfBoundsException aioobe) {
    throw new SAXParseException("name not closed, starts at line " + startLine, this);
  }
}

public boolean readNameAttributes(char[] chars) throws SAXException {
  int startLine = currentLine;
  boolean done = false;
  boolean emptyTag = false;

  while(!done) {
    switch(chars[current++]) {
    case '\t':
      // Ignore whitespace
      continue;
    case '\n':
      // Next line
      currentLine++;
      lastLinePosition=current;
      continue;
    case '\r':
      // Ignore whitespace
      continue;
    case ' ':
      // Ignore whitespace
      continue;
    case '/':
      try {
        match(chars, ">", "name", startLine);
        // Done
        emptyTag=true;done=true;
      } catch(Exception e) { current -= 2; sendCharacters(chars, 0); done = true; continue; }
      continue;
    case '>':
      // Done
      done = true;
      continue;
    case 'i':
      match(chars, "d", "name", startLine);
      {String value = _readAttribute(chars);
      // not required
      if(ids.put(value, this) != null) throw new SAXParseException("Duplicate ID found: " + value, this);
      if(true&& false) throw new SAXParseException("Not a valid attribute value: [" + value + "]", this);
      putAttribute("id", "ID", value);}
      continue;
    default:
      throw new SAXParseException("Could not parse: name starting at line " + startLine, this);
    }

  }

  return emptyTag;
}

public void readBodycontent(char[] chars) throws SAXException {
  int startLine = currentLine;
  try {
    reset();
    boolean emptyTag = readBodycontentAttributes(chars);
    dh.startElement("bodycontent", this);
    boolean done = false;
    while(!done && !emptyTag) {
    switch(chars[current++]) {
    case '\t':
      // Ignore whitespace
      continue;
    case '\n':
      nextLine();
      continue;
    case '\r':
      // Ignore whitespace
      continue;
    case ' ':
      // Ignore whitespace
      continue;
    case '&':
      handleEscapes(chars);
      continue;
    case '<':
      switch(chars[current++]) {
      case '!':
        switch(chars[current++]) {
        case '-':
          match(chars, "-", "bodycontent", startLine);
          eatComment(chars);
          continue;
        case '[':
          match(chars, "CDATA[", "bodycontent", startLine);
          handleCDATA(chars);
          continue;
        default:
          throw new SAXParseException("Could not parse: bodycontent starting at line " + startLine, this);
        }
      case '/':
        try {
          match(chars, "bodycontent>", "bodycontent", startLine);
          sendCharacters(chars, 14);
          done = true;
        } catch(Exception e) { current -= 2; sendCharacters(chars, 0); done = true; continue; }
        continue;
      default:
        current -= 2; sendCharacters(chars, 0); done = true; continue;
      }
    default:
      if(startCharacterData == -1) startCharacterData = current - 1;
    }

    }
    dh.endElement("bodycontent");
  } catch(ArrayIndexOutOfBoundsException aioobe) {
    throw new SAXParseException("bodycontent not closed, starts at line " + startLine, this);
  }
}

public boolean readBodycontentAttributes(char[] chars) throws SAXException {
  int startLine = currentLine;
  boolean done = false;
  boolean emptyTag = false;

  while(!done) {
    switch(chars[current++]) {
    case '\t':
      // Ignore whitespace
      continue;
    case '\n':
      // Next line
      currentLine++;
      lastLinePosition=current;
      continue;
    case '\r':
      // Ignore whitespace
      continue;
    case ' ':
      // Ignore whitespace
      continue;
    case '/':
      try {
        match(chars, ">", "bodycontent", startLine);
        // Done
        emptyTag=true;done=true;
      } catch(Exception e) { current -= 2; sendCharacters(chars, 0); done = true; continue; }
      continue;
    case '>':
      // Done
      done = true;
      continue;
    case 'i':
      match(chars, "d", "bodycontent", startLine);
      {String value = _readAttribute(chars);
      // not required
      if(ids.put(value, this) != null) throw new SAXParseException("Duplicate ID found: " + value, this);
      if(true&& false) throw new SAXParseException("Not a valid attribute value: [" + value + "]", this);
      putAttribute("id", "ID", value);}
      continue;
    default:
      throw new SAXParseException("Could not parse: bodycontent starting at line " + startLine, this);
    }

  }

  return emptyTag;
}

public void readAttribute(char[] chars) throws SAXException {
  int startLine = currentLine;
  try {
    reset();
    boolean emptyTag = readAttributeAttributes(chars);
    dh.startElement("attribute", this);
    boolean done = false;
    while(!done && !emptyTag) {
    switch(chars[current++]) {
    case '\t':
      // Ignore whitespace
      continue;
    case '\n':
      nextLine();
      continue;
    case '\r':
      // Ignore whitespace
      continue;
    case ' ':
      // Ignore whitespace
      continue;
    case '&':
      handleEscapes(chars);
      continue;
    case '<':
      switch(chars[current++]) {
      case '!':
        switch(chars[current++]) {
        case '-':
          match(chars, "-", "attribute", startLine);
          eatComment(chars);
          continue;
        case '[':
          match(chars, "CDATA[", "attribute", startLine);
          handleCDATA(chars);
          continue;
        default:
          throw new SAXParseException("Could not parse: attribute starting at line " + startLine, this);
        }
      case '/':
        try {
          match(chars, "attribute>", "attribute", startLine);
          sendCharacters(chars, 12);
          done = true;
        } catch(Exception e) { current -= 2; sendCharacters(chars, 0); done = true; continue; }
        continue;
      case 'n':
        match(chars, "ame", "attribute", startLine);
        sendCharacters(chars, 5);
        readName(chars);
        continue;
      case 'r':
        switch(chars[current++]) {
        case 'e':
          match(chars, "quired", "attribute", startLine);
          sendCharacters(chars, 9);
          readRequired(chars);
          continue;
        case 't':
          match(chars, "exprvalue", "attribute", startLine);
          sendCharacters(chars, 12);
          readRtexprvalue(chars);
          continue;
        default:
          throw new SAXParseException("Could not parse: attribute starting at line " + startLine, this);
        }
      default:
        current -= 2; sendCharacters(chars, 0); done = true; continue;
      }
    default:
      if(startCharacterData == -1) startCharacterData = current - 1;
    }

    }
    dh.endElement("attribute");
  } catch(ArrayIndexOutOfBoundsException aioobe) {
    throw new SAXParseException("attribute not closed, starts at line " + startLine, this);
  }
}

public boolean readAttributeAttributes(char[] chars) throws SAXException {
  int startLine = currentLine;
  boolean done = false;
  boolean emptyTag = false;

  while(!done) {
    switch(chars[current++]) {
    case '\t':
      // Ignore whitespace
      continue;
    case '\n':
      // Next line
      currentLine++;
      lastLinePosition=current;
      continue;
    case '\r':
      // Ignore whitespace
      continue;
    case ' ':
      // Ignore whitespace
      continue;
    case '/':
      try {
        match(chars, ">", "attribute", startLine);
        // Done
        emptyTag=true;done=true;
      } catch(Exception e) { current -= 2; sendCharacters(chars, 0); done = true; continue; }
      continue;
    case '>':
      // Done
      done = true;
      continue;
    case 'i':
      match(chars, "d", "attribute", startLine);
      {String value = _readAttribute(chars);
      // not required
      if(ids.put(value, this) != null) throw new SAXParseException("Duplicate ID found: " + value, this);
      if(true&& false) throw new SAXParseException("Not a valid attribute value: [" + value + "]", this);
      putAttribute("id", "ID", value);}
      continue;
    default:
      throw new SAXParseException("Could not parse: attribute starting at line " + startLine, this);
    }

  }

  return emptyTag;
}

public void readInfo(char[] chars) throws SAXException {
  int startLine = currentLine;
  try {
    reset();
    boolean emptyTag = readInfoAttributes(chars);
    dh.startElement("info", this);
    boolean done = false;
    while(!done && !emptyTag) {
    switch(chars[current++]) {
    case '\t':
      // Ignore whitespace
      continue;
    case '\n':
      nextLine();
      continue;
    case '\r':
      // Ignore whitespace
      continue;
    case ' ':
      // Ignore whitespace
      continue;
    case '&':
      handleEscapes(chars);
      continue;
    case '<':
      switch(chars[current++]) {
      case '!':
        switch(chars[current++]) {
        case '-':
          match(chars, "-", "info", startLine);
          eatComment(chars);
          continue;
        case '[':
          match(chars, "CDATA[", "info", startLine);
          handleCDATA(chars);
          continue;
        default:
          throw new SAXParseException("Could not parse: info starting at line " + startLine, this);
        }
      case '/':
        try {
          match(chars, "info>", "info", startLine);
          sendCharacters(chars, 7);
          done = true;
        } catch(Exception e) { current -= 2; sendCharacters(chars, 0); done = true; continue; }
        continue;
      default:
        current -= 2; sendCharacters(chars, 0); done = true; continue;
      }
    default:
      if(startCharacterData == -1) startCharacterData = current - 1;
    }

    }
    dh.endElement("info");
  } catch(ArrayIndexOutOfBoundsException aioobe) {
    throw new SAXParseException("info not closed, starts at line " + startLine, this);
  }
}

public boolean readInfoAttributes(char[] chars) throws SAXException {
  int startLine = currentLine;
  boolean done = false;
  boolean emptyTag = false;

  while(!done) {
    switch(chars[current++]) {
    case '\t':
      // Ignore whitespace
      continue;
    case '\n':
      // Next line
      currentLine++;
      lastLinePosition=current;
      continue;
    case '\r':
      // Ignore whitespace
      continue;
    case ' ':
      // Ignore whitespace
      continue;
    case '/':
      try {
        match(chars, ">", "info", startLine);
        // Done
        emptyTag=true;done=true;
      } catch(Exception e) { current -= 2; sendCharacters(chars, 0); done = true; continue; }
      continue;
    case '>':
      // Done
      done = true;
      continue;
    case 'i':
      match(chars, "d", "info", startLine);
      {String value = _readAttribute(chars);
      // not required
      if(ids.put(value, this) != null) throw new SAXParseException("Duplicate ID found: " + value, this);
      if(true&& false) throw new SAXParseException("Not a valid attribute value: [" + value + "]", this);
      putAttribute("id", "ID", value);}
      continue;
    default:
      throw new SAXParseException("Could not parse: info starting at line " + startLine, this);
    }

  }

  return emptyTag;
}

public void readUri(char[] chars) throws SAXException {
  int startLine = currentLine;
  try {
    reset();
    boolean emptyTag = readUriAttributes(chars);
    dh.startElement("uri", this);
    boolean done = false;
    while(!done && !emptyTag) {
    switch(chars[current++]) {
    case '\t':
      // Ignore whitespace
      continue;
    case '\n':
      nextLine();
      continue;
    case '\r':
      // Ignore whitespace
      continue;
    case ' ':
      // Ignore whitespace
      continue;
    case '&':
      handleEscapes(chars);
      continue;
    case '<':
      switch(chars[current++]) {
      case '!':
        switch(chars[current++]) {
        case '-':
          match(chars, "-", "uri", startLine);
          eatComment(chars);
          continue;
        case '[':
          match(chars, "CDATA[", "uri", startLine);
          handleCDATA(chars);
          continue;
        default:
          throw new SAXParseException("Could not parse: uri starting at line " + startLine, this);
        }
      case '/':
        try {
          match(chars, "uri>", "uri", startLine);
          sendCharacters(chars, 6);
          done = true;
        } catch(Exception e) { current -= 2; sendCharacters(chars, 0); done = true; continue; }
        continue;
      default:
        current -= 2; sendCharacters(chars, 0); done = true; continue;
      }
    default:
      if(startCharacterData == -1) startCharacterData = current - 1;
    }

    }
    dh.endElement("uri");
  } catch(ArrayIndexOutOfBoundsException aioobe) {
    throw new SAXParseException("uri not closed, starts at line " + startLine, this);
  }
}

public boolean readUriAttributes(char[] chars) throws SAXException {
  int startLine = currentLine;
  boolean done = false;
  boolean emptyTag = false;

  while(!done) {
    switch(chars[current++]) {
    case '\t':
      // Ignore whitespace
      continue;
    case '\n':
      // Next line
      currentLine++;
      lastLinePosition=current;
      continue;
    case '\r':
      // Ignore whitespace
      continue;
    case ' ':
      // Ignore whitespace
      continue;
    case '/':
      try {
        match(chars, ">", "uri", startLine);
        // Done
        emptyTag=true;done=true;
      } catch(Exception e) { current -= 2; sendCharacters(chars, 0); done = true; continue; }
      continue;
    case '>':
      // Done
      done = true;
      continue;
    case 'i':
      match(chars, "d", "uri", startLine);
      {String value = _readAttribute(chars);
      // not required
      if(ids.put(value, this) != null) throw new SAXParseException("Duplicate ID found: " + value, this);
      if(true&& false) throw new SAXParseException("Not a valid attribute value: [" + value + "]", this);
      putAttribute("id", "ID", value);}
      continue;
    default:
      throw new SAXParseException("Could not parse: uri starting at line " + startLine, this);
    }

  }

  return emptyTag;
}

public void readTlibversion(char[] chars) throws SAXException {
  int startLine = currentLine;
  try {
    reset();
    boolean emptyTag = readTlibversionAttributes(chars);
    dh.startElement("tlibversion", this);
    boolean done = false;
    while(!done && !emptyTag) {
    switch(chars[current++]) {
    case '\t':
      // Ignore whitespace
      continue;
    case '\n':
      nextLine();
      continue;
    case '\r':
      // Ignore whitespace
      continue;
    case ' ':
      // Ignore whitespace
      continue;
    case '&':
      handleEscapes(chars);
      continue;
    case '<':
      switch(chars[current++]) {
      case '!':
        switch(chars[current++]) {
        case '-':
          match(chars, "-", "tlibversion", startLine);
          eatComment(chars);
          continue;
        case '[':
          match(chars, "CDATA[", "tlibversion", startLine);
          handleCDATA(chars);
          continue;
        default:
          throw new SAXParseException("Could not parse: tlibversion starting at line " + startLine, this);
        }
      case '/':
        try {
          match(chars, "tlibversion>", "tlibversion", startLine);
          sendCharacters(chars, 14);
          done = true;
        } catch(Exception e) { current -= 2; sendCharacters(chars, 0); done = true; continue; }
        continue;
      default:
        current -= 2; sendCharacters(chars, 0); done = true; continue;
      }
    default:
      if(startCharacterData == -1) startCharacterData = current - 1;
    }

    }
    dh.endElement("tlibversion");
  } catch(ArrayIndexOutOfBoundsException aioobe) {
    throw new SAXParseException("tlibversion not closed, starts at line " + startLine, this);
  }
}

public boolean readTlibversionAttributes(char[] chars) throws SAXException {
  int startLine = currentLine;
  boolean done = false;
  boolean emptyTag = false;

  while(!done) {
    switch(chars[current++]) {
    case '\t':
      // Ignore whitespace
      continue;
    case '\n':
      // Next line
      currentLine++;
      lastLinePosition=current;
      continue;
    case '\r':
      // Ignore whitespace
      continue;
    case ' ':
      // Ignore whitespace
      continue;
    case '/':
      try {
        match(chars, ">", "tlibversion", startLine);
        // Done
        emptyTag=true;done=true;
      } catch(Exception e) { current -= 2; sendCharacters(chars, 0); done = true; continue; }
      continue;
    case '>':
      // Done
      done = true;
      continue;
    case 'i':
      match(chars, "d", "tlibversion", startLine);
      {String value = _readAttribute(chars);
      // not required
      if(ids.put(value, this) != null) throw new SAXParseException("Duplicate ID found: " + value, this);
      if(true&& false) throw new SAXParseException("Not a valid attribute value: [" + value + "]", this);
      putAttribute("id", "ID", value);}
      continue;
    default:
      throw new SAXParseException("Could not parse: tlibversion starting at line " + startLine, this);
    }

  }

  return emptyTag;
}

public void readShortname(char[] chars) throws SAXException {
  int startLine = currentLine;
  try {
    reset();
    boolean emptyTag = readShortnameAttributes(chars);
    dh.startElement("shortname", this);
    boolean done = false;
    while(!done && !emptyTag) {
    switch(chars[current++]) {
    case '\t':
      // Ignore whitespace
      continue;
    case '\n':
      nextLine();
      continue;
    case '\r':
      // Ignore whitespace
      continue;
    case ' ':
      // Ignore whitespace
      continue;
    case '&':
      handleEscapes(chars);
      continue;
    case '<':
      switch(chars[current++]) {
      case '!':
        switch(chars[current++]) {
        case '-':
          match(chars, "-", "shortname", startLine);
          eatComment(chars);
          continue;
        case '[':
          match(chars, "CDATA[", "shortname", startLine);
          handleCDATA(chars);
          continue;
        default:
          throw new SAXParseException("Could not parse: shortname starting at line " + startLine, this);
        }
      case '/':
        try {
          match(chars, "shortname>", "shortname", startLine);
          sendCharacters(chars, 12);
          done = true;
        } catch(Exception e) { current -= 2; sendCharacters(chars, 0); done = true; continue; }
        continue;
      default:
        current -= 2; sendCharacters(chars, 0); done = true; continue;
      }
    default:
      if(startCharacterData == -1) startCharacterData = current - 1;
    }

    }
    dh.endElement("shortname");
  } catch(ArrayIndexOutOfBoundsException aioobe) {
    throw new SAXParseException("shortname not closed, starts at line " + startLine, this);
  }
}

public boolean readShortnameAttributes(char[] chars) throws SAXException {
  int startLine = currentLine;
  boolean done = false;
  boolean emptyTag = false;

  while(!done) {
    switch(chars[current++]) {
    case '\t':
      // Ignore whitespace
      continue;
    case '\n':
      // Next line
      currentLine++;
      lastLinePosition=current;
      continue;
    case '\r':
      // Ignore whitespace
      continue;
    case ' ':
      // Ignore whitespace
      continue;
    case '/':
      try {
        match(chars, ">", "shortname", startLine);
        // Done
        emptyTag=true;done=true;
      } catch(Exception e) { current -= 2; sendCharacters(chars, 0); done = true; continue; }
      continue;
    case '>':
      // Done
      done = true;
      continue;
    case 'i':
      match(chars, "d", "shortname", startLine);
      {String value = _readAttribute(chars);
      // not required
      if(ids.put(value, this) != null) throw new SAXParseException("Duplicate ID found: " + value, this);
      if(true&& false) throw new SAXParseException("Not a valid attribute value: [" + value + "]", this);
      putAttribute("id", "ID", value);}
      continue;
    default:
      throw new SAXParseException("Could not parse: shortname starting at line " + startLine, this);
    }

  }

  return emptyTag;
}

public void readTeiclass(char[] chars) throws SAXException {
  int startLine = currentLine;
  try {
    reset();
    boolean emptyTag = readTeiclassAttributes(chars);
    dh.startElement("teiclass", this);
    boolean done = false;
    while(!done && !emptyTag) {
    switch(chars[current++]) {
    case '\t':
      // Ignore whitespace
      continue;
    case '\n':
      nextLine();
      continue;
    case '\r':
      // Ignore whitespace
      continue;
    case ' ':
      // Ignore whitespace
      continue;
    case '&':
      handleEscapes(chars);
      continue;
    case '<':
      switch(chars[current++]) {
      case '!':
        switch(chars[current++]) {
        case '-':
          match(chars, "-", "teiclass", startLine);
          eatComment(chars);
          continue;
        case '[':
          match(chars, "CDATA[", "teiclass", startLine);
          handleCDATA(chars);
          continue;
        default:
          throw new SAXParseException("Could not parse: teiclass starting at line " + startLine, this);
        }
      case '/':
        try {
          match(chars, "teiclass>", "teiclass", startLine);
          sendCharacters(chars, 11);
          done = true;
        } catch(Exception e) { current -= 2; sendCharacters(chars, 0); done = true; continue; }
        continue;
      default:
        current -= 2; sendCharacters(chars, 0); done = true; continue;
      }
    default:
      if(startCharacterData == -1) startCharacterData = current - 1;
    }

    }
    dh.endElement("teiclass");
  } catch(ArrayIndexOutOfBoundsException aioobe) {
    throw new SAXParseException("teiclass not closed, starts at line " + startLine, this);
  }
}

public boolean readTeiclassAttributes(char[] chars) throws SAXException {
  int startLine = currentLine;
  boolean done = false;
  boolean emptyTag = false;

  while(!done) {
    switch(chars[current++]) {
    case '\t':
      // Ignore whitespace
      continue;
    case '\n':
      // Next line
      currentLine++;
      lastLinePosition=current;
      continue;
    case '\r':
      // Ignore whitespace
      continue;
    case ' ':
      // Ignore whitespace
      continue;
    case '/':
      try {
        match(chars, ">", "teiclass", startLine);
        // Done
        emptyTag=true;done=true;
      } catch(Exception e) { current -= 2; sendCharacters(chars, 0); done = true; continue; }
      continue;
    case '>':
      // Done
      done = true;
      continue;
    case 'i':
      match(chars, "d", "teiclass", startLine);
      {String value = _readAttribute(chars);
      // not required
      if(ids.put(value, this) != null) throw new SAXParseException("Duplicate ID found: " + value, this);
      if(true&& false) throw new SAXParseException("Not a valid attribute value: [" + value + "]", this);
      putAttribute("id", "ID", value);}
      continue;
    default:
      throw new SAXParseException("Could not parse: teiclass starting at line " + startLine, this);
    }

  }

  return emptyTag;
}

public void readRtexprvalue(char[] chars) throws SAXException {
  int startLine = currentLine;
  try {
    reset();
    boolean emptyTag = readRtexprvalueAttributes(chars);
    dh.startElement("rtexprvalue", this);
    boolean done = false;
    while(!done && !emptyTag) {
    switch(chars[current++]) {
    case '\t':
      // Ignore whitespace
      continue;
    case '\n':
      nextLine();
      continue;
    case '\r':
      // Ignore whitespace
      continue;
    case ' ':
      // Ignore whitespace
      continue;
    case '&':
      handleEscapes(chars);
      continue;
    case '<':
      switch(chars[current++]) {
      case '!':
        switch(chars[current++]) {
        case '-':
          match(chars, "-", "rtexprvalue", startLine);
          eatComment(chars);
          continue;
        case '[':
          match(chars, "CDATA[", "rtexprvalue", startLine);
          handleCDATA(chars);
          continue;
        default:
          throw new SAXParseException("Could not parse: rtexprvalue starting at line " + startLine, this);
        }
      case '/':
        try {
          match(chars, "rtexprvalue>", "rtexprvalue", startLine);
          sendCharacters(chars, 14);
          done = true;
        } catch(Exception e) { current -= 2; sendCharacters(chars, 0); done = true; continue; }
        continue;
      default:
        current -= 2; sendCharacters(chars, 0); done = true; continue;
      }
    default:
      if(startCharacterData == -1) startCharacterData = current - 1;
    }

    }
    dh.endElement("rtexprvalue");
  } catch(ArrayIndexOutOfBoundsException aioobe) {
    throw new SAXParseException("rtexprvalue not closed, starts at line " + startLine, this);
  }
}

public boolean readRtexprvalueAttributes(char[] chars) throws SAXException {
  int startLine = currentLine;
  boolean done = false;
  boolean emptyTag = false;

  while(!done) {
    switch(chars[current++]) {
    case '\t':
      // Ignore whitespace
      continue;
    case '\n':
      // Next line
      currentLine++;
      lastLinePosition=current;
      continue;
    case '\r':
      // Ignore whitespace
      continue;
    case ' ':
      // Ignore whitespace
      continue;
    case '/':
      try {
        match(chars, ">", "rtexprvalue", startLine);
        // Done
        emptyTag=true;done=true;
      } catch(Exception e) { current -= 2; sendCharacters(chars, 0); done = true; continue; }
      continue;
    case '>':
      // Done
      done = true;
      continue;
    case 'i':
      match(chars, "d", "rtexprvalue", startLine);
      {String value = _readAttribute(chars);
      // not required
      if(ids.put(value, this) != null) throw new SAXParseException("Duplicate ID found: " + value, this);
      if(true&& false) throw new SAXParseException("Not a valid attribute value: [" + value + "]", this);
      putAttribute("id", "ID", value);}
      continue;
    default:
      throw new SAXParseException("Could not parse: rtexprvalue starting at line " + startLine, this);
    }

  }

  return emptyTag;
}

public void readRequired(char[] chars) throws SAXException {
  int startLine = currentLine;
  try {
    reset();
    boolean emptyTag = readRequiredAttributes(chars);
    dh.startElement("required", this);
    boolean done = false;
    while(!done && !emptyTag) {
    switch(chars[current++]) {
    case '\t':
      // Ignore whitespace
      continue;
    case '\n':
      nextLine();
      continue;
    case '\r':
      // Ignore whitespace
      continue;
    case ' ':
      // Ignore whitespace
      continue;
    case '&':
      handleEscapes(chars);
      continue;
    case '<':
      switch(chars[current++]) {
      case '!':
        switch(chars[current++]) {
        case '-':
          match(chars, "-", "required", startLine);
          eatComment(chars);
          continue;
        case '[':
          match(chars, "CDATA[", "required", startLine);
          handleCDATA(chars);
          continue;
        default:
          throw new SAXParseException("Could not parse: required starting at line " + startLine, this);
        }
      case '/':
        try {
          match(chars, "required>", "required", startLine);
          sendCharacters(chars, 11);
          done = true;
        } catch(Exception e) { current -= 2; sendCharacters(chars, 0); done = true; continue; }
        continue;
      default:
        current -= 2; sendCharacters(chars, 0); done = true; continue;
      }
    default:
      if(startCharacterData == -1) startCharacterData = current - 1;
    }

    }
    dh.endElement("required");
  } catch(ArrayIndexOutOfBoundsException aioobe) {
    throw new SAXParseException("required not closed, starts at line " + startLine, this);
  }
}

public boolean readRequiredAttributes(char[] chars) throws SAXException {
  int startLine = currentLine;
  boolean done = false;
  boolean emptyTag = false;

  while(!done) {
    switch(chars[current++]) {
    case '\t':
      // Ignore whitespace
      continue;
    case '\n':
      // Next line
      currentLine++;
      lastLinePosition=current;
      continue;
    case '\r':
      // Ignore whitespace
      continue;
    case ' ':
      // Ignore whitespace
      continue;
    case '/':
      try {
        match(chars, ">", "required", startLine);
        // Done
        emptyTag=true;done=true;
      } catch(Exception e) { current -= 2; sendCharacters(chars, 0); done = true; continue; }
      continue;
    case '>':
      // Done
      done = true;
      continue;
    case 'i':
      match(chars, "d", "required", startLine);
      {String value = _readAttribute(chars);
      // not required
      if(ids.put(value, this) != null) throw new SAXParseException("Duplicate ID found: " + value, this);
      if(true&& false) throw new SAXParseException("Not a valid attribute value: [" + value + "]", this);
      putAttribute("id", "ID", value);}
      continue;
    default:
      throw new SAXParseException("Could not parse: required starting at line " + startLine, this);
    }

  }

  return emptyTag;
}

public void readTagclass(char[] chars) throws SAXException {
  int startLine = currentLine;
  try {
    reset();
    boolean emptyTag = readTagclassAttributes(chars);
    dh.startElement("tagclass", this);
    boolean done = false;
    while(!done && !emptyTag) {
    switch(chars[current++]) {
    case '\t':
      // Ignore whitespace
      continue;
    case '\n':
      nextLine();
      continue;
    case '\r':
      // Ignore whitespace
      continue;
    case ' ':
      // Ignore whitespace
      continue;
    case '&':
      handleEscapes(chars);
      continue;
    case '<':
      switch(chars[current++]) {
      case '!':
        switch(chars[current++]) {
        case '-':
          match(chars, "-", "tagclass", startLine);
          eatComment(chars);
          continue;
        case '[':
          match(chars, "CDATA[", "tagclass", startLine);
          handleCDATA(chars);
          continue;
        default:
          throw new SAXParseException("Could not parse: tagclass starting at line " + startLine, this);
        }
      case '/':
        try {
          match(chars, "tagclass>", "tagclass", startLine);
          sendCharacters(chars, 11);
          done = true;
        } catch(Exception e) { current -= 2; sendCharacters(chars, 0); done = true; continue; }
        continue;
      default:
        current -= 2; sendCharacters(chars, 0); done = true; continue;
      }
    default:
      if(startCharacterData == -1) startCharacterData = current - 1;
    }

    }
    dh.endElement("tagclass");
  } catch(ArrayIndexOutOfBoundsException aioobe) {
    throw new SAXParseException("tagclass not closed, starts at line " + startLine, this);
  }
}

public boolean readTagclassAttributes(char[] chars) throws SAXException {
  int startLine = currentLine;
  boolean done = false;
  boolean emptyTag = false;

  while(!done) {
    switch(chars[current++]) {
    case '\t':
      // Ignore whitespace
      continue;
    case '\n':
      // Next line
      currentLine++;
      lastLinePosition=current;
      continue;
    case '\r':
      // Ignore whitespace
      continue;
    case ' ':
      // Ignore whitespace
      continue;
    case '/':
      try {
        match(chars, ">", "tagclass", startLine);
        // Done
        emptyTag=true;done=true;
      } catch(Exception e) { current -= 2; sendCharacters(chars, 0); done = true; continue; }
      continue;
    case '>':
      // Done
      done = true;
      continue;
    case 'i':
      match(chars, "d", "tagclass", startLine);
      {String value = _readAttribute(chars);
      // not required
      if(ids.put(value, this) != null) throw new SAXParseException("Duplicate ID found: " + value, this);
      if(true&& false) throw new SAXParseException("Not a valid attribute value: [" + value + "]", this);
      putAttribute("id", "ID", value);}
      continue;
    default:
      throw new SAXParseException("Could not parse: tagclass starting at line " + startLine, this);
    }

  }

  return emptyTag;
}

public void readJspversion(char[] chars) throws SAXException {
  int startLine = currentLine;
  try {
    reset();
    boolean emptyTag = readJspversionAttributes(chars);
    dh.startElement("jspversion", this);
    boolean done = false;
    while(!done && !emptyTag) {
    switch(chars[current++]) {
    case '\t':
      // Ignore whitespace
      continue;
    case '\n':
      nextLine();
      continue;
    case '\r':
      // Ignore whitespace
      continue;
    case ' ':
      // Ignore whitespace
      continue;
    case '&':
      handleEscapes(chars);
      continue;
    case '<':
      switch(chars[current++]) {
      case '!':
        switch(chars[current++]) {
        case '-':
          match(chars, "-", "jspversion", startLine);
          eatComment(chars);
          continue;
        case '[':
          match(chars, "CDATA[", "jspversion", startLine);
          handleCDATA(chars);
          continue;
        default:
          throw new SAXParseException("Could not parse: jspversion starting at line " + startLine, this);
        }
      case '/':
        try {
          match(chars, "jspversion>", "jspversion", startLine);
          sendCharacters(chars, 13);
          done = true;
        } catch(Exception e) { current -= 2; sendCharacters(chars, 0); done = true; continue; }
        continue;
      default:
        current -= 2; sendCharacters(chars, 0); done = true; continue;
      }
    default:
      if(startCharacterData == -1) startCharacterData = current - 1;
    }

    }
    dh.endElement("jspversion");
  } catch(ArrayIndexOutOfBoundsException aioobe) {
    throw new SAXParseException("jspversion not closed, starts at line " + startLine, this);
  }
}

public boolean readJspversionAttributes(char[] chars) throws SAXException {
  int startLine = currentLine;
  boolean done = false;
  boolean emptyTag = false;

  while(!done) {
    switch(chars[current++]) {
    case '\t':
      // Ignore whitespace
      continue;
    case '\n':
      // Next line
      currentLine++;
      lastLinePosition=current;
      continue;
    case '\r':
      // Ignore whitespace
      continue;
    case ' ':
      // Ignore whitespace
      continue;
    case '/':
      try {
        match(chars, ">", "jspversion", startLine);
        // Done
        emptyTag=true;done=true;
      } catch(Exception e) { current -= 2; sendCharacters(chars, 0); done = true; continue; }
      continue;
    case '>':
      // Done
      done = true;
      continue;
    case 'i':
      match(chars, "d", "jspversion", startLine);
      {String value = _readAttribute(chars);
      // not required
      if(ids.put(value, this) != null) throw new SAXParseException("Duplicate ID found: " + value, this);
      if(true&& false) throw new SAXParseException("Not a valid attribute value: [" + value + "]", this);
      putAttribute("id", "ID", value);}
      continue;
    default:
      throw new SAXParseException("Could not parse: jspversion starting at line " + startLine, this);
    }

  }

  return emptyTag;
}

public void readTaglib(char[] chars) throws SAXException {
  int startLine = currentLine;
  try {
    reset();
    boolean emptyTag = readTaglibAttributes(chars);
    dh.startElement("taglib", this);
    boolean done = false;
    while(!done && !emptyTag) {
    switch(chars[current++]) {
    case '\t':
      // Ignore whitespace
      continue;
    case '\n':
      nextLine();
      continue;
    case '\r':
      // Ignore whitespace
      continue;
    case ' ':
      // Ignore whitespace
      continue;
    case '&':
      handleEscapes(chars);
      continue;
    case '<':
      switch(chars[current++]) {
      case '!':
        switch(chars[current++]) {
        case '-':
          match(chars, "-", "taglib", startLine);
          eatComment(chars);
          continue;
        case '[':
          match(chars, "CDATA[", "taglib", startLine);
          handleCDATA(chars);
          continue;
        default:
          throw new SAXParseException("Could not parse: taglib starting at line " + startLine, this);
        }
      case '/':
        try {
          match(chars, "taglib>", "taglib", startLine);
          sendCharacters(chars, 9);
          done = true;
        } catch(Exception e) { current -= 2; sendCharacters(chars, 0); done = true; continue; }
        continue;
      case 'i':
        match(chars, "nfo", "taglib", startLine);
        sendCharacters(chars, 5);
        readInfo(chars);
        continue;
      case 'j':
        match(chars, "spversion", "taglib", startLine);
        sendCharacters(chars, 11);
        readJspversion(chars);
        continue;
      case 's':
        match(chars, "hortname", "taglib", startLine);
        sendCharacters(chars, 10);
        readShortname(chars);
        continue;
      case 't':
        switch(chars[current++]) {
        case 'a':
          match(chars, "g", "taglib", startLine);
          sendCharacters(chars, 4);
          readTag(chars);
          continue;
        case 'l':
          match(chars, "ibversion", "taglib", startLine);
          sendCharacters(chars, 12);
          readTlibversion(chars);
          continue;
        default:
          throw new SAXParseException("Could not parse: taglib starting at line " + startLine, this);
        }
      case 'u':
        switch(chars[current++]) {
        case 'r':
          switch(chars[current++]) {
          case 'i':
            sendCharacters(chars, 4);
            readUri(chars);
            continue;
          case 'n':
            sendCharacters(chars, 4);
            readUrn(chars);
            continue;
          default:
            throw new SAXParseException("Could not parse: taglib starting at line " + startLine, this);
          }
        default:
          throw new SAXParseException("Could not parse: taglib starting at line " + startLine, this);
        }
      default:
        current -= 2; sendCharacters(chars, 0); done = true; continue;
      }
    default:
      if(startCharacterData == -1) startCharacterData = current - 1;
    }

    }
    dh.endElement("taglib");
  } catch(ArrayIndexOutOfBoundsException aioobe) {
    throw new SAXParseException("taglib not closed, starts at line " + startLine, this);
  }
}

public boolean readTaglibAttributes(char[] chars) throws SAXException {
  int startLine = currentLine;
  boolean done = false;
  boolean emptyTag = false;

  while(!done) {
    switch(chars[current++]) {
    case '\t':
      // Ignore whitespace
      continue;
    case '\n':
      // Next line
      currentLine++;
      lastLinePosition=current;
      continue;
    case '\r':
      // Ignore whitespace
      continue;
    case ' ':
      // Ignore whitespace
      continue;
    case '/':
      try {
        match(chars, ">", "taglib", startLine);
        // Done
        emptyTag=true;done=true;
      } catch(Exception e) { current -= 2; sendCharacters(chars, 0); done = true; continue; }
      continue;
    case '>':
      // Done
      done = true;
      continue;
    case 'i':
      match(chars, "d", "taglib", startLine);
      {String value = _readAttribute(chars);
      // not required
      if(ids.put(value, this) != null) throw new SAXParseException("Duplicate ID found: " + value, this);
      if(true&& false) throw new SAXParseException("Not a valid attribute value: [" + value + "]", this);
      putAttribute("id", "ID", value);}
      continue;
    case 'x':
      match(chars, "mlns", "taglib", startLine);
      {String value = _readAttribute(chars);
      // not required
      // not an id
      if(true&& !value.equals("http://java.sun.com/j2ee/dtds/web-jsptaglibrary_1_1.dtd")) throw new SAXParseException("Not a valid attribute value: [" + value + "]", this);
      putAttribute("xmlns", "CDATA", value);}
      continue;
    default:
      throw new SAXParseException("Could not parse: taglib starting at line " + startLine, this);
    }

  }

  return emptyTag;
}

public void readUrn(char[] chars) throws SAXException {
  int startLine = currentLine;
  try {
    reset();
    boolean emptyTag = readUrnAttributes(chars);
    dh.startElement("urn", this);
    boolean done = false;
    while(!done && !emptyTag) {
    switch(chars[current++]) {
    case '\t':
      // Ignore whitespace
      continue;
    case '\n':
      nextLine();
      continue;
    case '\r':
      // Ignore whitespace
      continue;
    case ' ':
      // Ignore whitespace
      continue;
    case '&':
      handleEscapes(chars);
      continue;
    case '<':
      switch(chars[current++]) {
      case '!':
        switch(chars[current++]) {
        case '-':
          match(chars, "-", "urn", startLine);
          eatComment(chars);
          continue;
        case '[':
          match(chars, "CDATA[", "urn", startLine);
          handleCDATA(chars);
          continue;
        default:
          throw new SAXParseException("Could not parse: urn starting at line " + startLine, this);
        }
      case '/':
        try {
          match(chars, "urn>", "urn", startLine);
          sendCharacters(chars, 6);
          done = true;
        } catch(Exception e) { current -= 2; sendCharacters(chars, 0); done = true; continue; }
        continue;
      default:
        current -= 2; sendCharacters(chars, 0); done = true; continue;
      }
    default:
      if(startCharacterData == -1) startCharacterData = current - 1;
    }

    }
    dh.endElement("urn");
  } catch(ArrayIndexOutOfBoundsException aioobe) {
    throw new SAXParseException("urn not closed, starts at line " + startLine, this);
  }
}

public boolean readUrnAttributes(char[] chars) throws SAXException {
  int startLine = currentLine;
  boolean done = false;
  boolean emptyTag = false;

  while(!done) {
    switch(chars[current++]) {
    case '\t':
      // Ignore whitespace
      continue;
    case '\n':
      // Next line
      currentLine++;
      lastLinePosition=current;
      continue;
    case '\r':
      // Ignore whitespace
      continue;
    case ' ':
      // Ignore whitespace
      continue;
    case '/':
      try {
        match(chars, ">", "urn", startLine);
        // Done
        emptyTag=true;done=true;
      } catch(Exception e) { current -= 2; sendCharacters(chars, 0); done = true; continue; }
      continue;
    case '>':
      // Done
      done = true;
      continue;
    default:
      throw new SAXParseException("Could not parse: urn starting at line " + startLine, this);
    }

  }

  return emptyTag;
}

public void readTag(char[] chars) throws SAXException {
  int startLine = currentLine;
  try {
    reset();
    boolean emptyTag = readTagAttributes(chars);
    dh.startElement("tag", this);
    boolean done = false;
    while(!done && !emptyTag) {
    switch(chars[current++]) {
    case '\t':
      // Ignore whitespace
      continue;
    case '\n':
      nextLine();
      continue;
    case '\r':
      // Ignore whitespace
      continue;
    case ' ':
      // Ignore whitespace
      continue;
    case '&':
      handleEscapes(chars);
      continue;
    case '<':
      switch(chars[current++]) {
      case '!':
        switch(chars[current++]) {
        case '-':
          match(chars, "-", "tag", startLine);
          eatComment(chars);
          continue;
        case '[':
          match(chars, "CDATA[", "tag", startLine);
          handleCDATA(chars);
          continue;
        default:
          throw new SAXParseException("Could not parse: tag starting at line " + startLine, this);
        }
      case '/':
        try {
          match(chars, "tag>", "tag", startLine);
          sendCharacters(chars, 6);
          done = true;
        } catch(Exception e) { current -= 2; sendCharacters(chars, 0); done = true; continue; }
        continue;
      case 'a':
        match(chars, "ttribute", "tag", startLine);
        sendCharacters(chars, 10);
        readAttribute(chars);
        continue;
      case 'b':
        match(chars, "odycontent", "tag", startLine);
        sendCharacters(chars, 12);
        readBodycontent(chars);
        continue;
      case 'i':
        match(chars, "nfo", "tag", startLine);
        sendCharacters(chars, 5);
        readInfo(chars);
        continue;
      case 'n':
        match(chars, "ame", "tag", startLine);
        sendCharacters(chars, 5);
        readName(chars);
        continue;
      case 't':
        switch(chars[current++]) {
        case 'a':
          match(chars, "gclass", "tag", startLine);
          sendCharacters(chars, 9);
          readTagclass(chars);
          continue;
        case 'e':
          match(chars, "iclass", "tag", startLine);
          sendCharacters(chars, 9);
          readTeiclass(chars);
          continue;
        default:
          throw new SAXParseException("Could not parse: tag starting at line " + startLine, this);
        }
      default:
        current -= 2; sendCharacters(chars, 0); done = true; continue;
      }
    default:
      if(startCharacterData == -1) startCharacterData = current - 1;
    }

    }
    dh.endElement("tag");
  } catch(ArrayIndexOutOfBoundsException aioobe) {
    throw new SAXParseException("tag not closed, starts at line " + startLine, this);
  }
}

public boolean readTagAttributes(char[] chars) throws SAXException {
  int startLine = currentLine;
  boolean done = false;
  boolean emptyTag = false;

  while(!done) {
    switch(chars[current++]) {
    case '\t':
      // Ignore whitespace
      continue;
    case '\n':
      // Next line
      currentLine++;
      lastLinePosition=current;
      continue;
    case '\r':
      // Ignore whitespace
      continue;
    case ' ':
      // Ignore whitespace
      continue;
    case '/':
      try {
        match(chars, ">", "tag", startLine);
        // Done
        emptyTag=true;done=true;
      } catch(Exception e) { current -= 2; sendCharacters(chars, 0); done = true; continue; }
      continue;
    case '>':
      // Done
      done = true;
      continue;
    case 'i':
      match(chars, "d", "tag", startLine);
      {String value = _readAttribute(chars);
      // not required
      if(ids.put(value, this) != null) throw new SAXParseException("Duplicate ID found: " + value, this);
      if(true&& false) throw new SAXParseException("Not a valid attribute value: [" + value + "]", this);
      putAttribute("id", "ID", value);}
      continue;
    default:
      throw new SAXParseException("Could not parse: tag starting at line " + startLine, this);
    }

  }

  return emptyTag;
}




  // ============================================================
  // Factory methods

  public static weblogic.servlet.jsp.stdtag.Taglib makeTaglib(String filename, Map map, boolean verbose) throws IOException, SAXException {
     Handler handler = new Handler(map,"weblogic.servlet.jsp.stdtag",verbose);
     try {
       handler.setClassLoader(Class.forName("weblogic.servlet.jsp.stdtag.TaglibParser").getClassLoader());
     } catch(ClassNotFoundException cnfe) {
       cnfe.printStackTrace();  // really shouldn't happen
     }
     makeParser(handler).parse(filename);
     return (weblogic.servlet.jsp.stdtag.Taglib)handler.getTopLevel();
  }

  public static weblogic.servlet.jsp.stdtag.Taglib makeTaglib(File file, Map map, boolean verbose) throws IOException, SAXException {
     Handler handler = new Handler(map,"weblogic.servlet.jsp.stdtag",verbose);
     try {
       handler.setClassLoader(Class.forName("weblogic.servlet.jsp.stdtag.TaglibParser").getClassLoader());
     } catch(ClassNotFoundException cnfe) {
       cnfe.printStackTrace();  // really shouldn't happen
     }
     makeParser(handler).parse(file);
     return (weblogic.servlet.jsp.stdtag.Taglib)handler.getTopLevel();
  }

  public static weblogic.servlet.jsp.stdtag.Taglib makeTaglib(InputSource is, Map map, boolean verbose) throws IOException, SAXException {
     Handler handler = new Handler(map,"weblogic.servlet.jsp.stdtag",verbose);
     try {
       handler.setClassLoader(Class.forName("weblogic.servlet.jsp.stdtag.TaglibParser").getClassLoader());
     } catch(ClassNotFoundException cnfe) {
       cnfe.printStackTrace();  // really shouldn't happen
     }
     makeParser(handler).parse(is);
     return (weblogic.servlet.jsp.stdtag.Taglib)handler.getTopLevel();
  }

  public static weblogic.servlet.jsp.stdtag.Taglib makeTaglib(InputStream in, Map map, boolean verbose) throws IOException, SAXException {
     Handler handler = new Handler(map,"weblogic.servlet.jsp.stdtag",verbose);
     try {
       handler.setClassLoader(Class.forName("weblogic.servlet.jsp.stdtag.TaglibParser").getClassLoader());
     } catch(ClassNotFoundException cnfe) {
       cnfe.printStackTrace();  // really shouldn't happen
     }
     makeParser(handler).parse(in);
     return (weblogic.servlet.jsp.stdtag.Taglib)handler.getTopLevel();
  }

  public static weblogic.servlet.jsp.stdtag.Taglib makeTaglib(InputStream in, String encodingType, Map map, boolean verbose) throws IOException, SAXException {
     Handler handler = new Handler(map,"weblogic.servlet.jsp.stdtag",verbose);
     try {
       handler.setClassLoader(Class.forName("weblogic.servlet.jsp.stdtag.TaglibParser").getClassLoader());
     } catch(ClassNotFoundException cnfe) {
       cnfe.printStackTrace();  // really shouldn't happen
     }
     makeParser(handler).parse(in,encodingType);
     return (weblogic.servlet.jsp.stdtag.Taglib)handler.getTopLevel();
  }



  private static TaglibParser makeParser(Handler handler) throws IOException, SAXException {       
     TaglibParser parser = new TaglibParser();
     try {
       handler.setClassLoader(Class.forName("weblogic.servlet.jsp.stdtag.TaglibParser").getClassLoader());
     } catch(ClassNotFoundException cnfe) {
       cnfe.printStackTrace();  // really shouldn't happen
     }
     parser.setDocumentHandler(handler);
     return parser;
  }



  
  // ============================================================
  // Constructor

  public TaglibParser() {
    htypes.put("id", "ID");
    htypes.put("xmlns", "CDATA");

    names  = new String[2];
    types  = new String[2];
    values = new String[2];
  }

}
