package weblogic.servlet.jsp.wltag;

import weblogic.servlet.jsp.wltag.Jsptaglib;
import java.io.*;
import java.net.*;
import java.util.Hashtable;
import java.util.Locale;
import java.util.Map;
import org.w3c.dom.*;
import org.xml.sax.*;
import org.xml.sax.helpers.ParserFactory;
import weblogic.xml.dtdc.Handler;
import weblogic.xml.dtdc.NullHandler;

public class JsptaglibParser extends weblogic.xml.dtdc.BaseParser {

  // ============================================================
  // Parse

  public static void main(String[] args) throws Exception {
    try {
      Parser parser = ParserFactory.makeParser("weblogic.servlet.jsp.wltag.JsptaglibParser");
      Handler handler = new Handler("weblogic.servlet.jsp.wltag", true);
      handler.setClassLoader(Class.forName("weblogic.servlet.jsp.wltag.JsptaglibParser").getClassLoader());
      parser.setDocumentHandler(handler);
      parser.parse(args[0]);
    } catch(SAXParseException saxpe) {
      System.out.println("Line: " + saxpe.getLineNumber() + " Column: " + saxpe.getColumnNumber());
      throw saxpe;
    }
  }

  // ============================================================
  // Generated Code

  public void parse(char[] chars) throws SAXException {
    boolean done = false;
    int startLine = currentLine;
    if(dh == null) dh = new NullHandler();
    dh.setDocumentLocator(this);
    dh.startDocument();
    while(current != chars.length && !done) {
      switch(chars[current++]) {
      case '\t':
        // Ignore whitespace
        continue;
      case '\n':
        nextLine();
        continue;
      case '\r':
        // Ignore whitespace
        continue;
      case ' ':
        // Ignore whitespace
        continue;
      case '<':
        switch(chars[current++]) {
        case '!':
          switch(chars[current++]) {
          case '-':
            match(chars, "-", "jsptaglib", startLine);
            eatComment(chars);
            continue;
          case 'D':
            match(chars, "OCTYPE", "jsptaglib", startLine);
            // Ignore DTD specification
            while(chars[current++] != '>');
            continue;
          default:
            throw new SAXParseException("Could not parse: jsptaglib starting at line " + startLine, this);
          }
        case '?':
          match(chars, "xml", "jsptaglib", startLine);
          // Ignore XML version
          while(chars[current++] != '>');
          continue;
        case 'j':
          match(chars, "sptaglib", "jsptaglib", startLine);
          sendCharacters(chars, 10);
          readJsptaglib(chars);
          continue;
        default:
          throw new SAXParseException("Could not parse: jsptaglib starting at line " + startLine, this);
        }
      default:
        if(startCharacterData == -1) startCharacterData = current - 1;
      }

    }
    if(done) throw new SAXParseException("Could not parse (bad close tag): starting at line " + startLine, this);
    dh.endDocument();
  }

public void readTag(char[] chars) throws SAXException {
  int startLine = currentLine;
  try {
    reset();
    boolean emptyTag = readTagAttributes(chars);
    dh.startElement("tag", this);
    boolean done = false;
    while(!done && !emptyTag) {
    switch(chars[current++]) {
    case '\t':
      // Ignore whitespace
      continue;
    case '\n':
      nextLine();
      continue;
    case '\r':
      // Ignore whitespace
      continue;
    case ' ':
      // Ignore whitespace
      continue;
    case '&':
      handleEscapes(chars);
      continue;
    case '<':
      switch(chars[current++]) {
      case '!':
        switch(chars[current++]) {
        case '-':
          match(chars, "-", "tag", startLine);
          eatComment(chars);
          continue;
        case '[':
          match(chars, "CDATA[", "tag", startLine);
          handleCDATA(chars);
          continue;
        default:
          throw new SAXParseException("Could not parse: tag starting at line " + startLine, this);
        }
      case '/':
        try {
          match(chars, "tag>", "tag", startLine);
          sendCharacters(chars, 6);
          done = true;
        } catch(Exception e) { current -= 2; sendCharacters(chars, 0); done = true; continue; }
        continue;
      case 'a':
        match(chars, "ttribute", "tag", startLine);
        sendCharacters(chars, 10);
        readAttribute(chars);
        continue;
      case 'd':
        switch(chars[current++]) {
        case 'o':
          match(chars, "c", "tag", startLine);
          sendCharacters(chars, 4);
          readDoc(chars);
          continue;
        case 'w':
          match(chars, "_translator", "tag", startLine);
          sendCharacters(chars, 14);
          readDwTranslator(chars);
          continue;
        default:
          throw new SAXParseException("Could not parse: tag starting at line " + startLine, this);
        }
      default:
        current -= 2; sendCharacters(chars, 0); done = true; continue;
      }
    default:
      if(startCharacterData == -1) startCharacterData = current - 1;
    }

    }
    dh.endElement("tag");
  } catch(ArrayIndexOutOfBoundsException aioobe) {
    throw new SAXParseException("tag not closed, starts at line " + startLine, this);
  }
}

public boolean readTagAttributes(char[] chars) throws SAXException {
  int startLine = currentLine;
  boolean done = false;
  boolean emptyTag = false;
  boolean nameFound = false;
  boolean classFound = false;

  while(!done) {
    switch(chars[current++]) {
    case '\t':
      // Ignore whitespace
      continue;
    case '\n':
      // Next line
      currentLine++;
      lastLinePosition=current;
      continue;
    case '\r':
      // Ignore whitespace
      continue;
    case ' ':
      // Ignore whitespace
      continue;
    case '/':
      try {
        match(chars, ">", "tag", startLine);
        // Done
        emptyTag=true;done=true;
      } catch(Exception e) { current -= 2; sendCharacters(chars, 0); done = true; continue; }
      continue;
    case '>':
      // Done
      done = true;
      continue;
    case 'c':
      match(chars, "lass", "tag", startLine);
      {String value = _readAttribute(chars);
      classFound = true;
      // not an id
      if(true&& false) throw new SAXParseException("Not a valid attribute value: [" + value + "]", this);
      putAttribute("class", "CDATA", value);}
      continue;
    case 'n':
      match(chars, "ame", "tag", startLine);
      {String value = _readAttribute(chars);
      nameFound = true;
      // not an id
      if(true&& false) throw new SAXParseException("Not a valid attribute value: [" + value + "]", this);
      putAttribute("name", "CDATA", value);}
      continue;
    case 't':
      match(chars, "ype", "tag", startLine);
      {String value = _readAttribute(chars);
      // not required
      // not an id
      if(true && !value.equals("empty") && !value.equals("body") && !value.equals("both")) throw new SAXParseException("Not a valid attribute value: [" + value + "]", this);
      putAttribute("type", "ENUMERATION", value);}
      continue;
    default:
      throw new SAXParseException("Could not parse: tag starting at line " + startLine, this);
    }

  }
    if(!nameFound) throw new SAXParseException("Required attribute name not found", this);
    if(!classFound) throw new SAXParseException("Required attribute class not found", this);

  return emptyTag;
}

public void readDwValid(char[] chars) throws SAXException {
  int startLine = currentLine;
  try {
    reset();
    boolean emptyTag = readDwValidAttributes(chars);
    dh.startElement("dw_valid", this);
    boolean done = false;
    while(!done && !emptyTag) {
done = true;
    }
    dh.endElement("dw_valid");
  } catch(ArrayIndexOutOfBoundsException aioobe) {
    throw new SAXParseException("dw_valid not closed, starts at line " + startLine, this);
  }
}

public boolean readDwValidAttributes(char[] chars) throws SAXException {
  int startLine = currentLine;
  boolean done = false;
  boolean emptyTag = false;
  boolean valueFound = false;

  while(!done) {
    switch(chars[current++]) {
    case '\t':
      // Ignore whitespace
      continue;
    case '\n':
      // Next line
      currentLine++;
      lastLinePosition=current;
      continue;
    case '\r':
      // Ignore whitespace
      continue;
    case ' ':
      // Ignore whitespace
      continue;
    case '/':
      try {
        match(chars, ">", "dw_valid", startLine);
        // Done
        emptyTag=true;done=true;
      } catch(Exception e) { current -= 2; sendCharacters(chars, 0); done = true; continue; }
      continue;
    case '>':
      // Done
      done = true;
      continue;
    case 'v':
      match(chars, "alue", "dw_valid", startLine);
      {String value = _readAttribute(chars);
      valueFound = true;
      // not an id
      if(true&& false) throw new SAXParseException("Not a valid attribute value: [" + value + "]", this);
      putAttribute("value", "CDATA", value);}
      continue;
    default:
      throw new SAXParseException("Could not parse: dw_valid starting at line " + startLine, this);
    }

  }
    if(!valueFound) throw new SAXParseException("Required attribute value not found", this);

  return emptyTag;
}

public void readJsptaglib(char[] chars) throws SAXException {
  int startLine = currentLine;
  try {
    reset();
    boolean emptyTag = readJsptaglibAttributes(chars);
    dh.startElement("jsptaglib", this);
    boolean done = false;
    while(!done && !emptyTag) {
    switch(chars[current++]) {
    case '\t':
      // Ignore whitespace
      continue;
    case '\n':
      nextLine();
      continue;
    case '\r':
      // Ignore whitespace
      continue;
    case ' ':
      // Ignore whitespace
      continue;
    case '&':
      handleEscapes(chars);
      continue;
    case '<':
      switch(chars[current++]) {
      case '!':
        switch(chars[current++]) {
        case '-':
          match(chars, "-", "jsptaglib", startLine);
          eatComment(chars);
          continue;
        case '[':
          match(chars, "CDATA[", "jsptaglib", startLine);
          handleCDATA(chars);
          continue;
        default:
          throw new SAXParseException("Could not parse: jsptaglib starting at line " + startLine, this);
        }
      case '/':
        try {
          match(chars, "jsptaglib>", "jsptaglib", startLine);
          sendCharacters(chars, 12);
          done = true;
        } catch(Exception e) { current -= 2; sendCharacters(chars, 0); done = true; continue; }
        continue;
      case 't':
        match(chars, "ag", "jsptaglib", startLine);
        sendCharacters(chars, 4);
        readTag(chars);
        continue;
      default:
        current -= 2; sendCharacters(chars, 0); done = true; continue;
      }
    default:
      if(startCharacterData == -1) startCharacterData = current - 1;
    }

    }
    dh.endElement("jsptaglib");
  } catch(ArrayIndexOutOfBoundsException aioobe) {
    throw new SAXParseException("jsptaglib not closed, starts at line " + startLine, this);
  }
}

public boolean readJsptaglibAttributes(char[] chars) throws SAXException {
  int startLine = currentLine;
  boolean done = false;
  boolean emptyTag = false;
  boolean nameFound = false;

  while(!done) {
    switch(chars[current++]) {
    case '\t':
      // Ignore whitespace
      continue;
    case '\n':
      // Next line
      currentLine++;
      lastLinePosition=current;
      continue;
    case '\r':
      // Ignore whitespace
      continue;
    case ' ':
      // Ignore whitespace
      continue;
    case '/':
      try {
        match(chars, ">", "jsptaglib", startLine);
        // Done
        emptyTag=true;done=true;
      } catch(Exception e) { current -= 2; sendCharacters(chars, 0); done = true; continue; }
      continue;
    case '>':
      // Done
      done = true;
      continue;
    case 'n':
      match(chars, "ame", "jsptaglib", startLine);
      {String value = _readAttribute(chars);
      nameFound = true;
      // not an id
      if(true&& false) throw new SAXParseException("Not a valid attribute value: [" + value + "]", this);
      putAttribute("name", "CDATA", value);}
      continue;
    default:
      throw new SAXParseException("Could not parse: jsptaglib starting at line " + startLine, this);
    }

  }
    if(!nameFound) throw new SAXParseException("Required attribute name not found", this);

  return emptyTag;
}

public void readAttribute(char[] chars) throws SAXException {
  int startLine = currentLine;
  try {
    reset();
    boolean emptyTag = readAttributeAttributes(chars);
    dh.startElement("attribute", this);
    boolean done = false;
    while(!done && !emptyTag) {
    switch(chars[current++]) {
    case '\t':
      // Ignore whitespace
      continue;
    case '\n':
      nextLine();
      continue;
    case '\r':
      // Ignore whitespace
      continue;
    case ' ':
      // Ignore whitespace
      continue;
    case '&':
      handleEscapes(chars);
      continue;
    case '<':
      switch(chars[current++]) {
      case '!':
        switch(chars[current++]) {
        case '-':
          match(chars, "-", "attribute", startLine);
          eatComment(chars);
          continue;
        case '[':
          match(chars, "CDATA[", "attribute", startLine);
          handleCDATA(chars);
          continue;
        default:
          throw new SAXParseException("Could not parse: attribute starting at line " + startLine, this);
        }
      case '/':
        try {
          match(chars, "attribute>", "attribute", startLine);
          sendCharacters(chars, 12);
          done = true;
        } catch(Exception e) { current -= 2; sendCharacters(chars, 0); done = true; continue; }
        continue;
      case 'd':
        switch(chars[current++]) {
        case 'o':
          match(chars, "c", "attribute", startLine);
          sendCharacters(chars, 4);
          readDoc(chars);
          continue;
        case 'w':
          match(chars, "_valid", "attribute", startLine);
          sendCharacters(chars, 9);
          readDwValid(chars);
          continue;
        default:
          throw new SAXParseException("Could not parse: attribute starting at line " + startLine, this);
        }
      default:
        current -= 2; sendCharacters(chars, 0); done = true; continue;
      }
    default:
      if(startCharacterData == -1) startCharacterData = current - 1;
    }

    }
    dh.endElement("attribute");
  } catch(ArrayIndexOutOfBoundsException aioobe) {
    throw new SAXParseException("attribute not closed, starts at line " + startLine, this);
  }
}

public boolean readAttributeAttributes(char[] chars) throws SAXException {
  int startLine = currentLine;
  boolean done = false;
  boolean emptyTag = false;
  boolean nameFound = false;

  while(!done) {
    switch(chars[current++]) {
    case '\t':
      // Ignore whitespace
      continue;
    case '\n':
      // Next line
      currentLine++;
      lastLinePosition=current;
      continue;
    case '\r':
      // Ignore whitespace
      continue;
    case ' ':
      // Ignore whitespace
      continue;
    case '/':
      try {
        match(chars, ">", "attribute", startLine);
        // Done
        emptyTag=true;done=true;
      } catch(Exception e) { current -= 2; sendCharacters(chars, 0); done = true; continue; }
      continue;
    case '>':
      // Done
      done = true;
      continue;
    case 'n':
      match(chars, "ame", "attribute", startLine);
      {String value = _readAttribute(chars);
      nameFound = true;
      // not an id
      if(true&& false) throw new SAXParseException("Not a valid attribute value: [" + value + "]", this);
      putAttribute("name", "CDATA", value);}
      continue;
    case 't':
      match(chars, "ype", "attribute", startLine);
      {String value = _readAttribute(chars);
      // not required
      // not an id
      if(true && !value.equals("required") && !value.equals("optional") && !value.equals("any")) throw new SAXParseException("Not a valid attribute value: [" + value + "]", this);
      putAttribute("type", "ENUMERATION", value);}
      continue;
    default:
      throw new SAXParseException("Could not parse: attribute starting at line " + startLine, this);
    }

  }
    if(!nameFound) throw new SAXParseException("Required attribute name not found", this);

  return emptyTag;
}

public void readDwTranslator(char[] chars) throws SAXException {
  int startLine = currentLine;
  try {
    reset();
    boolean emptyTag = readDwTranslatorAttributes(chars);
    dh.startElement("dw_translator", this);
    boolean done = false;
    while(!done && !emptyTag) {
    switch(chars[current++]) {
    case '\t':
      // Ignore whitespace
      continue;
    case '\n':
      nextLine();
      continue;
    case '\r':
      // Ignore whitespace
      continue;
    case ' ':
      // Ignore whitespace
      continue;
    case '&':
      handleEscapes(chars);
      continue;
    case '<':
      switch(chars[current++]) {
      case '!':
        switch(chars[current++]) {
        case '-':
          match(chars, "-", "dw_translator", startLine);
          eatComment(chars);
          continue;
        case '[':
          match(chars, "CDATA[", "dw_translator", startLine);
          handleCDATA(chars);
          continue;
        default:
          throw new SAXParseException("Could not parse: dw_translator starting at line " + startLine, this);
        }
      case '/':
        try {
          match(chars, "dw_translator>", "dw_translator", startLine);
          sendCharacters(chars, 16);
          done = true;
        } catch(Exception e) { current -= 2; sendCharacters(chars, 0); done = true; continue; }
        continue;
      default:
        current -= 2; sendCharacters(chars, 0); done = true; continue;
      }
    default:
      if(startCharacterData == -1) startCharacterData = current - 1;
    }

    }
    dh.endElement("dw_translator");
  } catch(ArrayIndexOutOfBoundsException aioobe) {
    throw new SAXParseException("dw_translator not closed, starts at line " + startLine, this);
  }
}

public boolean readDwTranslatorAttributes(char[] chars) throws SAXException {
  int startLine = currentLine;
  boolean done = false;
  boolean emptyTag = false;

  while(!done) {
    switch(chars[current++]) {
    case '\t':
      // Ignore whitespace
      continue;
    case '\n':
      // Next line
      currentLine++;
      lastLinePosition=current;
      continue;
    case '\r':
      // Ignore whitespace
      continue;
    case ' ':
      // Ignore whitespace
      continue;
    case '/':
      try {
        match(chars, ">", "dw_translator", startLine);
        // Done
        emptyTag=true;done=true;
      } catch(Exception e) { current -= 2; sendCharacters(chars, 0); done = true; continue; }
      continue;
    case '>':
      // Done
      done = true;
      continue;
    case 't':
      match(chars, "ype", "dw_translator", startLine);
      {String value = _readAttribute(chars);
      // not required
      // not an id
      if(true && !value.equals("empty") && !value.equals("start") && !value.equals("end") && !value.equals("default")) throw new SAXParseException("Not a valid attribute value: [" + value + "]", this);
      putAttribute("type", "ENUMERATION", value);}
      continue;
    default:
      throw new SAXParseException("Could not parse: dw_translator starting at line " + startLine, this);
    }

  }

  return emptyTag;
}

public void readDoc(char[] chars) throws SAXException {
  int startLine = currentLine;
  try {
    reset();
    boolean emptyTag = readDocAttributes(chars);
    dh.startElement("doc", this);
    boolean done = false;
    while(!done && !emptyTag) {
    switch(chars[current++]) {
    case '\t':
      // Ignore whitespace
      continue;
    case '\n':
      nextLine();
      continue;
    case '\r':
      // Ignore whitespace
      continue;
    case ' ':
      // Ignore whitespace
      continue;
    case '&':
      handleEscapes(chars);
      continue;
    case '<':
      switch(chars[current++]) {
      case '!':
        switch(chars[current++]) {
        case '-':
          match(chars, "-", "doc", startLine);
          eatComment(chars);
          continue;
        case '[':
          match(chars, "CDATA[", "doc", startLine);
          handleCDATA(chars);
          continue;
        default:
          throw new SAXParseException("Could not parse: doc starting at line " + startLine, this);
        }
      case '/':
        try {
          match(chars, "doc>", "doc", startLine);
          sendCharacters(chars, 6);
          done = true;
        } catch(Exception e) { current -= 2; sendCharacters(chars, 0); done = true; continue; }
        continue;
      default:
        current -= 2; sendCharacters(chars, 0); done = true; continue;
      }
    default:
      if(startCharacterData == -1) startCharacterData = current - 1;
    }

    }
    dh.endElement("doc");
  } catch(ArrayIndexOutOfBoundsException aioobe) {
    throw new SAXParseException("doc not closed, starts at line " + startLine, this);
  }
}

public boolean readDocAttributes(char[] chars) throws SAXException {
  int startLine = currentLine;
  boolean done = false;
  boolean emptyTag = false;

  while(!done) {
    switch(chars[current++]) {
    case '\t':
      // Ignore whitespace
      continue;
    case '\n':
      // Next line
      currentLine++;
      lastLinePosition=current;
      continue;
    case '\r':
      // Ignore whitespace
      continue;
    case ' ':
      // Ignore whitespace
      continue;
    case '/':
      try {
        match(chars, ">", "doc", startLine);
        // Done
        emptyTag=true;done=true;
      } catch(Exception e) { current -= 2; sendCharacters(chars, 0); done = true; continue; }
      continue;
    case '>':
      // Done
      done = true;
      continue;
    default:
      throw new SAXParseException("Could not parse: doc starting at line " + startLine, this);
    }

  }

  return emptyTag;
}




  // ============================================================
  // Factory methods

  public static weblogic.servlet.jsp.wltag.Jsptaglib makeJsptaglib(String filename, Map map, boolean verbose) throws IOException, SAXException {
     Handler handler = new Handler(map,"weblogic.servlet.jsp.wltag",verbose);
     try {
       handler.setClassLoader(Class.forName("weblogic.servlet.jsp.wltag.JsptaglibParser").getClassLoader());
     } catch(ClassNotFoundException cnfe) {
       cnfe.printStackTrace();  // really shouldn't happen
     }
     makeParser(handler).parse(filename);
     return (weblogic.servlet.jsp.wltag.Jsptaglib)handler.getTopLevel();
  }

  public static weblogic.servlet.jsp.wltag.Jsptaglib makeJsptaglib(File file, Map map, boolean verbose) throws IOException, SAXException {
     Handler handler = new Handler(map,"weblogic.servlet.jsp.wltag",verbose);
     try {
       handler.setClassLoader(Class.forName("weblogic.servlet.jsp.wltag.JsptaglibParser").getClassLoader());
     } catch(ClassNotFoundException cnfe) {
       cnfe.printStackTrace();  // really shouldn't happen
     }
     makeParser(handler).parse(file);
     return (weblogic.servlet.jsp.wltag.Jsptaglib)handler.getTopLevel();
  }

  public static weblogic.servlet.jsp.wltag.Jsptaglib makeJsptaglib(InputSource is, Map map, boolean verbose) throws IOException, SAXException {
     Handler handler = new Handler(map,"weblogic.servlet.jsp.wltag",verbose);
     try {
       handler.setClassLoader(Class.forName("weblogic.servlet.jsp.wltag.JsptaglibParser").getClassLoader());
     } catch(ClassNotFoundException cnfe) {
       cnfe.printStackTrace();  // really shouldn't happen
     }
     makeParser(handler).parse(is);
     return (weblogic.servlet.jsp.wltag.Jsptaglib)handler.getTopLevel();
  }

  public static weblogic.servlet.jsp.wltag.Jsptaglib makeJsptaglib(InputStream in, Map map, boolean verbose) throws IOException, SAXException {
     Handler handler = new Handler(map,"weblogic.servlet.jsp.wltag",verbose);
     try {
       handler.setClassLoader(Class.forName("weblogic.servlet.jsp.wltag.JsptaglibParser").getClassLoader());
     } catch(ClassNotFoundException cnfe) {
       cnfe.printStackTrace();  // really shouldn't happen
     }
     makeParser(handler).parse(in);
     return (weblogic.servlet.jsp.wltag.Jsptaglib)handler.getTopLevel();
  }

  public static weblogic.servlet.jsp.wltag.Jsptaglib makeJsptaglib(InputStream in, String encodingType, Map map, boolean verbose) throws IOException, SAXException {
     Handler handler = new Handler(map,"weblogic.servlet.jsp.wltag",verbose);
     try {
       handler.setClassLoader(Class.forName("weblogic.servlet.jsp.wltag.JsptaglibParser").getClassLoader());
     } catch(ClassNotFoundException cnfe) {
       cnfe.printStackTrace();  // really shouldn't happen
     }
     makeParser(handler).parse(in,encodingType);
     return (weblogic.servlet.jsp.wltag.Jsptaglib)handler.getTopLevel();
  }



  private static JsptaglibParser makeParser(Handler handler) throws IOException, SAXException {       
     JsptaglibParser parser = new JsptaglibParser();
     try {
       handler.setClassLoader(Class.forName("weblogic.servlet.jsp.wltag.JsptaglibParser").getClassLoader());
     } catch(ClassNotFoundException cnfe) {
       cnfe.printStackTrace();  // really shouldn't happen
     }
     parser.setDocumentHandler(handler);
     return parser;
  }



  
  // ============================================================
  // Constructor

  public JsptaglibParser() {
    htypes.put("class", "CDATA");
    htypes.put("name", "CDATA");
    htypes.put("type", "ENUMERATION");
    htypes.put("value", "CDATA");

    names  = new String[4];
    types  = new String[4];
    values = new String[4];
  }

}
