package weblogic;

import java.lang.reflect.Field;

import java.util.HashMap;
import java.util.Iterator;
import java.util.Map;

/**
 * Version utility for WebLogic Server
 * <p>
 * WebLogic Server Build <code>6.0 12/13/2000 22:49:45 #94427</code>
 * @author     Copyright (c) 1999-2000 BEA Systems, Inc. All Rights Reserved.
 */

public class version {

  private static Map modules;

/**
 * Build version of WebLogic Server and installed modules<p>
 * Build <code>6.0 12/13/2000 22:49:45 #94427</code>
 */
  private final static String WLS_PRODUCT_NAME = "WebLogic Server Build";
  //Changing the names not to protect the innocent but those that
  //that were directly referring to these, as it inlined version
  //strings into class files
  private final static String BLD_VERSION = "6.0 12/13/2000 22:49:45 #94427";
  private final static String REL_BLD_VERSION = "6.0";

  public static String getBuildVersion() {
    return BLD_VERSION;
  }

  public static String getReleaseBuildVersion() {
    return REL_BLD_VERSION;
  }





  static {
    modules = new HashMap();

    // xmlx.jar build version
    String xmlxVer = getModuleVersionString("weblogicx.xml.version");
    modules.put("WebLogic XML Module", xmlxVer);

    // other modules that might be created in the future go here... 
  }

  // constructor
  public version() {}

  public static String getProductVersion(String moduleName) {
    if (WLS_PRODUCT_NAME.equalsIgnoreCase(moduleName) ||
	WLS_PRODUCT_NAME.startsWith(moduleName)) {
      return BLD_VERSION;
    } else {
      String stringVersion = "Not installed";
      Iterator i = modules.keySet().iterator();
      while (i.hasNext()) {
	String modkey = (String)i.next();
	if (modkey.equalsIgnoreCase(moduleName) || 
	    modkey.startsWith(moduleName)) {
	  stringVersion = (String)modules.get(modkey);
	  break;
	}
      }
      return stringVersion;
    }
  }
  
  public static void main(String argv[]) {
    try {
      System.out.println("\n" + getVersions());
      System.out.flush();
    } finally {
      System.exit(0);
    }
  }
  
  public static String getVersions() {
    StringBuffer str = new StringBuffer();

    // Do main WLS first
    str.append(WLS_PRODUCT_NAME);
    str.append(":\t");
    str.append(BLD_VERSION);
    str.append("\n");

    // Now put version of installable modules
    Iterator i = modules.keySet().iterator();
    while (i.hasNext()) {
      String moduleName = (String)i.next();
      String versionString = (String)modules.get(moduleName);
      str.append(moduleName);
      str.append(":\t");
      if (versionString != null) str.append(versionString);
      else str.append("Not installed");
      str.append('\n');
    }
    return str.toString();
  }

  /**
   * Return a two-element String array containing WebLogic Server version
   * info.
   * @return The first element is the string "WebLogic Server", the second
   * element is the version number of WebLogic Server.
   */

  public static String[] getPLInfo() {
    String[] str = new String[2];
    str[0] = "WebLogic Server";    
    str[1] = BLD_VERSION;
    int i = BLD_VERSION.indexOf(" ");
    str[1] = str[1].substring(0, i);
    return str;
  }


  /**
   * Given the name of a module's version class, return the version
   * string. The version string is stored in a public static String
   * field of name "VERSION".
   * @param moduleVersionClassName The name of the module's version class
   * @return the version string; returns null if the module is not installed
   * or there was some other error
   */
  private static String getModuleVersionString(String moduleVersionClassName) {
    String verString = null;
    try {
      Class verClass = Class.forName(moduleVersionClassName);
      Field verField = verClass.getDeclaredField("VERSION");
      verString = (String)verField.get(null);
    } catch (Throwable t) {} // module not installed or other error
    return verString;
  }

}

