// $ANTLR 2.7.0: "weblogic/servlet/jsp/JspLexer.g" -> "JspLexer.java"$

package weblogic.servlet.jsp;

import java.io.InputStream;
import antlr.TokenStreamException;
import antlr.TokenStreamIOException;
import antlr.TokenStreamRecognitionException;
import antlr.CharStreamException;
import antlr.CharStreamIOException;
import antlr.ANTLRException;
import java.io.Reader;
import java.util.Hashtable;
import antlr.CharScanner;
import antlr.InputBuffer;
import antlr.ByteBuffer;
import antlr.CharBuffer;
import antlr.Token;
import antlr.CommonToken;
import antlr.RecognitionException;
import antlr.NoViableAltForCharException;
import antlr.MismatchedCharException;
import antlr.TokenStream;
import antlr.ANTLRHashString;
import antlr.LexerSharedInputState;
import antlr.collections.impl.BitSet;
import antlr.SemanticException;

import antlr.*;
import java.beans.*;
import java.util.*;
import java.util.jar.*;
import java.util.jar.Attributes;
import java.util.zip.*;
import java.io.*;
import weblogic.utils.AssertionError;
import weblogic.utils.Debug;
import weblogic.utils.ParsingException;
import weblogic.utils.UnsyncStringBuffer;
import weblogic.kernel.Kernel;
import weblogic.server.Server;
import weblogic.servlet.jhtmlc.*;
import weblogic.servlet.internal.*; 
import org.w3c.dom.*;
import org.xml.sax.*;
import weblogic.xml.dtdc.*;
import weblogic.servlet.internal.dd.TaglibDescriptor;
import weblogic.utils.classloaders.Source; 
import weblogic.t3.srvr.T3Srvr;

/**
 * ANTLR-generated lexer for JSP pages.
 *
 * @author Copyright (c) 1999 by BEA WebXpress. All Rights Reserved.
 */
public class JspLexer extends antlr.CharScanner implements JspLexerTokenTypes, TokenStream
 {

  public static File getHomeRelativeFile(String uri) {
    File file = new File(uri.replace('/', File.separatorChar));
    if(!file.exists()) {
      if (Kernel.isServer()) {
        file = new File(Server.getConfig().getRootDirectory() + File.separatorChar + uri.replace('/', File.separatorChar));
      } else {
        file = new File(uri.replace('/', File.separatorChar));
      }
    }
    if(file.exists()) {
      return file;
    }
    return null;
  }

    public TagLib loadTagLib(String uri, String prefix, boolean verbose) throws IOException, SAXException, JspException {
	/* look first for a weblogic tag lib */
	if (isWebLogicTagLib(uri)) {
          File taglib = getHomeRelativeFile(uri);
          if(taglib != null) {
            recordSourceDependency(uri, taglib.lastModified(), true);
            return new WLTagLib(uri, verbose);
          }
	}

	InputStream is = loadTaglibTLD(uri, verbose);
	/* REMIND/FIXME: how should we know when a standard taglib dependency
	 * is stale (for the StaleIndicator interface)???
	 */
	if (is != null) {
	    try {
		ClassLoader cl = servletClassLoader;
		if (servletContext != null)
		    cl = servletContext.getServletClassLoader();

		jspc.setLine(getLine());
		return new StandardTagLib(uri, prefix,
					  is,
					  cl, jspc);
	    } finally {
		is.close();
	    }
	}
	throw new IOException("cannot resolve '" + uri + "' into a valid tag library");
    }

    private InputStream loadTaglibTLDFromJar(String location, WebAppServletContext sc, boolean verbose) {
	if (!location.endsWith(".jar") && !location.endsWith(".JAR")) {
	    return null;
	}
	try {
	    Dictionary jars = sc.getJarFiles();
	    if (jars == null) {
		return null;
	    }
	    location = location.replace('/', File.separatorChar);
	    String simpleName = location;
	    int ind = simpleName.lastIndexOf(File.separatorChar);
	    if (ind >= 0) {
		simpleName = simpleName.substring(ind + 1);
	    }
	    String jarPath = (String)jars.get(simpleName);
	    if (jarPath == null) {
		sc.logError("Could not resolve taglib location " + location +
			    ": no such jar file was found.  It should be in the /WEB-INF/lib directory");
		return null;
	    }
	    ZipFile zf = new ZipFile(jarPath);
	    try {
		ZipEntry ze = zf.getEntry("META-INF/taglib.tld");
		if (ze == null) ze = zf.getEntry("/META-INF/taglib.tld");
		if (ze == null) {
		    sc.logError("Could not load taglib from jar file " + jarPath +
				": this jarfile has no META-INF/taglib.tld entry " +
				"(JSP 1.1 spec, 5.2.1)");
		    return null;
		}
		InputStream is = zf.getInputStream(ze);
		ByteArrayOutputStream baos = new ByteArrayOutputStream();
		byte[] buf = new byte[512];
		int r;
		int nread = 0;
		while ((r = is.read(buf)) > 0) {
		    baos.write(buf, 0, r);
		    nread += r;
		}
		zf.close();
		zf = null;
		buf = baos.toByteArray();
		is = new ByteArrayInputStream(buf, 0, nread);
		return is;
	    } finally {
		if (zf != null) zf.close();
	    }
	} catch (Exception ignore) {
	    if (debug) ignore.printStackTrace();
	}
	return null;
    }
	    
    private InputStream loadTaglibTLD(String uri, boolean verbose) throws IOException {
	String wiuri = null;
	if (uri.length() > 0 && uri.charAt(0) == '/')
	    wiuri = "/WEB-INF" + uri;
	else
	    wiuri = "/WEB-INF/" + uri;
	/* JSP 1.1 spec, and Eduardo's email of 10/05/1999 */
	if (servletContext != null) {
	    /* first, look for its location given its name */
	    List libs = servletContext.getTaglibs();
	    if (libs != null) {
		Iterator iter = libs.iterator();
		while (iter.hasNext()) {
		    TaglibDescriptor tld = (TaglibDescriptor)iter.next();
		    if (uri.equals(tld.getURI())) {
			String location = tld.getLocation();
			if (verbose) {
			    servletContext.log("resolving taglib uri '" + uri + "' to taglib-location " + location + ":");
			}
			if (location != null && location.endsWith(".jar") || location.endsWith(".JAR")) {
			    /* JSP 1.1 section 5.2.1 */
			    InputStream is = loadTaglibTLDFromJar(location, servletContext, verbose);
			    if (is != null) return is;
			} else {
			    try {
				return servletContext.getResourceAsSource(location, false).getInputStream();
			    } catch (IOException ignore) {
			    } catch (NullPointerException ignoreThisToo) {}
			}
		    }
		}
	    }
	    /* look for it as a path relative to WEB-INF */
	    if (uri.endsWith(".jar") || uri.endsWith(".JAR")) {
		if (verbose) servletContext.log("looking for taglib uri " + uri + " as JAR packaged taglib " +
						wiuri + " in Web Application root:");
		InputStream is = loadTaglibTLDFromJar(wiuri, servletContext, verbose);
		if (is != null) return is;
		if (verbose) servletContext.log("looking for taglib uri " + uri + " as JAR packaged taglib " +
						uri + " in Web Application root:");
		is = loadTaglibTLDFromJar(uri, servletContext, verbose);
		if (is != null) return is;
	    } else {
		try {
		if (verbose) servletContext.log("looking for taglib uri " + uri + " as resource " +
						wiuri + " in Web Application root:");
		    return servletContext.getResourceAsSource(wiuri, false).getInputStream();
		} catch (IOException ignore) {
		} catch (NullPointerException ignoreThisToo) {}
		/* lastly, try just as a resource */
		try {
		if (verbose) servletContext.log("looking for taglib uri " + uri + " as resource " +
						uri + " in Web Application root:");
		    return servletContext.getResourceAsSource(uri, false).getInputStream();
		} catch (IOException ignore) {
		} catch (NullPointerException ignoreThisToo) {}
	    }
	}
	/* try loading it with the classloader, if not null */
	if (servletClassLoader != null && !wiuri.endsWith(".jar") && !wiuri.endsWith(".jar")) {
	    try {
		InputStream ret = servletClassLoader.getResourceAsStream(wiuri);
		if (ret != null) return ret;
	    } catch (Exception ignore) {}
	}
	/* weblogic.jspc uses this */
	File docroot = (File)jspc.getAttribute("docroot");
	if (docroot != null) {
	    try {
		File f = new File(docroot, wiuri.replace('/', File.separatorChar));
		return new FileInputStream(f);
	    } catch (Exception ignore) {}
	    try {
		File f = new File(docroot, uri.replace('/', File.separatorChar));
		return new FileInputStream(f);
	    } catch (Exception ignore) {}
	}
	return null;
    }

    private boolean isWebLogicTagLib(String uri) throws IOException, JspException {
      JarFile jf = null;
      try {
        File taglib = getHomeRelativeFile(uri);
        if(taglib == null) return false;
        jf = new JarFile(taglib);

        Map manifest = jf.getManifest().getEntries();
        Iterator entries = manifest.keySet().iterator();
        while(entries.hasNext()) {
          String key = (String) entries.next();
          Attributes entry = (Attributes) manifest.get(key);
          String isJspTagLib = 
            (String) entry.get(new Attributes.Name("jsp-tag-lib"));
          if("true".equalsIgnoreCase(isJspTagLib))
            return true;
        }
        throw new JspException("Found tag library, no jsp-tag-lib manifest entry");
      } catch (IOException ignore) {
        /** error loading jar file **/
      } finally {
        if (jf != null) jf.close();
      }
      return false;
    }

    private String[][] vector2array(Vector props) {
	int len = props.size();
	String[][] ret = new String[len][];
	Enumeration enum = props.elements();
        int i = 0;
        while(enum.hasMoreElements()) {
            String tmp[] = (String[])enum.nextElement();
            ret[i++] = tmp;
            if (debug) p("vector2array(): vector contains "+tmp[0]+"="+tmp[1]);
	}
	return ret;
    }

    /* dequoting script elements */
    public String scriptDequote(String script) {
	int position;
	while((position = script.indexOf("%\\>")) != -1) {
	    script = script.substring(0, position) + "%>" + script.substring(position + 3);
	}
	return script;
    }

    /* used in XML_PLUGIN */
    private void iePluginTag(Properties atts, Properties params, String fallback) {
	javaSection("code", "if (_isIE) { // begin IE plugin block...\n");
	javaSection("code", "out.println(\"<OBJECT classid=\\\"clsid:8AD9C840-044E-11D1-B3E9-00805F499D93\\\"\");\n");

	/*** the following are all attributes of the OBJECT tag: ***/
	String s = atts.getProperty("align");
	if (s != null) javaSection("code", "out.print(\" align=\\\"" + s + "\\\"\");\n");
	s = atts.getProperty("height");
	if (s != null) javaSection("code", "out.print(\" height=\\\"" + s + "\\\"\");\n");
	s = atts.getProperty("hspace");
	if (s != null) javaSection("code", "out.print(\" hspace=\\\"" + s + "\\\"\");\n");

	/* 'name' must be an OBJECT attribute and a param */
	String name = atts.getProperty("name");
	if (name != null) javaSection("code", "out.print(\" name=\\\"" + name + "\\\"\");\n");

	s = atts.getProperty("vspace");
	if (s != null) javaSection("code", "out.print(\" vspace=\\\"" + s + "\\\"\");\n");
	s = atts.getProperty("width");
	if (s != null) javaSection("code", "out.print(\" width=\\\"" + s + "\\\"\");\n");

	s = atts.getProperty("iepluginurl");
	if (s != null) {
	/* REMIND/FIXME: is this what to do with jreversion?? */
	    String jreversion = atts.getProperty("jreversion");
	    if (jreversion != null) {
		s += '#' + jreversion;
	    }
	    javaSection("code", "out.print(\" codebase=\\\"" + s + "\\\"\");\n");
	}

	/* close out object tag beginning */
	javaSection("code", "out.print(\">\\n\");\n");
	/*** The following are all params of the applet:
	 * archive, code, codebase
	 */
	s = atts.getProperty("archive");
	if (s != null)
	    javaSection("code", "out.print(\"  <PARAM name=\\\"archive\\\" value=\\\"" + s + "\\\">\\n\");\n");

	s = atts.getProperty("code");
	if (s != null)
	    javaSection("code", "out.print(\"  <PARAM name=\\\"code\\\" value=\\\"" + s + "\\\">\\n\");\n");

	s = atts.getProperty("codebase");
	if (s != null)
	    javaSection("code", "out.print(\"  <PARAM name=\\\"codebase\\\" value=\\\"" + s + "\\\">\\n\");\n");

	/* name is both an attribute and a param */
	if (name != null) 
	    javaSection("code", "out.print(\"  <PARAM name=\\\"name\\\" value=\\\"" + name + "\\\">\\n\");\n");
	String nspluginurl = (String)atts.remove("nspluginurl");
	/* add all the 'user' params */
	Enumeration enum = params.keys();
        javaSection("code", "String paramVal, paramName;");
	while (enum.hasMoreElements()) {
	    String pname = (String)enum.nextElement();
	    String pval = params.getProperty(pname);
            javaSection("code", "paramName = ");
            parseRequestTimeAttribute(pname);
            javaSection("code", "paramVal = ");
            parseRequestTimeAttribute(pval);
	    javaSection("code", "out.print(\"  <PARAM name=\\\"\"+paramName+\"\\\" value=\\\"\"+paramVal+\"\\\">\\n\");\n");
	}
	/* print fallbackstring, if any */
	if (fallback != null) {
	    htmlBuf.append(fallback);
	    htmlSection();
	}
	/* close out object tag */
	htmlBuf.append("\n</OBJECT>\n");
	htmlSection();
	javaSection("code", "\n} // end IE plugin block...\n");
	if (nspluginurl != null) atts.put("nspluginurl", nspluginurl);
    }

    /* used in XML_PLUGIN */
    private void nnPluginTag(Properties atts, Properties params, String fallback) {
	javaSection("code", "if (_isNN) { // begin NN plugin block...\n");
	/*** all attributes/params of an applet tag are attributes of the embed tag.
	 * So we remove the ones where we have to change the name between the
	 * jsp plugin tag and the embed tag, and then just add all the others as-is.
	 */
	String iepluginurl = (String)atts.remove("iepluginurl");
	String jreVersion = (String)atts.remove("jreversion");
	String type = (String)atts.remove("type");
	
	if (jreVersion == null) jreVersion = "";
	else jreVersion = ";version=" + jreVersion;

	/* if type=bean, the content-type is different */
	String embedType = null;
	//Debug.say("got plugin type='" + type + "'");
	if ("bean".equalsIgnoreCase(type)) {
	    embedType = "application/x-java-bean";
	} else {
	    embedType = "application/x-java-applet";
	}
	
	javaSection("code", "out.println(\"<EMBED type=\\\"" + embedType +
		    jreVersion + "\\\" \");\n");
	String pluginspage = (String)atts.remove("nspluginurl");
	if (pluginspage != null) javaSection("code", "out.print(\" pluginspage=\\\"" + pluginspage + "\\\"\");\n");
	/* add all the 'regular' attributes */
	Enumeration enum = atts.keys();
	while (enum.hasMoreElements()) {
	    String pname = (String)enum.nextElement();
	    String pval = atts.getProperty(pname);
	    javaSection("code", "out.print(\"  " + pname + "=\\\"" + pval +
			"\\\"\");\n");
	}
	/* add all the 'user' attributes */
	enum = params.keys();
        javaSection("code", "String paramVal, paramName;");
	while (enum.hasMoreElements()) {
	    String pname = (String)enum.nextElement();
	    String pval = params.getProperty(pname);
            javaSection("code", "paramName = ");
            parseRequestTimeAttribute(pname);
            javaSection("code", "paramVal = ");
            parseRequestTimeAttribute(pval);
	    javaSection("code", "out.print(\"  \"+paramName+\"=\\\"\"+paramVal+\"\\\"\");\n");
	}

	/* close out embed open tag */
	javaSection("code", "out.println(\">\\n\");\n");
	/* print the fallback within a NOEMBED tag */
	if (fallback != null) {
	    htmlBuf.append("  <NOEMBED>\n" + fallback + "\n  </NOEMBED>");
	    htmlSection();
	}
	/* close out EMBED tag */
	htmlBuf.append("\n</EMBED>\n");
	htmlSection();
	javaSection("code", "\n} // end NN plugin block...\n");
	if (iepluginurl != null) atts.put("iepluginurl", iepluginurl);
    }	

    /* used in XML_PLUGIN */
    private static Properties toLowerKeys(Properties orig) {
	Properties ret = new Properties();
	Enumeration enum = orig.keys();
	while (enum.hasMoreElements()) {
	    String k = (String)enum.nextElement();
	    String v = orig.getProperty(k);
	    k = k.toLowerCase();
	    ret.put(k, v);
	}
	return ret;
    }

    public String htmlDequote(String html) {
	int position;
	while((position = html.indexOf("<\\%")) != -1) {
	    html = html.substring(0, position) + "<%" + html.substring(position + 3);
	}
	return html;
    }

    public String attributeDequote(String attribute) {
	int position;
	while((position = attribute.indexOf("<\\%")) != -1) {
	    attribute = attribute.substring(0, position) + "<%" + attribute.substring(position + 3);
	}
	while((position = attribute.indexOf("%\\>")) != -1) {
	    attribute = attribute.substring(0, position) + "%>" + attribute.substring(position + 3);
	}
	while((position = attribute.indexOf("\\'")) != -1) {
	    attribute = attribute.substring(0, position) + "'" + attribute.substring(position + 2);
	}
//	while((position = attribute.indexOf("\\\"")) != -1) {
//	    attribute = attribute.substring(0, position) + "\"" + attribute.substring(position + 2);
//	}
	while((position = attribute.indexOf("&apos;")) != -1) {
	    attribute = attribute.substring(0, position) + "'" + attribute.substring(position + 6);
	}
	while((position = attribute.indexOf("&quot;")) != -1) {
	    attribute = attribute.substring(0, position) + "\"" + attribute.substring(position + 6);
	}
	while((position = attribute.indexOf("&lt;")) != -1) {
	    attribute = attribute.substring(0, position) + "<" + attribute.substring(position + 4);
	}
	while((position = attribute.indexOf("&gt;")) != -1) {
	    attribute = attribute.substring(0, position) + ">" + attribute.substring(position + 4);
	}
	return attribute;
    }

    /* for tag extension */
    private Hashtable taglibs = new Hashtable();

    protected String getTagExtraVarDeclarations() {
	UnsyncStringBuffer sb = new UnsyncStringBuffer();
	sb.append("// variables for Tag extension protocol\n");
	sb.append(StandardTagLib.getIntVariableDeclarations(jspc));
	Enumeration e = taglibs.elements();
	while (e.hasMoreElements()) {
	    Object o = e.nextElement();
	    if (o instanceof StandardTagLib) {
		StandardTagLib st = (StandardTagLib)o;
		sb.append(st.getVarDeclarations());
	    }
	}
	return sb.toString();
    }

    public void setTagLibs(Hashtable taglibs) {
      this.taglibs = taglibs;
    }

    /* convert the MM:Lock orig="..." tag:
     * %3Cjsp:expression%3E new Date() %3C/jsp:expression%3E -->
     * <jsp:expression> new Date() </jsp:expression>
     */
    private String decodeMM(String s) {
	return weblogic.utils.http.HttpParsing.unescape(s);
    }
	
    /* for dreamweaver */
    private void saveJSPBegin(String s, String tagType) {
	/* append the standard beginning... */
	htmlBuf.append("<MM:BeginLock translatorClass=\"WebLogic_JSP\" type=\"" + tagType + "\"" +
		  " depFiles=\"\" orig=\"");
	/* urlencode '"', '<', '>', and '%' */
	int len = s.length();
	for (int i = 0; i < len; i++) {
	    char c = s.charAt(i);
	    switch (c) {
	    case '"':
		htmlBuf.append("%22");
		break;
	    case '<':
		htmlBuf.append("%3C");
		break;
	    case '>':
		htmlBuf.append("%3E");
		break;
	    case '%':
		htmlBuf.append("%25");
		break;
	    case '\r': //also encode \r\n - javac pukes on them
		htmlBuf.append("%0D");
		break;
	    case '\n':
		htmlBuf.append("%0A");
		break;
	    default:
		htmlBuf.append(c);
	    }
	}
//  	/* end the MM... string */
  	htmlBuf.append("\"");
//  	/* end the MM tag */
  	htmlBuf.append(">");
	/* next comes translated content */
        javaSection("code", "\n// saved JSP Tag for DreamWeaver:\n");
        htmlSection();
    }

    private void saveJSPEnd() {
	javaSection("code", "out.println(\"<MM:EndLock>\");\n");
    }

    private final static boolean debug = false;
    static void p(String s) { System.out.println("[JspLexer]: " + s); }  
    private StringBuffer htmlBuf  = new StringBuffer();
    private PageCompileParser.Helper helper;

    private static final int DEFAULT_BUFFER_SIZE = 8192; // 8K
    private static final String pluginPreambleCode = " boolean _isIE = false, _isNN = false;\n" +
	" String _userAgent = request.getHeader(\"User-Agent\");\n" +
	" if (_userAgent != null) {\n" +
	"   String _userAgentLower = _userAgent.toLowerCase();\n" +
	"   if (_userAgent.indexOf(\"MSIE\") >= 0)\n" +
	"     _isIE = true;\n" +
	"   else if (_userAgentLower.indexOf(\"mozilla\") >= 0)\n" +
	"     _isNN = true;\n" +
	" }\n";
  
    /*** JSPPageContext initialization variables.
     ** These are initialzied to defaults, and
     * may change during parsing.
     */
    private int bufsize = DEFAULT_BUFFER_SIZE;
    private boolean autoflush = true;
    protected boolean session = true;
    private boolean iserrorpage = false;
      
    /** The error page to dispatch to if an error occurs here */
    private String errorPage = null;

    /* The JspContext */
    private JspContext jspc;

    /* propagate the following five variables to the sub-JspLexer
     * when processing include directives.
     */
    /* for dreamweaver */
    private boolean saveJSP = false;
    weblogic.servlet.internal.WebAppServletContext servletContext;
    ClassLoader servletClassLoader = null;

    public String getErrorPage() { return errorPage; }
    /* package */ void setSaveJSP(boolean b) { saveJSP = b; }
    private boolean getSaveJSP() { return saveJSP; }

    public void setJspContext(JspContext jspc) {
	this.jspc = jspc;
    }

    private void recordSourceDependency(String uri, long lastMod, boolean wltaglib) {
	JspDependency d = wltaglib ? new WLTagLibDependency(uri, lastMod):
	    new JspDependency(uri,lastMod);
	jspc.addDependency(d);
    }
	    
    String getPageContextCode() {
	return "PageContext pageContext =\n" +
	    " JspFactory.getDefaultFactory().getPageContext(this, request, response, " +
	    (errorPage == null ? "null, " : "\"" + errorPage + "\", ") +
	    session + ", " + bufsize + ", " + autoflush + ");\n";
    }

    String getIsErrorPageCode() {
	return iserrorpage ? IS_ERROR_PAGE_CODE: "";
    }

    private static final String IS_ERROR_PAGE_CODE =
	"Throwable exception = (Throwable)request.getAttribute(\"javax.servlet.jsp.jspException\");\n";

    private void jspException(String msg) {
	throw new JspException(msg, getLine());
    }

    private void languageDirective(String k) {
	if (!"java".equalsIgnoreCase(k)) {
	    jspException("This JSP engine only supports 'java' as a language, not '" + k + "'");
	}
    }

    static {
	JspFactoryImpl.init();
    }

    private void implementsDirective(String impls) {
	StringTokenizer st = new StringTokenizer(impls, ",", false);
	while (st.hasMoreTokens()) {
	    String iname = st.nextToken();
	    if (iname == null)
		continue;
	    iname = iname.trim();
	    if (iname.length() == 0)
		continue;
	    javaSection("implements", iname);
	}
    }

    private void bufferDirective(String b) {
	b = b.trim();
	if ("none".equalsIgnoreCase(b)) {
	    if (!autoflush) {
		jspException("Cannot set both buffer=\"none\" and autoFlush=\"false\" (JSP 1.0: 2.7.1.1)");
	    }
	    bufsize = 0;
	    return;
	}
	StringBuffer number = new StringBuffer(10);
	int len = b.length();
	int i;
	for (i = 0; i < len; i++) {
	    char c = b.charAt(i);
	    if (c < '0' || c > '9')
		break;
	    number.append(c);
	}
	if (i == 0)
	    return;
	int tmp = Integer.parseInt(number.toString());
	if (i == len) {
	    bufsize = tmp;
	    return;
	}
	char c = b.charAt(i);
	if (c == ' ') {
	    bufsize = tmp;
	    return;
	}
	if (c == 'k' || c == 'K') {
	    bufsize = tmp;
	    bufsize <<= 10; // multiply by 1024
	}
	if (c == 'm' || c == 'M') {
	    bufsize = tmp;
	    bufsize <<= 20; // multiply by 1024*1024
	}
    }

    private void extendsDirective(String ext) {
	javaSection("extends", ext.trim());
    }

    private void sessionDirective(String s) {
	if ("false".equalsIgnoreCase(s)) {
	    session = false;
	}
    }

    private void autoflushDirective(String a) {
	if ("false".equalsIgnoreCase(a)) {
	    if (bufsize == 0) {
		jspException("Cannot set both buffer=\"none\" and autoFlush=\"false\" (JSP 1.0: 2.7.1.1)");
	    }
	    autoflush = false;
	}
    }

    private void infoDirective(String a) {
	javaSection("class", "\n// Servlet info directive.\n  public String getServletInfo() {\n    return \"" +
		    a + "\";\n  }\n");
    }

    private void errorpageDirective(String s) {
	if (s != null && s.length() > 0)
	    errorPage = s;
    }

    /* Values are either of the form "TYPE" or "TYPE; charset=CHARSET", with an
   * optional whitespace after the ';'.
   */
    private void contentTypeDirective(String s) {
	int ind = s.lastIndexOf(';');
	String ctype = null, enc = null;
	if (ind < 0) {
	    ctype = s.trim();
	} else {
	    ctype = s.substring(0, ind).trim();
	    try {
		enc = s.substring(ind + 1).trim();
	    } catch (Exception ignore) { // out of bounds
	    }
	}
	/* put it at the beginning of service(...) */
	helper.addServiceSection(new JavaSection("code", "response.setContentType(\"" +
						 s + "\");\n"), 0);
	if (enc == null)
	    return;
	String alreadyUsing = jspc.getEncoding();
	/* If the contentType defines a charset, and we're not already
	 * using that charset, raise a weblogic.servlet.jsp.UseEncodingException
	 * If we're already using a *different* charset, puke completely...
	 */
	String[] ceq = weblogic.utils.StringUtils.split(enc, '=');
	if (ceq != null && ceq.length > 1)
	    enc = ceq[1];
	if (enc != null) {
            if (!compareCodesets(alreadyUsing, enc)) {
	        throw new UseEncodingException(enc, getLine());
            }
	}
    }

    private boolean compareCodesets(String oldenc, String newenc)
    {	
      // handle case where no encoding was originally defined.
      if (oldenc == null) {
	if (newenc == null)
          return true;
	else
          return false;
      }

      // See if they are equal.
      if (newenc.equals(oldenc))
        return true;

      // It's possible that one is a JAVA codeset name and the other is
      // an IANA codeset name. Try to convert both to JAVA names and then
      // recompare.

      WebAppServletContext ctx = jspc.getServletContext();

      CharsetMap cm;
      if (ctx == null) {
	cm = new CharsetMap(null);
      } else {
        cm = ctx.getCharsetMap();
      }
      
      String enc;

      enc = cm.getJavaCharset(newenc);
      if (enc != null) {
        newenc = enc;
      }

      enc = cm.getJavaCharset(oldenc);
      if (enc != null) {
        oldenc = enc;
      }

      //servletContext.log("prev codeset: "+oldenc+" new codeset: "+newenc);

      return newenc.equals(oldenc);

    }

    private Reader makeReader(Source s) {
	/* We assume that if they're using a charset to read the current
	 * page, they want that same charset to read the sub page.... -brown
	 */
	try {
            WebAppServletContext ctx = jspc.getServletContext();
            CharsetMap cm;
            if (ctx == null) {
              cm = new CharsetMap(null);
            } else {
              cm = ctx.getCharsetMap();
            }
	    return cm.makeI18NReader(jspc.getEncoding(), s.getInputStream());
	} catch (Exception e) {
	    jspException(e.toString());
	}
	return null;
    }

    private void buildTimeInclude(String s) throws IOException{

	if (s == null || s.length() == 0) {
	    javaSection("code", "// cannot include file '" + s + "'\n");
	    javaSection("code", "out.println(\"<!-- cannot include file '" + s +
			"', invalid path -->\");\n");
	    return;
	}

	s = s.replace(File.separatorChar, '/');

	String currentURI = jspc.getURI();
	String newuri = null;
	Source src = null;
	if (s.charAt(0) == '/') {
	    /* relative to root */
	    newuri = s;
	} else {
	    /* relative to current JSP */
	    if (currentURI.endsWith("/")) {
		newuri = currentURI + s;
	    } else {
		int ind = currentURI.lastIndexOf('/');
		String dirPart = currentURI.substring(0, ind + 1);
		newuri = dirPart + s;
	    }
	}
	src = jspc.getResourceAsSource(newuri);
	if (src == null) {
	/*
	    javaSection("code", "// cannot include file '" + s + "'\n");
	    javaSection("code", "out.println(\"<!-- cannot include file '" + s +
			"', resource not found -->\");\n");
	    return;
	*/
	//see #Issue 10338
	//the user prefers Exception in this case
	throw new IOException("cannot include file '" + s + "', resource not found");
	}
	/* read the whole file, parse it as JSP... */
	if (htmlBuf.length() > 0) htmlSection();
	recordSourceDependency(newuri, src.lastModified(), false);
	parseJspCode(makeReader(src), newuri);
    }

    void addImportSections(String imports) {
	if (imports == null)
	    return;
	StringTokenizer st = new StringTokenizer(imports, ",", false);
	while (st.hasMoreTokens()) {
	    String pkg = st.nextToken();
	    if (pkg == null)
		continue;
	    pkg = pkg.trim();
	    if (pkg.length() == 0)
		continue;
	    javaSection("import", pkg);
	}
    }

    void setHelper(PageCompileParser.Helper h) {
	helper = h;
    }

    PageCompileParser.Helper getHelper() {
	return helper;
    }

    void parse() throws ParsingException {
	long start = System.currentTimeMillis();
	try {
	    while (nextToken().getType() != JspLexer.EOF);
        } catch (TokenStreamException tse) {
          throw new ParsingException("nested TokenStreamException: " + tse);
        }
	    
	htmlSection();
      
	long end = System.currentTimeMillis();

	if(jspExtensionTags.size() != 0) {
	    StringBuffer sb = new StringBuffer("Could not complete parsing, unmatched tags: ");
	    while(jspExtensionTags.size() != 0) {
		Properties props = (Properties) jspExtensionTags.pop();
		String tag = (String) jspExtensionTags.pop();
		sb.append(tag);
		sb.append(" ");
	    }
	    throw new ParsingException(sb.toString());
	}
    }

    public JavaSection getPackageSection() {
	return helper.getPackageSection();
    }
  
    public JavaSection getExtendsSection() {
	return helper.getExtendsSection();
    }
  
    public JavaSection getMethodSection() {
	return helper.getMethodSection();
    }
  
    public JavaSection[] getImplementsSections() {
	return helper.getImplementsSections();
    }
  
    public JavaSection[] getImportSections() {
	return helper.getImportSections();
    }

    public JavaSection[] getClassSections() {
	return helper.getClassSections();
    }
  
    public Section[] getServiceSections() {
	return helper.getServiceSections();
    }

    // End weblogic.servlet.jhtmlc.PageCompileParser implementation.
    // ===================================================================

    private void htmlSection() {
	String html = htmlDequote(htmlBuf.toString());
	if (html.length() == 0) {  // don't bother if it's an empty string
	    return;                  // got tired of 100's of out.println("")'s in my servlet  -pcal
	}
	helper.addServiceSection(new HtmlSection(html));
	htmlBuf.setLength(0);
    }

    private void javaSection(String type, String text) {
	javaSection(type, text, getLine());
    }

    private void javaSection(String type, String text, int startLine) {
	JavaSection sec = new JavaSection(type, text);
	switch (sec.getType()) {
	case JavaSection.CODE:
	case JavaSection.CLASS:
	    int additionallines = 0;
	    StringBuffer current = new StringBuffer();
	    for(int i = 0; i < text.length(); i++) {
		if(text.charAt(i) == '\r') continue;
		if(text.charAt(i) == '\n') {
		    javaSection(type, current.toString(), additionallines++, startLine);
		    current = new StringBuffer();
		    continue;
		}
		current.append(text.charAt(i));
	    }
	    /* always prepend a newline '\n' to "code"
	     * scriptlets.  ScriptletScopeLexer assumes
	     * that a slash-slash comment will always
	     * be broken at the end of a scriptlet,
	     * and prepending '\n' makes this so.
	     */
	    String addCode = null;
	    if (sec.getType() == JavaSection.CODE) {
		addCode = '\n' + current.toString();
	    } else {
		addCode = current.toString();
	    }
	    javaSection(type, addCode, additionallines++, startLine);
	    break;
	default:
	    javaSection(type, text, 0, startLine);
	}
    }

    private void javaSection(String type, String text, int additionallines, int startLine) {

	if (text == null) return;

	if (htmlBuf.length() > 0) htmlSection();

	JavaSection sec = new JavaSection(type, text);

	String path = jspc.getURI();

	path = JspParser.fixPathLiteral(path);
	String ctag = "[ " + path + "; Line: " + (startLine + (stickyLine == -1 ? additionallines : 0)) + "]";
	sec.setCommentTag(ctag);


	// NOTE peter@weblogic.com 1999-Feb-11 -- this isn't the most
	// efficient way to do things -- we could let the parser figure
	// out which type it is but this fits more naturally with the
	// existing classes. We can optimize later.

	switch (sec.getType()) {
	case JavaSection.PACKAGE:
	    helper.setPackageSection(sec);
	    break;

	case JavaSection.IMPORT:
	    helper.addImportSection(sec);
	    break;

	case JavaSection.EXTENDS:
	    helper.setExtendsSection(sec);
	    break;

	case JavaSection.IMPLEMENTS:
	    helper.addImplementsSection(sec);
	    break;

	case JavaSection.CLASS:
	    helper.addClassSection(sec);
	    break;

	case JavaSection.PRINT:
	case JavaSection.CODE:
	    helper.addServiceSection(sec);
	    break;

	case JavaSection.METHOD:
	    helper.setMethodSection(sec);
	    break;

	default:
	    throw new AssertionError("Bad type: " + sec.getType());
	}
    }

    private Stack jspExtensionTags = new Stack();
    
    private int stickyLine = -1;

    public int getLine() {
	if(stickyLine == -1) {
	    return super.getLine();
	}
	return stickyLine;
    }

    public void parseJspCode(Reader jspCode) {
	parseJspCode(jspCode, -1);
    }
  
    public void parseJspCode(Reader jspCode, String uri) {
	String oldURI = jspc.getURI();
	try {
	    jspc.setURI(uri);
	    parseJspCode(jspCode, -1);
	} finally {
	    jspc.setURI(oldURI);
	}
    }
  
    public void parseJspCode(Reader jspCode, int stickyLine) {
	parseJspCode(jspCode, stickyLine, true);
    }

    static void closeReader(Reader r) {
	try {r.close();} catch (Exception ignore) {}
    }

    // Parsing
    public void parseJspCode(Reader jspCode, int stickyLine, boolean passTagLibs) {
	try {
	    JspLexer lexer = new JspLexer(jspCode);
	    /** PROPAGATE ALL NECESSARY CONTEXT TO THE CHILD **/
	    lexer.stickyLine = stickyLine;
	    lexer.setJspContext(jspc);
	    lexer.setHelper(getHelper());
	    lexer.setSaveJSP(false); // don't nest these...
	    lexer.setBeans(beans);
	    if(passTagLibs) lexer.setTagLibs(taglibs);
	    lexer.servletContext = this.servletContext;
	    lexer.servletClassLoader = this.servletClassLoader;
	    lexer.parse();
	    mergeSubLexerState(lexer);
	} catch (RuntimeException re) {
	    throw re;
	} catch(ParsingException pe) {
	    throw new RuntimeException("Could not parse embedded JSP code: " + pe);
	} finally {
	    /* we were leaking file descriptors before - brown */
	    closeReader(jspCode);
	}
    }

    /* When we parse a sub page because of an include directive
     * (<%@ include file="sub.jsp" %>), this is where we
     * suck all of the state from the sub-page into us (the
     * top-level page).  I don't really have an authoritative
     * list of what should be sucked in, the things that are
     * sucked in were decided on intuitively.  Anyone else,
     * add/remove things here as you see fit. - brown 6/20/2000
     * Note also that all of the sections (Java/Html sections)
     * are already merged.
     */
    private void mergeSubLexerState(JspLexer lexer) {
	/* We want the sub-page's error page, only if we
	 * don't already have one ourselves.
	 */
	if (errorPage == null) errorPage = lexer.errorPage;
	
    }
    private String isRequestTimeAttribute(String attribute) {
	int len = attribute.length();
	if (attribute.startsWith("<%=") &&
	    attribute.endsWith("%>") && len > 5) {
	    return attribute.substring(0, len - 2).substring(3).trim();
	}
	return null;
    }

    /** Request time attribute:
   * simply turn <%= some_arbitrary_stuff %> into some_arbitrary_stuff
   */

    protected void parseRequestTimeAttribute(String attribute) {
        if(attribute == null) {
          return;
        }
        javaSection("code", param2code(attribute) + ";\n");
    }

    /* almost same as above */
    protected String param2code(String param) {
        param = attributeDequote(param);
	String expr = isRequestTimeAttribute(param);
	if (expr != null) {
	    return "weblogic.utils.StringUtils.valueOf(" + expr + ")";
	}
	return '"' + param + '"';
    }

    private void saveParamJSP(String urlAttribute, String[][] paramStrings, String type) {
	UnsyncStringBuffer sb = new UnsyncStringBuffer();
	sb.append("<jsp:" + type + " page=\"" + urlAttribute + "\">\n");
	for (int i = 0; i < paramStrings.length; i++) {
	    sb.append("<jsp:param name=\"" + paramStrings[i][0]);
	    sb.append("\" value=\"" + paramStrings[i][1] + "\"/>\n");
	}
	sb.append("</jsp:" + type + ">\n");
	saveJSPBegin(sb.toString(), "wl_jsp_" + type);
    }
      
    private void queryParams2code(String[][] paramStrings) {
	UnsyncStringBuffer sb = new UnsyncStringBuffer();
	sb.append("String[][] __queryParams = {\n");
	for (int i = 0; i < paramStrings.length; i++) {
	    sb.append("{ ");
	    sb.append(param2code(paramStrings[i][0]));
	    sb.append(", ");
	    sb.append(param2code(paramStrings[i][1]));
	    sb.append(" }");
	    if (i < paramStrings.length - 1)
		sb.append(",");
	    sb.append("\n");
	}
	sb.append("};\n");
	javaSection("code", sb.toString());
	javaSection("code",
		    "__thePage = weblogic.utils.http.HttpParsing.makeURI(" +
		    "__thePage, __queryParams);\n");
    }
      
    private Hashtable beans = new Hashtable();

    private Hashtable sessionScopeBeans = new Hashtable();
    public void setBeans(Hashtable beans) {
	this.beans = beans;
    }

    // Beans stuff
    private void processBeanTag(Properties props, boolean empty) {
	// Section 2.13.1
	String id = props.getProperty("id");
	if (id == null) jspException("jsp:useBean tag must have an id attribute");
	if (beans.get(id) != null) jspException("You already defined a bean named: " + id);

	String scope = props.getProperty("scope", "page");
	String clazz = props.getProperty("class");
	String type = props.getProperty("type");
	if (type == null && clazz == null) jspException("jsp:useBean tag must have type and/or class");
	if (type == null) type = clazz;

	String beanName = props.getProperty("beanName");
	if (beanName == null) beanName = props.getProperty("beanname");
    
	if (beanName != null && clazz != null)
	    jspException("jsp:useBean tags cannot specify both class and beanName");

	if (getSaveJSP()) {
	    StringBuffer sb = new StringBuffer();
	    sb.append("<jsp:useBean id=\"" + id + "\" scope=\"" + scope + "\"");
	    if (clazz != null) sb.append(" class=\"" + clazz + "\"");
	    if (beanName != null) sb.append(" beanName=\"" + beanName + "\"");
	    if (type != null && type != clazz) sb.append(" type=\"" + type + "\"");
	    saveJSPBegin(sb + (empty ? "/>" : ">"), "wl_jsp_openbeantag");
	}

	id = attributeDequote(id);
	scope = attributeDequote(scope);
	type = attributeDequote(type);

        // Remember if this bean lives in the session
        if (scope.equalsIgnoreCase("session"))
            sessionScopeBeans.put(id, "session");
        else
            sessionScopeBeans.remove(id);

	// Add the declaration of the variable that will hold the bean
	javaSection("code", type + " " + id + " = (" + type + ") ");
    
	// Add the getter for the appropriate scope
	addScopeGetter(id, scope);
    
	// Check to see if it was present in the scope
	javaSection("code", "if (" + id + " == null) { // begin '" + id +
		    "' instantiation block...\n");
    
	// If it was not in the scope then we need to create the object
	if (beanName == null) {
	    if (clazz == null) {
		javaSection("code", "if (true) throw new ServletException(\"Could not find bean '" + id + "', type '" +
			    type + "' in scope\");\n");
		try {
		    Class bc = null;
		    if (servletClassLoader != null)
			bc = servletClassLoader.loadClass(type);
		    else
			bc = Class.forName(type);
		    beans.put(id, bc);
		} catch (Exception e) {
		    jspException("Could not create a bean of type: " + type + ": " + e);
		}
	    } else {
		try {
		    clazz = attributeDequote(clazz);
		    beans.put(id, Beans.instantiate(servletClassLoader, clazz));
		} catch (Exception e) {
                  // We failed to instantiate the bean -- must be missing a default
                  // constructor and is not a .ser.  This type of bean cannot be created
                  // at runtime by the useBean tag.  Lets try and load the class directly.
                  try {
                    beans.put(id, servletClassLoader.loadClass(clazz));
                  } catch(Exception e2) {
		    jspException("Could not create a bean of type: " + clazz + ": " + e + " and " + e2);
                  }
		}
		javaSection("code", "try {\n" + id + " = (" + type +
			    ") java.beans.Beans.instantiate(getClass().getClassLoader(), \"" +
			    clazz + "\");\n" +
			    "} catch (Exception _beanException) {\n" +
			    "throw new weblogic.utils.NestedRuntimeException(\"" +
			    "cannot instantiate '" + clazz + "'\", _beanException);\n}\n");
		addScopeSetter(id, scope);
	    }
	} else {
	    try {
		beanName = attributeDequote(beanName);
                String newBeanName = isRequestTimeAttribute(beanName);
                if(newBeanName == null) {
                  beanName = "\"" + beanName + "\"";
                } else {
                  beanName = newBeanName;
                }
		beans.put(id, servletClassLoader.loadClass(type));
	    } catch (Exception e) {
		jspException("Could not create bean: " + beanName + ": " + e);
	    }
	    javaSection("code", "try { " + id + " = (" + type +
                        ") java.beans.Beans.instantiate(getClass().getClassLoader(), weblogic.utils.StringUtils.valueOf(" +
			beanName + "));" + 
			"} catch(Exception _beanException) {\n" +
			"throw new weblogic.utils.NestedRuntimeException(\"" +
			"cannot instantiate '" + clazz + "'\", _beanException);\n}\n");
	    addScopeSetter(id, scope);
	}
	if (getSaveJSP()) saveJSPEnd();
    }
  
    private void addScopeGetter(String id, String scope) {
	if (scope.equalsIgnoreCase("page")) {
	    javaSection("code", "pageContext.getAttribute(\"" + id + "\");\n");
	} else
	    if (scope.equalsIgnoreCase("request")) {
		javaSection("code", "request.getAttribute(\"" + id + "\");\n");
	    } else
		if (scope.equalsIgnoreCase("session")) {
		    javaSection("code", "session.getAttribute(\"" + id + "\");\n");
		} else
		    if (scope.equalsIgnoreCase("application")) {	
			javaSection("code", "application.getAttribute(\"" + id + "\");\n");
		    } else
			jspException("jsp:useBean scope must be either page, session," +
				     " request, or application: " + scope);
    }

    private void addScopeSetter(String id, String scope) {
	if (scope.equalsIgnoreCase("page")) {
	    javaSection("code", "pageContext.setAttribute(\"" + id + "\", " + id + ");\n");
	} else
	    if (scope.equalsIgnoreCase("request")) {
		javaSection("code", "request.setAttribute(\"" + id + "\", " + id + ");\n");
	    } else
		if (scope.equalsIgnoreCase("session")) {
		    javaSection("code", "session.setAttribute(\"" + id + "\", " + id + ");\n");
		} else
		    if (scope.equalsIgnoreCase("application")) {
			javaSection("code", "application.setAttribute(\"" + id + "\", " + id + ");\n");
		    } else
			jspException("jsp:useBean scope must be either page, session, " +
				     "request, or application: " + scope);
    }

    private PropertyDescriptor getPD(BeanInfo bi, String propertyName) throws Exception {
	PropertyDescriptor[] pds = bi.getPropertyDescriptors();
	for(int i = 0; i < pds.length; i++) {
	    if (propertyName.equalsIgnoreCase(pds[i].getName())) return pds[i];
	}
	jspException("Property " + propertyName + " not found in " + bi.getBeanDescriptor().getBeanClass());
	return null;
    }

    private BeanInfo getBI(Object bean) throws Exception {
	if(bean instanceof Class) return Introspector.getBeanInfo((Class)bean, Object.class);
	return Introspector.getBeanInfo(bean.getClass(), Object.class);
    }

    private String convert(Class propertyType, String value) {
	return BeanUtils.convert(propertyType, value);
    }

    private String convertArray(Class propertyType, String size) {
	return BeanUtils.convertArray(propertyType, size);
    }

    private void addSetProperty(String id, Object bean, String propertyName) {
	addSetProperty(id, bean, propertyName, propertyName);
    }

    private void addSetProperty(String id, Object bean, String propertyName, String param) {
	try {
	    BeanInfo bi = getBI(bean);
	    PropertyDescriptor pd = getPD(bi, propertyName);
	    Class propertyType = pd.getPropertyType();
            //Debug.say("addSetProperty: id="+id + " name="+propertyName);
	    if (propertyType.isArray()) {
		javaSection("code", "{\nString[] _propertyValues = request.getParameterValues(\"" + param + "\");\n");
		javaSection("code", "if(_propertyValues != null) {\n");
		String convertedArray = convertArray(propertyType.getComponentType(), "_propertyValues.length");
		javaSection("code", convertedArray + "\n");
		javaSection("code", "for(int _propertyIterator = 0; _propertyIterator < _propertyValues.length; _propertyIterator++) {\n");
		javaSection("code", "_propertyArray[_propertyIterator] = " +
			    convert(propertyType.getComponentType(), "_propertyValues[_propertyIterator]") + ";\n");
		javaSection("code", "}\n");
		javaSection("code", id + "." +
			    pd.getWriteMethod().getName() +
			    "(_propertyArray);\n}\n}");
	    } else {
		String converted = convert(propertyType, "_propertyValue");
		if(converted != null) {
		    javaSection("code", "{\nString _propertyValue = request.getParameter(\"" + param + "\");\n");
		//CR036978 --jlee 10/20/2000
		//If the param is not set in the Request object, 
		//or if it has the value of "",
    		//the jsp:setProperty element has no effect (a noop).
		//we don't check if "" which will lead to an Exception
		if (jspc.getAttribute("setEmptyStrings") == Boolean.TRUE)
		    javaSection("code", "if (_propertyValue != null)\n");
		else
		    javaSection("code", "if (_propertyValue != null && _propertyValue.length() > 0)\n");

		javaSection("code", id + "." +
			pd.getWriteMethod().getName() +
			"(" + converted +
			");\n}\n");
		}
	    }
	} catch (JspException jspe) {
	    throw jspe;
	} catch (Exception e) {
	    jspException("Could not set property: " + propertyName + ": " + e);
	}
    }

    private void addSetPropertyValue(String id, Object bean, String propertyName, String value) {
	try {
	    BeanInfo bi = getBI(bean);
	    PropertyDescriptor pd = getPD(bi, propertyName);
	    Class propertyType = pd.getPropertyType();
	    if (!BeanUtils.isStringConvertible(propertyType)) {
		/* still let it go through if it is rtexprvalue */
		String rtvalue = isRequestTimeAttribute(value);
		if (rtvalue != null) {
		    javaSection("code", id + "." + pd.getWriteMethod().getName() + "(" + rtvalue + ");\n");
		} else {
		    jspException("Could not coerce value (JSP 1.0: 2.13.2)");
		}
		return;
	    }
	    javaSection("code", "Object _propertyValue = ");
	    parseRequestTimeAttribute(value);
	    if (propertyType.isArray()) {
		javaSection("code", "{\n" + propertyType.getComponentType().getName() +
			    "[] _propertyValues = (" + propertyType.getComponentType() + "[]) _propertyValue;\n");
		javaSection("code", "if(_propertyValues != null) {\n");
		String convertedArray = convertArray(propertyType.getComponentType(), "_propertyValues.length");
		javaSection("code", convertedArray + "\n");
		javaSection("code", "for(int _propertyIterator = 0; _propertyIterator < _propertyValues.length; _propertyIterator++) {\n");
		javaSection("code", "_propertyArray[_propertyIterator] = " +
			    convert(propertyType.getComponentType(), "_propertyValues[_propertyIterator]") + ";\n");
		javaSection("code", "}\n");
		javaSection("code", id + "." +
			    pd.getWriteMethod().getName() +
			    "(_propertyArray);\n}\n}");
	    } else {
		String converted = convert(propertyType, "_propertyValue");
		if(converted != null) {
		    javaSection("code", "if (_propertyValue != null && !_propertyValue.equals(\"\"))\n");
		    javaSection("code", id + "." + pd.getWriteMethod().getName() + "(" +
				converted +");\n");
		} else {
		    jspException("Could not coerce value (JSP 1.0: 2.13.2)");
		}
	    }
	} catch (RuntimeException re) {
	    throw re;
	} catch(Exception e) {
	    jspException("Could not set property: " + propertyName + ": " + e);
	}
    }

    private void addSetAllProperties(String id, Object bean) {
	try {
	    BeanInfo bi = getBI(bean);
	    PropertyDescriptor[] pds = bi.getPropertyDescriptors();
	    for(int i = 0; i < pds.length; i++) {
		PropertyDescriptor pd = pds[i];
		String name = pd.getName();
		Class propertyType = pd.getPropertyType();
		if (propertyType == null) continue;
		if (pd.getWriteMethod() != null) {
		    if(propertyType.isArray()) {
			try {
			    javaSection("code", "{\nString[] _propertyValues = request.getParameterValues(\"" + name + "\");\n");
			    javaSection("code", "if(_propertyValues != null) {\n");
			    String convertedArray = convertArray(propertyType.getComponentType(), "_propertyValues.length");
			    javaSection("code", convertedArray + "\n");
			    javaSection("code", "for(int _propertyIterator = 0; _propertyIterator < _propertyValues.length; _propertyIterator++) {\n");
			    javaSection("code", "_propertyArray[_propertyIterator] = " +
					convert(propertyType.getComponentType(), "_propertyValues[_propertyIterator]") + ";\n");
			    javaSection("code", "}\n");
			    javaSection("code", id + "." +
					pd.getWriteMethod().getName() +
					"(_propertyArray);\n}\n}");
			} catch (Error error) {
			    continue;
			}
		    } else {
			try {
			    String converted = convert(propertyType, "_propertyValue");
			    javaSection("code", "{\nString _propertyValue = request.getParameter(\"" + name + "\");\n");
			    javaSection("code", "if (_propertyValue != null && !_propertyValue.equals(\"\"))\n");
			    javaSection("code", id + "." + pd.getWriteMethod().getName() + "(" + converted + ");\n}\n");
			} catch (Error error) {
			    continue;
			}
		    }
		}
	    }
	} catch (RuntimeException re) {
	    throw re;
	} catch (Exception e) {
	    e.printStackTrace();
	    jspException("Could not set properties: " + e);
	}
    }

    private void addGetProperty(String id, Object bean, String propertyName) {
	try {
	    BeanInfo bi = getBI(bean);
	    PropertyDescriptor pd = getPD(bi, propertyName);
	    Class propertyType = pd.getPropertyType();
	    javaSection("print", id + "." + pd.getReadMethod().getName() + "()");
	} catch (JspException jspe) {
	    throw jspe;
	} catch (Exception e) {
	    jspException("Could not set property: " + propertyName + ": " + e);
	}
    }
public JspLexer(InputStream in) {
	this(new ByteBuffer(in));
}
public JspLexer(Reader in) {
	this(new CharBuffer(in));
}
public JspLexer(InputBuffer ib) {
	this(new LexerSharedInputState(ib));
}
public JspLexer(LexerSharedInputState state) {
	super(state);
	literals = new Hashtable();
caseSensitiveLiterals = true;
setCaseSensitive(true);
}

public Token nextToken() throws TokenStreamException {
	Token theRetToken=null;
tryAgain:
	for (;;) {
		Token _token = null;
		int _ttype = Token.INVALID_TYPE;
		setCommitToPath(false);
		int _m;
		_m = mark();
		resetText();
		try {   // for char stream error handling
			try {   // for lexical error handling
				if ((LA(1)=='<')) {
					mTOKEN(true);
					theRetToken=_returnToken;
				}
				else {
					if (LA(1)==EOF_CHAR) {uponEOF(); _returnToken = makeToken(Token.EOF_TYPE);}
				else {
					commit();
					try {mHTML(false);}
					catch(RecognitionException e) {
						// catastrophic failure
						reportError(e);
						consume();
					}
					continue tryAgain;
				}
				}
				
				commit();
				if ( _returnToken==null ) continue tryAgain; // found SKIP token
				_ttype = _returnToken.getType();
				_ttype = testLiteralsTable(_ttype);
				_returnToken.setType(_ttype);
				return _returnToken;
			}
			catch (RecognitionException e) {
				if ( !getCommitToPath() ) {
					rewind(_m);
					resetText();
					try {mHTML(false);}
					catch(RecognitionException ee) {
						// horrendous failure: error in filter rule
						reportError(ee);
						consume();
					}
					continue tryAgain;
				}
				throw new TokenStreamRecognitionException(e);
			}
		}
		catch (CharStreamException cse) {
			if ( cse instanceof CharStreamIOException ) {
				throw new TokenStreamIOException(((CharStreamIOException)cse).io);
			}
			else {
				throw new TokenStreamException(cse.getMessage());
			}
		}
	}
}

	public final void mTOKEN(boolean _createToken) throws RecognitionException, CharStreamException, TokenStreamException {
		int _ttype; Token _token=null; int _begin=text.length();
		_ttype = TOKEN;
		int _saveIndex;
		
		boolean synPredMatched3 = false;
		if (((LA(1)=='<') && (LA(2)=='j') && (LA(3)=='s'))) {
			int _m3 = mark();
			synPredMatched3 = true;
			inputState.guessing++;
			try {
				{
				match("<jsp:");
				}
			}
			catch (RecognitionException pe) {
				synPredMatched3 = false;
			}
			rewind(_m3);
			inputState.guessing--;
		}
		if ( synPredMatched3 ) {
			mXML_THING(false);
		}
		else {
			boolean synPredMatched5 = false;
			if (((LA(1)=='<') && (LA(2)=='M') && (LA(3)=='M'))) {
				int _m5 = mark();
				synPredMatched5 = true;
				inputState.guessing++;
				try {
					{
					match("<MM:");
					}
				}
				catch (RecognitionException pe) {
					synPredMatched5 = false;
				}
				rewind(_m5);
				inputState.guessing--;
			}
			if ( synPredMatched5 ) {
				mMM_THING(false);
			}
			else {
				boolean synPredMatched7 = false;
				if (((LA(1)=='<') && (LA(2)=='/') && (LA(3)=='j'))) {
					int _m7 = mark();
					synPredMatched7 = true;
					inputState.guessing++;
					try {
						{
						match("</jsp:");
						}
					}
					catch (RecognitionException pe) {
						synPredMatched7 = false;
					}
					rewind(_m7);
					inputState.guessing--;
				}
				if ( synPredMatched7 ) {
					mXML_JSP_CLOSE(false);
				}
				else if ((LA(1)=='<') && (LA(2)=='%') && (LA(3)=='-')) {
					mJSP_COMMENT(false);
				}
				else if ((LA(1)=='<') && (LA(2)=='%') && (_tokenSet_0.member(LA(3)))) {
					mSTANDARD_THING(false);
				}
				else if ((LA(1)=='<') && (_tokenSet_1.member(LA(2))) && (_tokenSet_2.member(LA(3)))) {
					mOPEN_EXTENSION_TAG(false);
				}
				else if ((LA(1)=='<') && (LA(2)=='/') && (_tokenSet_1.member(LA(3)))) {
					mCLOSE_EXTENSION_TAG(false);
				}
				else {
					throw new NoViableAltForCharException((char)LA(1), getFilename(), getLine());
				}
				}}
				if ( _createToken && _token==null && _ttype!=Token.SKIP ) {
					_token = makeToken(_ttype);
					_token.setText(new String(text.getBuffer(), _begin, text.length()-_begin));
				}
				_returnToken = _token;
			}
			
	protected final void mXML_THING(boolean _createToken) throws RecognitionException, CharStreamException, TokenStreamException {
		int _ttype; Token _token=null; int _begin=text.length();
		_ttype = XML_THING;
		int _saveIndex;
		
		match("<jsp:");
		{
		switch ( LA(1)) {
		case 'e':
		{
			mXML_EXPRESSION(false);
			break;
		}
		case 'i':
		{
			mXML_INCLUDE(false);
			break;
		}
		case 'f':
		{
			mXML_FORWARD(false);
			break;
		}
		case 'u':
		{
			mXML_OPEN_USEBEAN(false);
			break;
		}
		case 'g':
		{
			mXML_GET_PROPERTY(false);
			break;
		}
		case 'p':
		{
			mXML_PLUGIN(false);
			break;
		}
		default:
			if ((LA(1)=='d') && (LA(2)=='i')) {
				mXML_DIRECTIVE(false);
			}
			else if ((LA(1)=='d') && (LA(2)=='e')) {
				mXML_DECLARATION(false);
			}
			else if ((LA(1)=='s') && (LA(2)=='c')) {
				mXML_SCRIPT(false);
			}
			else if ((LA(1)=='s') && (LA(2)=='e')) {
				mXML_SET_PROPERTY(false);
			}
		else {
			throw new NoViableAltForCharException((char)LA(1), getFilename(), getLine());
		}
		}
		}
		if ( _createToken && _token==null && _ttype!=Token.SKIP ) {
			_token = makeToken(_ttype);
			_token.setText(new String(text.getBuffer(), _begin, text.length()-_begin));
		}
		_returnToken = _token;
	}
	
	protected final void mMM_THING(boolean _createToken) throws RecognitionException, CharStreamException, TokenStreamException {
		int _ttype; Token _token=null; int _begin=text.length();
		_ttype = MM_THING;
		int _saveIndex;
		
		match("<MM:");
		{
		switch ( LA(1)) {
		case 'B':
		{
			mMM_LOCK(false);
			break;
		}
		case 'E':
		{
			mMM_UNLOCK(false);
			break;
		}
		default:
		{
			throw new NoViableAltForCharException((char)LA(1), getFilename(), getLine());
		}
		}
		}
		if ( _createToken && _token==null && _ttype!=Token.SKIP ) {
			_token = makeToken(_ttype);
			_token.setText(new String(text.getBuffer(), _begin, text.length()-_begin));
		}
		_returnToken = _token;
	}
	
	protected final void mXML_JSP_CLOSE(boolean _createToken) throws RecognitionException, CharStreamException, TokenStreamException {
		int _ttype; Token _token=null; int _begin=text.length();
		_ttype = XML_JSP_CLOSE;
		int _saveIndex;
		
		match("</jsp:");
		mXML_CLOSE_USEBEAN(false);
		if ( _createToken && _token==null && _ttype!=Token.SKIP ) {
			_token = makeToken(_ttype);
			_token.setText(new String(text.getBuffer(), _begin, text.length()-_begin));
		}
		_returnToken = _token;
	}
	
	protected final void mJSP_COMMENT(boolean _createToken) throws RecognitionException, CharStreamException, TokenStreamException {
		int _ttype; Token _token=null; int _begin=text.length();
		_ttype = JSP_COMMENT;
		int _saveIndex;
		Token c=null;
		
		match("<%--");
		mJSP_COMMENT_CONTENT(true);
		c=_returnToken;
		match("--%>");
		if ( inputState.guessing==0 ) {
			
			if (debug) p("matched JSP_COMMENT");
			if (getSaveJSP()) {
				saveJSPBegin("<%--" + c.getText() + "--%>", "wl_jsp_comment");
				saveJSPEnd();
			}
			
		}
		if ( _createToken && _token==null && _ttype!=Token.SKIP ) {
			_token = makeToken(_ttype);
			_token.setText(new String(text.getBuffer(), _begin, text.length()-_begin));
		}
		_returnToken = _token;
	}
	
	protected final void mSTANDARD_THING(boolean _createToken) throws RecognitionException, CharStreamException, TokenStreamException {
		int _ttype; Token _token=null; int _begin=text.length();
		_ttype = STANDARD_THING;
		int _saveIndex;
		
		if ((LA(1)=='<') && (LA(2)=='%') && (LA(3)=='@')) {
			mDIRECTIVE(false);
		}
		else if ((LA(1)=='<') && (LA(2)=='%') && (LA(3)=='!')) {
			mDECLARATION(false);
		}
		else if ((LA(1)=='<') && (LA(2)=='%') && (_tokenSet_3.member(LA(3)))) {
			mSCRIPT(false);
		}
		else if ((LA(1)=='<') && (LA(2)=='%') && (LA(3)=='=')) {
			mEXPRESSION(false);
		}
		else {
			throw new NoViableAltForCharException((char)LA(1), getFilename(), getLine());
		}
		
		if ( _createToken && _token==null && _ttype!=Token.SKIP ) {
			_token = makeToken(_ttype);
			_token.setText(new String(text.getBuffer(), _begin, text.length()-_begin));
		}
		_returnToken = _token;
	}
	
	protected final void mOPEN_EXTENSION_TAG(boolean _createToken) throws RecognitionException, CharStreamException, TokenStreamException {
		int _ttype; Token _token=null; int _begin=text.length();
		_ttype = OPEN_EXTENSION_TAG;
		int _saveIndex;
		Token tagLibName=null;
		Token tagName=null;
		
		Properties props = new Properties();
		
		
		match("<");
		mWORD(true);
		tagLibName=_returnToken;
		match(":");
		mWORD(true);
		tagName=_returnToken;
		{
		switch ( LA(1)) {
		case '\t':  case '\n':  case '\r':  case ' ':
		{
			{
			int _cnt45=0;
			_loop45:
			do {
				if ((_tokenSet_4.member(LA(1)))) {
					mWS(false);
				}
				else {
					if ( _cnt45>=1 ) { break _loop45; } else {throw new NoViableAltForCharException((char)LA(1), getFilename(), getLine());}
				}
				
				_cnt45++;
			} while (true);
			}
			{
			_loop47:
			do {
				if ((_tokenSet_1.member(LA(1)))) {
					mXML_ATTRIBUTES(false,props);
				}
				else {
					break _loop47;
				}
				
			} while (true);
			}
			break;
		}
		case '/':  case '>':
		{
			match("");
			break;
		}
		default:
		{
			throw new NoViableAltForCharException((char)LA(1), getFilename(), getLine());
		}
		}
		}
		{
		switch ( LA(1)) {
		case '>':
		{
			match(">");
			if ( inputState.guessing==0 ) {
				
				if (debug) p("matched OPEN_EXTENSION_TAG \"" + tagLibName.getText() +
						 ":" + tagName.getText() + "\" (*with* body): " + props);
				try {
					if (htmlBuf.length() > 0) htmlSection();
					TagLib tagLib = (TagLib) taglibs.get(tagLibName.getText());
					if (tagLib == null) {
				htmlBuf.append("<" + tagLibName.getText() + ":" + tagName.getText());
				Enumeration attrs = props.keys();
				while(attrs.hasMoreElements()) {
				String key = (String) attrs.nextElement();
				String value = props.getProperty(key);
				htmlBuf.append(" " + key + "=");
				if(value.indexOf("\"") == -1) {
				htmlBuf.append("\"" + value + "\"");
				} else {
				htmlBuf.append("'" + value + "'");
				}
				}
				htmlBuf.append(">");
				return;
				}
					/* FIXME: Who uses this attribute?  can we remove it? -brown */
				jspc.setAttribute("taglibPrefix", tagLibName.getText());
					String tag = tagName.getText();
					Properties dequoted = new Properties();
					Enumeration keys = props.keys();
					while(keys.hasMoreElements()) {
					    String key = (String) keys.nextElement();
					    dequoted.put(key, attributeDequote(props.getProperty(key)));
					}
					jspc.setLine(getLine());
					String jspCode = tagLib.processStartTag(tag, props, jspc);
					if (getSaveJSP()) {
					    StringBuffer sb = new StringBuffer();
					    sb.append("<" + tagLibName.getText() + ":" + tag);
					    Enumeration attributes = props.keys();
					    while(attributes.hasMoreElements()) {
						String key = (String) attributes.nextElement();
						String value = props.getProperty(key);
						sb.append(" "  + key + "=\"" + value + "\"");
					    }
					    sb.append(">");
					    saveJSPBegin(sb.toString(), "wl_jsp_opentagextension");
					}
					parseJspCode(new StringReader(jspCode), getLine(), false);
					if (getSaveJSP()) saveJSPEnd();
					jspExtensionTags.push(tag);
					jspExtensionTags.push(props);
				} catch (RuntimeException re) {
					throw re;
				} catch(Exception e) {
					jspException(e.toString());
				}
				
			}
			break;
		}
		case '/':
		{
			match("/>");
			if ( inputState.guessing==0 ) {
				
				if (debug) p("matched OPEN_EXTENSION_TAG (*without* body): " + props);
				try {
					if (htmlBuf.length() > 0) htmlSection();
					TagLib tagLib = (TagLib) taglibs.get(tagLibName.getText());
					if (tagLib == null) {
				htmlBuf.append("<" + tagLibName.getText() + ":" + tagName.getText());
				Enumeration attrs = props.keys();
				while(attrs.hasMoreElements()) {
				String key = (String) attrs.nextElement();
				String value = props.getProperty(key);
				htmlBuf.append(" " + key + "=");
				if(value.indexOf("\"") == -1) {
				htmlBuf.append("\"" + value + "\"");
				} else {
				htmlBuf.append("'" + value + "'");
				}
				}
				htmlBuf.append("/>");
				return;
				}
					String tag = tagName.getText();
					Properties dequoted = new Properties();
					Enumeration keys = props.keys();
					while(keys.hasMoreElements()) {
					    String key = (String) keys.nextElement();
					    dequoted.put(key, attributeDequote(props.getProperty(key)));
					}
					jspc.setLine(getLine());
					String jspCode = tagLib.processTag(tag, dequoted, jspc);
					if (getSaveJSP()) {
					    StringBuffer sb = new StringBuffer();
					    sb.append("<" + tagLibName.getText() + ":" + tag);
					    Enumeration attributes = props.keys();
					    while(attributes.hasMoreElements()) {
						String key = (String) attributes.nextElement();
						String value = props.getProperty(key);
						sb.append(" "  + key + "=\"" + value + "\"");
					    }
					    sb.append("/>");
					    saveJSPBegin(sb.toString(), "wl_jsp_opentagextension");
					}
					parseJspCode(new StringReader(jspCode), getLine(), false);
					if (getSaveJSP()) saveJSPEnd();
				} catch (RuntimeException re) {
					throw re;
				} catch (Exception e) {
					jspException(e.toString());
				}
				
			}
			break;
		}
		default:
		{
			throw new NoViableAltForCharException((char)LA(1), getFilename(), getLine());
		}
		}
		}
		if ( _createToken && _token==null && _ttype!=Token.SKIP ) {
			_token = makeToken(_ttype);
			_token.setText(new String(text.getBuffer(), _begin, text.length()-_begin));
		}
		_returnToken = _token;
	}
	
	protected final void mCLOSE_EXTENSION_TAG(boolean _createToken) throws RecognitionException, CharStreamException, TokenStreamException {
		int _ttype; Token _token=null; int _begin=text.length();
		_ttype = CLOSE_EXTENSION_TAG;
		int _saveIndex;
		Token tagLibName=null;
		Token tagName=null;
		
		match("</");
		mWORD(true);
		tagLibName=_returnToken;
		match(":");
		mWORD(true);
		tagName=_returnToken;
		match(">");
		if ( inputState.guessing==0 ) {
			
			try {
			if (debug) p("matched CLOSE_EXTENSION_TAG: " + tagLibName.getText() + ":" + tagName.getText());
			// take off stack and check tag name
			if (htmlBuf.length() > 0) htmlSection();
			TagLib tagLib = (TagLib) taglibs.get(tagLibName.getText());
			if (tagLib == null) {
			htmlBuf.append("</" + tagLibName.getText() + ":" + tagName.getText() + ">");
			return;
			}
			if (jspExtensionTags.isEmpty()) {
			jspException("no corresponding open tag for tag extension close: </" + tagLibName.getText() +
				":" + tagName.getText() + ">");
			}
			Properties props = (Properties) jspExtensionTags.pop();
			String tag = (String) jspExtensionTags.pop();
			if(!tag.equals(tagName.getText())) {
			jspException("Non-matching extension tags");
			} else {
			jspc.setLine(getLine());
			String jspCode = tagLib.processEndTag(tag, props, jspc);
			if (getSaveJSP()) {
			saveJSPBegin("</" + tagLibName.getText() + ":" + tag + ">", "wl_jsp_closeextensiontag");
			}
			parseJspCode(new StringReader(jspCode), getLine(), false);
			if (getSaveJSP()) saveJSPEnd();
			}
			} catch (RuntimeException re) {
			throw re;
			} catch(Exception e) {
			jspException(e.getMessage());
			}
			
		}
		if ( _createToken && _token==null && _ttype!=Token.SKIP ) {
			_token = makeToken(_ttype);
			_token.setText(new String(text.getBuffer(), _begin, text.length()-_begin));
		}
		_returnToken = _token;
	}
	
	protected final void mXML_CLOSE_USEBEAN(boolean _createToken) throws RecognitionException, CharStreamException, TokenStreamException {
		int _ttype; Token _token=null; int _begin=text.length();
		_ttype = XML_CLOSE_USEBEAN;
		int _saveIndex;
		
		match("use");
		{
		switch ( LA(1)) {
		case 'B':
		{
			match('B');
			break;
		}
		case 'b':
		{
			match('b');
			break;
		}
		default:
		{
			throw new NoViableAltForCharException((char)LA(1), getFilename(), getLine());
		}
		}
		}
		match("ean>");
		if ( inputState.guessing==0 ) {
			
			if (debug) p("matched XML_CLOSE_USEBEAN");
			javaSection("code", "} // end bean instantiation block...\n");
			if (getSaveJSP()) {
				saveJSPBegin("</jsp:useBean>", "wl_jsp_closeusebean");
				saveJSPEnd();
			}
			
		}
		if ( _createToken && _token==null && _ttype!=Token.SKIP ) {
			_token = makeToken(_ttype);
			_token.setText(new String(text.getBuffer(), _begin, text.length()-_begin));
		}
		_returnToken = _token;
	}
	
	protected final void mMM_LOCK(boolean _createToken) throws RecognitionException, CharStreamException, TokenStreamException {
		int _ttype; Token _token=null; int _begin=text.length();
		_ttype = MM_LOCK;
		int _saveIndex;
		
		Properties props = new Properties();
		
		
		match("BeginLock");
		{
		int _cnt15=0;
		_loop15:
		do {
			if ((_tokenSet_4.member(LA(1)))) {
				mWS(false);
			}
			else {
				if ( _cnt15>=1 ) { break _loop15; } else {throw new NoViableAltForCharException((char)LA(1), getFilename(), getLine());}
			}
			
			_cnt15++;
		} while (true);
		}
		{
		_loop17:
		do {
			if ((_tokenSet_1.member(LA(1)))) {
				mXML_ATTRIBUTES(false,props);
			}
			else {
				break _loop17;
			}
			
		} while (true);
		}
		match(">");
		if ( inputState.guessing==0 ) {
			
			if (htmlBuf.length() > 0) { htmlSection(); }
			//Debug.say("got MM props: " + props);
			String orig = props.getProperty("orig");
			String type = props.getProperty("type");
			if (orig != null && type != null) {
				orig = decodeMM(orig);
			//Debug.say("got code ###" + orig + "###");
				saveJSPBegin(orig, type);
				parseJspCode(new StringReader(orig), getLine());
				saveJSPEnd();
			} else {
				/* REMIND: what to do??? */
				javaSection("code", "out.println(\"<!-- SaveJSP error: type='" + type +
					    "' code='" + orig + "' -->");
			}
			
		}
		if ( _createToken && _token==null && _ttype!=Token.SKIP ) {
			_token = makeToken(_ttype);
			_token.setText(new String(text.getBuffer(), _begin, text.length()-_begin));
		}
		_returnToken = _token;
	}
	
	protected final void mMM_UNLOCK(boolean _createToken) throws RecognitionException, CharStreamException, TokenStreamException {
		int _ttype; Token _token=null; int _begin=text.length();
		_ttype = MM_UNLOCK;
		int _saveIndex;
		
		match("EndLock>");
		if ( inputState.guessing==0 ) {
			
			/* simply consume any html output ... */
			htmlBuf.setLength(0);
			
		}
		if ( _createToken && _token==null && _ttype!=Token.SKIP ) {
			_token = makeToken(_ttype);
			_token.setText(new String(text.getBuffer(), _begin, text.length()-_begin));
		}
		_returnToken = _token;
	}
	
	protected final void mXML_DIRECTIVE(boolean _createToken) throws RecognitionException, CharStreamException, TokenStreamException {
		int _ttype; Token _token=null; int _begin=text.length();
		_ttype = XML_DIRECTIVE;
		int _saveIndex;
		Token attVal=null;
		
		match("directive.");
		{
		switch ( LA(1)) {
		case 'p':
		{
			match("page");
			{
			int _cnt137=0;
			_loop137:
			do {
				if ((_tokenSet_4.member(LA(1)))) {
					mWS(false);
				}
				else {
					if ( _cnt137>=1 ) { break _loop137; } else {throw new NoViableAltForCharException((char)LA(1), getFilename(), getLine());}
				}
				
				_cnt137++;
			} while (true);
			}
			mPAGE_DIRECTIVE_BODY(false,true);
			match("/>");
			if ( inputState.guessing==0 ) {
				
				if (debug) p("matched directive.page");
				
			}
			break;
		}
		case 'i':
		{
			match("include");
			{
			int _cnt139=0;
			_loop139:
			do {
				if ((_tokenSet_4.member(LA(1)))) {
					mWS(false);
				}
				else {
					if ( _cnt139>=1 ) { break _loop139; } else {throw new NoViableAltForCharException((char)LA(1), getFilename(), getLine());}
				}
				
				_cnt139++;
			} while (true);
			}
			match("file");
			mWSEQ(false);
			mSTRING(true);
			attVal=_returnToken;
			{
			_loop141:
			do {
				if ((_tokenSet_4.member(LA(1)))) {
					mWS(false);
				}
				else {
					break _loop141;
				}
				
			} while (true);
			}
			match("/>");
			if ( inputState.guessing==0 ) {
				
						    if (debug) p("matched directive.include");
						    String attribute = attributeDequote(attVal.getText());
						    if (getSaveJSP())
							saveJSPBegin("<jsp:directive.include file=\"" +
								     attVal.getText() + "\"/>\n",
								     "wl_jsp_directive_include");
				
				try {
				buildTimeInclude(attribute);
				} catch(IOException ioe) {
				throw new CharStreamException("Could not include " + attribute);
				}
				
						    if (getSaveJSP())
							saveJSPEnd();
						
			}
			break;
		}
		default:
		{
			throw new NoViableAltForCharException((char)LA(1), getFilename(), getLine());
		}
		}
		}
		if ( _createToken && _token==null && _ttype!=Token.SKIP ) {
			_token = makeToken(_ttype);
			_token.setText(new String(text.getBuffer(), _begin, text.length()-_begin));
		}
		_returnToken = _token;
	}
	
	protected final void mXML_DECLARATION(boolean _createToken) throws RecognitionException, CharStreamException, TokenStreamException {
		int _ttype; Token _token=null; int _begin=text.length();
		_ttype = XML_DECLARATION;
		int _saveIndex;
		Token c=null;
		
		match("declaration>");
		mXML_CONTENT(true);
		c=_returnToken;
		match("</jsp:declaration>");
		if ( inputState.guessing==0 ) {
			
			if (getSaveJSP())
			saveJSPBegin("<jsp:declaration> " + c.getText() + " </jsp:declaration>", "wl_jsp_decl");
			javaSection("class", c.getText());
			if (getSaveJSP())
			saveJSPEnd();
			
		}
		if ( _createToken && _token==null && _ttype!=Token.SKIP ) {
			_token = makeToken(_ttype);
			_token.setText(new String(text.getBuffer(), _begin, text.length()-_begin));
		}
		_returnToken = _token;
	}
	
	protected final void mXML_SCRIPT(boolean _createToken) throws RecognitionException, CharStreamException, TokenStreamException {
		int _ttype; Token _token=null; int _begin=text.length();
		_ttype = XML_SCRIPT;
		int _saveIndex;
		Token c=null;
		
		int startLine = getLine();
		
		
		match("scriptlet>");
		mXML_CONTENT(true);
		c=_returnToken;
		match("</jsp:scriptlet>");
		if ( inputState.guessing==0 ) {
			
			/* our generated tag code comes as a scriptlet,
			* don't parse that, we know it balances braces
			* correctly.
			*/
			String text = c.getText();
			if (!text.startsWith(StandardTagLib.WL_GENERATED_BEGIN)) {
				ScriptletScopeLexer ssl = new ScriptletScopeLexer(new StringReader(text));
				int line = getLine();
				if (debug) p("parsing scriptlet ending at line#" + line +
					     " for scope changes");
				/* backup lineno to beginning of scriptlet */
				int len = text.length();
				for (int i = 0; i < len; i++) if (text.charAt(i) == '\n') line--;
				ssl.parse(jspc, line);
			}
			
			if (getSaveJSP())
			saveJSPBegin("<jsp:scriptlet> " + text + " </jsp:scriptlet>", "wl_jsp_scriptlet");
			javaSection("code", text, startLine);
			if (getSaveJSP())
			saveJSPEnd();
			
			
			
		}
		if ( _createToken && _token==null && _ttype!=Token.SKIP ) {
			_token = makeToken(_ttype);
			_token.setText(new String(text.getBuffer(), _begin, text.length()-_begin));
		}
		_returnToken = _token;
	}
	
	protected final void mXML_EXPRESSION(boolean _createToken) throws RecognitionException, CharStreamException, TokenStreamException {
		int _ttype; Token _token=null; int _begin=text.length();
		_ttype = XML_EXPRESSION;
		int _saveIndex;
		Token c=null;
		
		int startLine = getLine();
		
		
		match("expression>");
		mXML_CONTENT(true);
		c=_returnToken;
		match("</jsp:expression>");
		if ( inputState.guessing==0 ) {
			
			if (debug) p("matched XML_EXPRESSION");
			if (getSaveJSP())
			saveJSPBegin("<jsp:expression> " + c.getText() + " </jsp:expression>",
					 "wl_jsp_expression");
			javaSection("print", c.getText(), startLine);
			if (getSaveJSP())
			saveJSPEnd();
			
		}
		if ( _createToken && _token==null && _ttype!=Token.SKIP ) {
			_token = makeToken(_ttype);
			_token.setText(new String(text.getBuffer(), _begin, text.length()-_begin));
		}
		_returnToken = _token;
	}
	
/** <jsp:include page="/blah" flush="true|false"/>

/*** <jsp:include page="some/relative/URL"/> ***/
	protected final void mXML_INCLUDE(boolean _createToken) throws RecognitionException, CharStreamException, TokenStreamException {
		int _ttype; Token _token=null; int _begin=text.length();
		_ttype = XML_INCLUDE;
		int _saveIndex;
		Token url=null;
		Token flushBool=null;
		
		Vector params = new Vector();
		
		
		match("include");
		{
		int _cnt153=0;
		_loop153:
		do {
			if ((_tokenSet_4.member(LA(1)))) {
				mWS(false);
			}
			else {
				if ( _cnt153>=1 ) { break _loop153; } else {throw new NoViableAltForCharException((char)LA(1), getFilename(), getLine());}
			}
			
			_cnt153++;
		} while (true);
		}
		match("page");
		mWSEQ(false);
		mSTRING(true);
		url=_returnToken;
		{
		_loop155:
		do {
			if ((_tokenSet_4.member(LA(1))) && (_tokenSet_5.member(LA(2))) && (_tokenSet_6.member(LA(3)))) {
				mWS(false);
			}
			else {
				break _loop155;
			}
			
		} while (true);
		}
		{
		switch ( LA(1)) {
		case 'f':
		{
			match("flush");
			mWSEQ(false);
			mSTRING(true);
			flushBool=_returnToken;
			break;
		}
		case '\t':  case '\n':  case '\r':  case ' ':
		case '/':  case '>':
		{
			break;
		}
		default:
		{
			throw new NoViableAltForCharException((char)LA(1), getFilename(), getLine());
		}
		}
		}
		{
		_loop158:
		do {
			if ((_tokenSet_4.member(LA(1)))) {
				mWS(false);
			}
			else {
				break _loop158;
			}
			
		} while (true);
		}
		{
		switch ( LA(1)) {
		case '/':
		{
			match("/>");
			if ( inputState.guessing==0 ) {
				if (debug) p("matched empty include tag");
			}
			break;
		}
		case '>':
		{
			match(">");
			{
			_loop161:
			do {
				if ((_tokenSet_4.member(LA(1)))) {
					mWS(false);
				}
				else {
					break _loop161;
				}
				
			} while (true);
			}
			{
			_loop163:
			do {
				if ((LA(1)=='<') && (LA(2)=='j')) {
					mXML_PARAM(false,params);
				}
				else {
					break _loop163;
				}
				
			} while (true);
			}
			match("</jsp:include>");
			break;
		}
		default:
		{
			throw new NoViableAltForCharException((char)LA(1), getFilename(), getLine());
		}
		}
		}
		if ( inputState.guessing==0 ) {
			
			String urlAttribute = attributeDequote(url.getText());
			String[][] paramStrings = null;
			if (params.size() > 0){
				paramStrings = vector2array(params);
			}
			if (getSaveJSP()) {
				if (paramStrings == null) {
				    saveJSPBegin("<jsp:include page=\"" + urlAttribute + "\"/>", "wl_jsp_include");
				} else {
				    saveParamJSP(urlAttribute, paramStrings, "include");
				}
			}
			
			javaSection("code", "{ /* include block for '" + urlAttribute + "' */\n");
			javaSection("code", "  String __thePage = ");
			parseRequestTimeAttribute(urlAttribute);
			if (paramStrings != null)
				queryParams2code(paramStrings);
			javaSection("code", "pageContext.include(__thePage);\n");
			if (flushBool != null && "true".equalsIgnoreCase(flushBool.getText()))
				javaSection("code", "out.flush();\n");
			javaSection("code", "} /* end include block for '" + urlAttribute + "' */\n");
			if (getSaveJSP())
				saveJSPEnd();
			
		}
		if ( _createToken && _token==null && _ttype!=Token.SKIP ) {
			_token = makeToken(_ttype);
			_token.setText(new String(text.getBuffer(), _begin, text.length()-_begin));
		}
		_returnToken = _token;
	}
	
/** <jsp:forward page="some/url"/>
 */
	protected final void mXML_FORWARD(boolean _createToken) throws RecognitionException, CharStreamException, TokenStreamException {
		int _ttype; Token _token=null; int _begin=text.length();
		_ttype = XML_FORWARD;
		int _saveIndex;
		Token url=null;
		
		Vector params = new Vector();
		
		
		match("forward");
		{
		int _cnt166=0;
		_loop166:
		do {
			if ((_tokenSet_4.member(LA(1)))) {
				mWS(false);
			}
			else {
				if ( _cnt166>=1 ) { break _loop166; } else {throw new NoViableAltForCharException((char)LA(1), getFilename(), getLine());}
			}
			
			_cnt166++;
		} while (true);
		}
		match("page");
		mWSEQ(false);
		mSTRING(true);
		url=_returnToken;
		{
		_loop168:
		do {
			if ((_tokenSet_4.member(LA(1)))) {
				mWS(false);
			}
			else {
				break _loop168;
			}
			
		} while (true);
		}
		{
		switch ( LA(1)) {
		case '/':
		{
			match("/>");
			if ( inputState.guessing==0 ) {
				if (debug) p("matched empty forward tag");
			}
			break;
		}
		case '>':
		{
			match(">");
			{
			_loop171:
			do {
				if ((_tokenSet_4.member(LA(1)))) {
					mWS(false);
				}
				else {
					break _loop171;
				}
				
			} while (true);
			}
			{
			_loop173:
			do {
				if ((LA(1)=='<') && (LA(2)=='j')) {
					mXML_PARAM(false,params);
				}
				else {
					break _loop173;
				}
				
			} while (true);
			}
			match("</jsp:forward>");
			if ( inputState.guessing==0 ) {
				if (debug) p("matched body forward tag: " + params);
			}
			break;
		}
		default:
		{
			throw new NoViableAltForCharException((char)LA(1), getFilename(), getLine());
		}
		}
		}
		if ( inputState.guessing==0 ) {
			
			if (debug) p("matched XML_FORWARD");
			String urlAttribute = attributeDequote(url.getText());
			String[][] paramStrings = null;
			if (params.size() > 0){
				paramStrings = vector2array(params);
			}
			if (getSaveJSP()) {
				if (paramStrings == null) {
				    saveJSPBegin("<jsp:forward page=\"" + urlAttribute + "\"/>", "wl_jsp_forward");
				} else {
				    saveParamJSP(urlAttribute, paramStrings, "forward");
				}
			}
				    
			javaSection("code", "if (true) { //forwarding request\n" +
					"out.clear(); // clear current output buffer\n");
			/* the urlAttribute may be a request-time attribute: <%= some_code_snippet %> */
			javaSection("code", "String __thePage = ");
			parseRequestTimeAttribute(urlAttribute);
			if (paramStrings != null)
				queryParams2code(paramStrings);
			javaSection("code", "pageContext.forward(__thePage);\nreturn;\n}\n");
			if (getSaveJSP())
				saveJSPEnd();
			
		}
		if ( _createToken && _token==null && _ttype!=Token.SKIP ) {
			_token = makeToken(_ttype);
			_token.setText(new String(text.getBuffer(), _begin, text.length()-_begin));
		}
		_returnToken = _token;
	}
	
	protected final void mXML_OPEN_USEBEAN(boolean _createToken) throws RecognitionException, CharStreamException, TokenStreamException {
		int _ttype; Token _token=null; int _begin=text.length();
		_ttype = XML_OPEN_USEBEAN;
		int _saveIndex;
		
		int startLine = getLine();
		Properties props = new Properties();
		
		
		match("use");
		{
		switch ( LA(1)) {
		case 'B':
		{
			match('B');
			break;
		}
		case 'b':
		{
			match('b');
			break;
		}
		default:
		{
			throw new NoViableAltForCharException((char)LA(1), getFilename(), getLine());
		}
		}
		}
		match("ean");
		{
		switch ( LA(1)) {
		case '\t':  case '\n':  case '\r':  case ' ':
		{
			{
			int _cnt35=0;
			_loop35:
			do {
				if ((_tokenSet_4.member(LA(1)))) {
					mWS(false);
				}
				else {
					if ( _cnt35>=1 ) { break _loop35; } else {throw new NoViableAltForCharException((char)LA(1), getFilename(), getLine());}
				}
				
				_cnt35++;
			} while (true);
			}
			{
			_loop37:
			do {
				if ((_tokenSet_1.member(LA(1)))) {
					mXML_ATTRIBUTES(false,props);
				}
				else {
					break _loop37;
				}
				
			} while (true);
			}
			break;
		}
		case '/':  case '>':
		{
			match("");
			break;
		}
		default:
		{
			throw new NoViableAltForCharException((char)LA(1), getFilename(), getLine());
		}
		}
		}
		{
		switch ( LA(1)) {
		case '>':
		{
			match(">");
			if ( inputState.guessing==0 ) {
				
				if (debug) p("matched XML_OPEN_USEBEAN (*with* body): " + props);
				if (htmlBuf.length() > 0) htmlSection();
				// useBean w/body
				processBeanTag(props, false);
				
			}
			break;
		}
		case '/':
		{
			match("/>");
			if ( inputState.guessing==0 ) {
				
				if (debug) p("matched XML_OPEN_USEBEAN (*without* body): " + props);
				if (htmlBuf.length() > 0) htmlSection();
				// useBean w/o body
				processBeanTag(props, true);
				javaSection("code", "}", startLine);
				
			}
			break;
		}
		default:
		{
			throw new NoViableAltForCharException((char)LA(1), getFilename(), getLine());
		}
		}
		}
		if ( _createToken && _token==null && _ttype!=Token.SKIP ) {
			_token = makeToken(_ttype);
			_token.setText(new String(text.getBuffer(), _begin, text.length()-_begin));
		}
		_returnToken = _token;
	}
	
/** also support syntax like:
 * <jsp:setProperty name="mybean" property="title" value="<%= some_java_expr %>"/>
 */
	protected final void mXML_SET_PROPERTY(boolean _createToken) throws RecognitionException, CharStreamException, TokenStreamException {
		int _ttype; Token _token=null; int _begin=text.length();
		_ttype = XML_SET_PROPERTY;
		int _saveIndex;
		
		Properties props = new Properties();
		
		
		match("set");
		{
		switch ( LA(1)) {
		case 'P':
		{
			match('P');
			break;
		}
		case 'p':
		{
			match('p');
			break;
		}
		default:
		{
			throw new NoViableAltForCharException((char)LA(1), getFilename(), getLine());
		}
		}
		}
		match("roperty");
		{
		int _cnt28=0;
		_loop28:
		do {
			if ((_tokenSet_4.member(LA(1)))) {
				mWS(false);
			}
			else {
				if ( _cnt28>=1 ) { break _loop28; } else {throw new NoViableAltForCharException((char)LA(1), getFilename(), getLine());}
			}
			
			_cnt28++;
		} while (true);
		}
		{
		_loop30:
		do {
			if ((_tokenSet_1.member(LA(1)))) {
				mXML_ATTRIBUTES(false,props);
			}
			else {
				break _loop30;
			}
			
		} while (true);
		}
		match("/>");
		if ( inputState.guessing==0 ) {
			
			if (debug) p("matched XML_SET_PROPERTY: " + props);
			if (htmlBuf.length() > 0) htmlSection();
			String name = props.getProperty("name");
			if (name == null) jspException("jsp:setProperty tag must have a name");
			Object bean;
			if ((bean = beans.get(name)) == null) jspException(name + " not a defined bean");
			
			String property = props.getProperty("property");
			if (property == null)
				jspException("jsp:setProperty must have a property name");
			
			String param = props.getProperty("param");
			String value = props.getProperty("value");
			if (param != null && value != null)
				jspException("jsp:setProperty can't have both param and value set");
			
			if (getSaveJSP()) {
				if (param == null) {
				    if (value == null) {
					saveJSPBegin("<jsp:setProperty name=\"" + name + "\" property=\"" +
						     property + "\"/>", "wl_jsp_setproperty");
				    } else {
					saveJSPBegin("<jsp:setProperty name=\"" + name + "\" property=\"" +
						     property + "\" value=\"" + value + "\"/>", "wl_jsp_setproperty");
				    }
				} else {
				    saveJSPBegin("<jsp:setProperty name=\"" + name + "\" property=\"" +
						 property + "\" param=\"" + param + "\"/>", "wl_jsp_setproperty");
				    param = attributeDequote(param);
				}
				saveJSPEnd();
			}
			
			name = attributeDequote(name);
			property = attributeDequote(property);
			
			// If value isn't null we have to handle the
			// request-time attribute possibilty
			if (value != null) {
				javaSection("code", "{ // begin setProperty block...\n");
				addSetPropertyValue(name, bean, property, value);
				javaSection("code", "} // end setProperty block...\n");
			} else {
				if (property.equals("*")) {
				    addSetAllProperties(name, bean);
				} else {
				    if (param == null) {
					addSetProperty(name, bean, property);
				    } else {
					addSetProperty(name, bean, property, param);
				    }
				}
			}
			// At this point we need to determine if the bean is stored in a session
			// and call a session.setValue() for the bean to cause it to be replicated
			// across a clustered server using in-memory-state-replication. 
			if (sessionScopeBeans.containsKey(name)) {
			javaSection("code", "session.putValue(\""+name+"\", "+name+");\n");
			}
			
		}
		if ( _createToken && _token==null && _ttype!=Token.SKIP ) {
			_token = makeToken(_ttype);
			_token.setText(new String(text.getBuffer(), _begin, text.length()-_begin));
		}
		_returnToken = _token;
	}
	
	protected final void mXML_GET_PROPERTY(boolean _createToken) throws RecognitionException, CharStreamException, TokenStreamException {
		int _ttype; Token _token=null; int _begin=text.length();
		_ttype = XML_GET_PROPERTY;
		int _saveIndex;
		
		Properties props = new Properties();
		
		
		match("get");
		{
		switch ( LA(1)) {
		case 'P':
		{
			match('P');
			break;
		}
		case 'p':
		{
			match('p');
			break;
		}
		default:
		{
			throw new NoViableAltForCharException((char)LA(1), getFilename(), getLine());
		}
		}
		}
		match("roperty");
		{
		int _cnt22=0;
		_loop22:
		do {
			if ((_tokenSet_4.member(LA(1)))) {
				mWS(false);
			}
			else {
				if ( _cnt22>=1 ) { break _loop22; } else {throw new NoViableAltForCharException((char)LA(1), getFilename(), getLine());}
			}
			
			_cnt22++;
		} while (true);
		}
		{
		_loop24:
		do {
			if ((_tokenSet_1.member(LA(1)))) {
				mXML_ATTRIBUTES(false,props);
			}
			else {
				break _loop24;
			}
			
		} while (true);
		}
		match("/>");
		if ( inputState.guessing==0 ) {
			
			if (debug) p("matched XML_GET_PROPERTY: " + props);
			if (htmlBuf.length() > 0) htmlSection();
			String property = props.getProperty("property");
			if (property == null) jspException("jsp:getProperty tag must specify the property name");
			String name = props.getProperty("name");
			if (name == null) jspException("jsp:getProperty tag must specify the bean name");
			
			if (getSaveJSP()) {
				saveJSPBegin("<jsp:getProperty name=\"" + name + "\" property=\"" + property + "\"/>", "wl_jsp_getproperty");
			}
			
			name = attributeDequote(name);
			property = attributeDequote(property);
			
			Object bean;
			if ((bean = beans.get(name)) == null) jspException(name + " is not defined as bean");
			
			addGetProperty(name, bean, property);
			
			if (getSaveJSP()) {
				saveJSPEnd();
			}
			
		}
		if ( _createToken && _token==null && _ttype!=Token.SKIP ) {
			_token = makeToken(_ttype);
			_token.setText(new String(text.getBuffer(), _begin, text.length()-_begin));
		}
		_returnToken = _token;
	}
	
/** <jsp:plugin ...(atts)...>
 *    <params>
 *      <param name="foo" value="bar"/>
 *    </params>
 *    <fallback>
 *     <p> Unable to load applet </p>
 *    </fallback>
 *  </jsp:plugin>
 */
	protected final void mXML_PLUGIN(boolean _createToken) throws RecognitionException, CharStreamException, TokenStreamException {
		int _ttype; Token _token=null; int _begin=text.length();
		_ttype = XML_PLUGIN;
		int _saveIndex;
		Token fbtoken2=null;
		Token fbtoken=null;
		
		Properties props = new Properties();
		Properties params = null;
		String fbtxt = null;
		
		
		match("plugin");
		{
		int _cnt74=0;
		_loop74:
		do {
			if ((_tokenSet_4.member(LA(1)))) {
				mWS(false);
			}
			else {
				if ( _cnt74>=1 ) { break _loop74; } else {throw new NoViableAltForCharException((char)LA(1), getFilename(), getLine());}
			}
			
			_cnt74++;
		} while (true);
		}
		{
		_loop76:
		do {
			if ((_tokenSet_1.member(LA(1)))) {
				mXML_ATTRIBUTES(false,props);
			}
			else {
				break _loop76;
			}
			
		} while (true);
		}
		match(">");
		{
		_loop78:
		do {
			if ((_tokenSet_4.member(LA(1)))) {
				mWS(false);
			}
			else {
				break _loop78;
			}
			
		} while (true);
		}
		if ( inputState.guessing==0 ) {
			
			if (debug) p("matched XML_PLUGIN: " + props);
			if (htmlBuf.length() > 0) { htmlSection(); }
			//Debug.say("got plugin atts: '" + props + "'");
			params = new Properties();
			
		}
		{
		boolean synPredMatched81 = false;
		if (((LA(1)=='<') && (LA(2)=='j') && (LA(3)=='s'))) {
			int _m81 = mark();
			synPredMatched81 = true;
			inputState.guessing++;
			try {
				{
				match("<jsp:params>");
				}
			}
			catch (RecognitionException pe) {
				synPredMatched81 = false;
			}
			rewind(_m81);
			inputState.guessing--;
		}
		if ( synPredMatched81 ) {
			{
			match("<jsp:params>");
			{
			_loop84:
			do {
				if ((_tokenSet_4.member(LA(1)))) {
					mWS(false);
				}
				else {
					break _loop84;
				}
				
			} while (true);
			}
			{
			_loop86:
			do {
				if ((LA(1)=='<') && (LA(2)=='j'||LA(2)=='p')) {
					mPLUGIN_PARAM(false,params);
				}
				else {
					break _loop86;
				}
				
			} while (true);
			}
			match("</jsp:params>");
			{
			_loop88:
			do {
				if ((_tokenSet_4.member(LA(1)))) {
					mWS(false);
				}
				else {
					break _loop88;
				}
				
			} while (true);
			}
			}
		}
		else if ((LA(1)=='<') && (LA(2)=='/'||LA(2)=='f'||LA(2)=='j') && (LA(3)=='a'||LA(3)=='j'||LA(3)=='s')) {
		}
		else if ((LA(1)=='<') && (LA(2)=='p')) {
			{
			match("<params>");
			{
			_loop91:
			do {
				if ((_tokenSet_4.member(LA(1)))) {
					mWS(false);
				}
				else {
					break _loop91;
				}
				
			} while (true);
			}
			{
			_loop93:
			do {
				if ((LA(1)=='<') && (LA(2)=='j'||LA(2)=='p')) {
					mPLUGIN_PARAM(false,params);
				}
				else {
					break _loop93;
				}
				
			} while (true);
			}
			match("</params>");
			{
			_loop95:
			do {
				if ((_tokenSet_4.member(LA(1)))) {
					mWS(false);
				}
				else {
					break _loop95;
				}
				
			} while (true);
			}
			}
		}
		else {
			throw new NoViableAltForCharException((char)LA(1), getFilename(), getLine());
		}
		
		}
		if ( inputState.guessing==0 ) {
			
			//Debug.say("got plugin params: '" + params + "'");
			
		}
		{
		boolean synPredMatched98 = false;
		if (((LA(1)=='<') && (LA(2)=='j'))) {
			int _m98 = mark();
			synPredMatched98 = true;
			inputState.guessing++;
			try {
				{
				match("<jsp:fallback>");
				}
			}
			catch (RecognitionException pe) {
				synPredMatched98 = false;
			}
			rewind(_m98);
			inputState.guessing--;
		}
		if ( synPredMatched98 ) {
			{
			match("<jsp:fallback>");
			mPCDATA2(true);
			fbtoken2=_returnToken;
			match("</jsp:fallback>");
			{
			_loop101:
			do {
				if ((_tokenSet_4.member(LA(1)))) {
					mWS(false);
				}
				else {
					break _loop101;
				}
				
			} while (true);
			}
			}
			if ( inputState.guessing==0 ) {
				
				fbtxt = fbtoken2 != null ? fbtoken2.getText() : "";
				
			}
		}
		else if ((LA(1)=='<') && (LA(2)=='f')) {
			{
			match("<fallback>");
			mPCDATA(true);
			fbtoken=_returnToken;
			match("</fallback>");
			{
			_loop104:
			do {
				if ((_tokenSet_4.member(LA(1)))) {
					mWS(false);
				}
				else {
					break _loop104;
				}
				
			} while (true);
			}
			}
			if ( inputState.guessing==0 ) {
				
				fbtxt = fbtoken != null ? fbtoken.getText() : "";
				
			}
		}
		else if ((LA(1)=='<') && (LA(2)=='/')) {
		}
		else {
			throw new NoViableAltForCharException((char)LA(1), getFilename(), getLine());
		}
		
		}
		match("</jsp:plugin>");
		if ( inputState.guessing==0 ) {
			
			//Debug.say("got fallback string: '" + fbtxt + "'");
			props = toLowerKeys(props);
			//Debug.say("got to end!");
			javaSection("code", "{ // begin java-plugin section...\n");
			try {
				javaSection("code", pluginPreambleCode);
				iePluginTag(props, params, fbtxt);
				nnPluginTag(props, params, fbtxt);
			//    javaSection("code", "if (_isIE) out.println(\"You're running IE!!!\");\n");
			//    javaSection("code", "else if (_isNN) out.println(\"You're running Netscape!!!\");\n");
			} finally {
				javaSection("code", "\n} // end java-plugin section...\n");
			}
			
		}
		if ( _createToken && _token==null && _ttype!=Token.SKIP ) {
			_token = makeToken(_ttype);
			_token.setText(new String(text.getBuffer(), _begin, text.length()-_begin));
		}
		_returnToken = _token;
	}
	
	protected final void mWS(boolean _createToken) throws RecognitionException, CharStreamException, TokenStreamException {
		int _ttype; Token _token=null; int _begin=text.length();
		_ttype = WS;
		int _saveIndex;
		
		{
		switch ( LA(1)) {
		case ' ':
		{
			match(' ');
			break;
		}
		case '\t':
		{
			match('\t');
			break;
		}
		case '\r':
		{
			match('\r');
			break;
		}
		case '\n':
		{
			match('\n');
			if ( inputState.guessing==0 ) {
				newline();
			}
			break;
		}
		default:
		{
			throw new NoViableAltForCharException((char)LA(1), getFilename(), getLine());
		}
		}
		}
		if ( _createToken && _token==null && _ttype!=Token.SKIP ) {
			_token = makeToken(_ttype);
			_token.setText(new String(text.getBuffer(), _begin, text.length()-_begin));
		}
		_returnToken = _token;
	}
	
	protected final void mXML_ATTRIBUTES(boolean _createToken,
		Properties props
	) throws RecognitionException, CharStreamException, TokenStreamException {
		int _ttype; Token _token=null; int _begin=text.length();
		_ttype = XML_ATTRIBUTES;
		int _saveIndex;
		Token pname=null;
		Token pval=null;
		
		String key = null;
		String value = "";
		
		
		mWORD(true);
		pname=_returnToken;
		mWSEQ(false);
		mSTRING(true);
		pval=_returnToken;
		{
		_loop129:
		do {
			if ((_tokenSet_4.member(LA(1)))) {
				mWS(false);
			}
			else {
				break _loop129;
			}
			
		} while (true);
		}
		if ( inputState.guessing==0 ) {
			
			key = pname.getText();
			value = attributeDequote(pval.getText());
			if (debug && false) p("matched XML_ATTRIBUTES: \"" + key + "\"=\"" + value + "\"");
			props.put(key, value);
			
		}
		if ( _createToken && _token==null && _ttype!=Token.SKIP ) {
			_token = makeToken(_ttype);
			_token.setText(new String(text.getBuffer(), _begin, text.length()-_begin));
		}
		_returnToken = _token;
	}
	
	protected final void mJSP_COMMENT_CONTENT(boolean _createToken) throws RecognitionException, CharStreamException, TokenStreamException {
		int _ttype; Token _token=null; int _begin=text.length();
		_ttype = JSP_COMMENT_CONTENT;
		int _saveIndex;
		
		{
		_loop189:
		do {
			if ((((LA(1) >= '\3' && LA(1) <= '\uffff')) && ((LA(2) >= '\3' && LA(2) <= '\uffff')) && ((LA(3) >= '\3' && LA(3) <= '\uffff')))&&(! (LA(1) == '-' && LA(2) == '-' && LA(3) == '%' && LA(4) == '>') )) {
				mNEWLINE_COUNTER(false);
			}
			else {
				break _loop189;
			}
			
		} while (true);
		}
		if ( _createToken && _token==null && _ttype!=Token.SKIP ) {
			_token = makeToken(_ttype);
			_token.setText(new String(text.getBuffer(), _begin, text.length()-_begin));
		}
		_returnToken = _token;
	}
	
	protected final void mWORD(boolean _createToken) throws RecognitionException, CharStreamException, TokenStreamException {
		int _ttype; Token _token=null; int _begin=text.length();
		_ttype = WORD;
		int _saveIndex;
		
		mLETTER(false);
		{
		_loop217:
		do {
			switch ( LA(1)) {
			case 'A':  case 'B':  case 'C':  case 'D':
			case 'E':  case 'F':  case 'G':  case 'H':
			case 'I':  case 'J':  case 'K':  case 'L':
			case 'M':  case 'N':  case 'O':  case 'P':
			case 'Q':  case 'R':  case 'S':  case 'T':
			case 'U':  case 'V':  case 'W':  case 'X':
			case 'Y':  case 'Z':  case '_':  case 'a':
			case 'b':  case 'c':  case 'd':  case 'e':
			case 'f':  case 'g':  case 'h':  case 'i':
			case 'j':  case 'k':  case 'l':  case 'm':
			case 'n':  case 'o':  case 'p':  case 'q':
			case 'r':  case 's':  case 't':  case 'u':
			case 'v':  case 'w':  case 'x':  case 'y':
			case 'z':
			{
				mLETTER(false);
				break;
			}
			case '0':  case '1':  case '2':  case '3':
			case '4':  case '5':  case '6':  case '7':
			case '8':  case '9':
			{
				mDIGIT(false);
				break;
			}
			case '.':
			{
				mDOT(false);
				break;
			}
			case '-':
			{
				mDASH(false);
				break;
			}
			default:
			{
				break _loop217;
			}
			}
		} while (true);
		}
		if ( _createToken && _token==null && _ttype!=Token.SKIP ) {
			_token = makeToken(_ttype);
			_token.setText(new String(text.getBuffer(), _begin, text.length()-_begin));
		}
		_returnToken = _token;
	}
	
	protected final void mDIRECTIVE(boolean _createToken) throws RecognitionException, CharStreamException, TokenStreamException {
		int _ttype; Token _token=null; int _begin=text.length();
		_ttype = DIRECTIVE;
		int _saveIndex;
		
		match("<%@");
		{
		_loop53:
		do {
			if ((_tokenSet_4.member(LA(1)))) {
				mWS(false);
			}
			else {
				break _loop53;
			}
			
		} while (true);
		}
		{
		switch ( LA(1)) {
		case 't':
		{
			mTAGLIB_DIRECTIVE(false);
			break;
		}
		case 'p':
		{
			mPAGE_DIRECTIVE(false);
			break;
		}
		case 'i':
		{
			mINCLUDE_DIRECTIVE(false);
			break;
		}
		default:
		{
			throw new NoViableAltForCharException((char)LA(1), getFilename(), getLine());
		}
		}
		}
		if ( _createToken && _token==null && _ttype!=Token.SKIP ) {
			_token = makeToken(_ttype);
			_token.setText(new String(text.getBuffer(), _begin, text.length()-_begin));
		}
		_returnToken = _token;
	}
	
	protected final void mDECLARATION(boolean _createToken) throws RecognitionException, CharStreamException, TokenStreamException {
		int _ttype; Token _token=null; int _begin=text.length();
		_ttype = DECLARATION;
		int _saveIndex;
		Token c=null;
		
		int startLine = getLine();
		
		
		match("<%!");
		mSTANDARD_CONTENT(true);
		c=_returnToken;
		match("%>");
		if ( inputState.guessing==0 ) {
			
			if (debug) p("matched DECLARATION");
			String text = scriptDequote(c.getText());
			javaSection("class", text, startLine);
			if (getSaveJSP()) {
				saveJSPBegin("<%! " + text + " %>\n", "wl_jsp_directive");
				saveJSPEnd();
			}
			
		}
		if ( _createToken && _token==null && _ttype!=Token.SKIP ) {
			_token = makeToken(_ttype);
			_token.setText(new String(text.getBuffer(), _begin, text.length()-_begin));
		}
		_returnToken = _token;
	}
	
	protected final void mSCRIPT(boolean _createToken) throws RecognitionException, CharStreamException, TokenStreamException {
		int _ttype; Token _token=null; int _begin=text.length();
		_ttype = SCRIPT;
		int _saveIndex;
		Token c=null;
		
		int startLine = getLine();
		
		
		match("<%");
		mSCRIPT_CONTENT(true);
		c=_returnToken;
		match("%>");
		if ( inputState.guessing==0 ) {
			
			if (debug) p("matched SCRIPT_CONTENT");
			String text = scriptDequote(c.getText());
			/* our generated tag code comes as a scriptlet,
			* don't parse that, we know it balances braces
			* correctly.
			*/
			if (!text.startsWith(StandardTagLib.WL_GENERATED_BEGIN)) {
				ScriptletScopeLexer ssl = new ScriptletScopeLexer(new StringReader(text));
				int line = getLine();
				if (debug) p("parsing scriptlet ending at line#" + line +
					     " for scope changes");
				/* backup lineno to beginning of scriptlet */
				int len = text.length();
				for (int i = 0; i < len; i++) if (text.charAt(i) == '\n') line--;
				ssl.parse(jspc, line);
			}
			if (getSaveJSP())
				saveJSPBegin("<%" + text + "%>", "wl_jsp_scriptlet");
			javaSection("code", text, startLine);
			if (getSaveJSP())
				saveJSPEnd();
			
		}
		if ( _createToken && _token==null && _ttype!=Token.SKIP ) {
			_token = makeToken(_ttype);
			_token.setText(new String(text.getBuffer(), _begin, text.length()-_begin));
		}
		_returnToken = _token;
	}
	
	protected final void mEXPRESSION(boolean _createToken) throws RecognitionException, CharStreamException, TokenStreamException {
		int _ttype; Token _token=null; int _begin=text.length();
		_ttype = EXPRESSION;
		int _saveIndex;
		Token c=null;
		
		int startLine = getLine();
		
		
		match("<%=");
		mSTANDARD_CONTENT(true);
		c=_returnToken;
		match("%>");
		if ( inputState.guessing==0 ) {
			
			if (debug) p("matched EXPRESSION");
			String text = scriptDequote(c.getText());  
			if (getSaveJSP())
				saveJSPBegin("<%=" + text + "%>", "wl_jsp_expression");
			javaSection("print", text, startLine);
			if (getSaveJSP())
				saveJSPEnd();
			
		}
		if ( _createToken && _token==null && _ttype!=Token.SKIP ) {
			_token = makeToken(_ttype);
			_token.setText(new String(text.getBuffer(), _begin, text.length()-_begin));
		}
		_returnToken = _token;
	}
	
	protected final void mTAGLIB_DIRECTIVE(boolean _createToken) throws RecognitionException, CharStreamException, TokenStreamException {
		int _ttype; Token _token=null; int _begin=text.length();
		_ttype = TAGLIB_DIRECTIVE;
		int _saveIndex;
		
		match("taglib");
		{
		int _cnt62=0;
		_loop62:
		do {
			if ((_tokenSet_4.member(LA(1)))) {
				mWS(false);
			}
			else {
				if ( _cnt62>=1 ) { break _loop62; } else {throw new NoViableAltForCharException((char)LA(1), getFilename(), getLine());}
			}
			
			_cnt62++;
		} while (true);
		}
		mTAGLIB_DIRECTIVE_BODY(false,false);
		match("%>");
		if ( _createToken && _token==null && _ttype!=Token.SKIP ) {
			_token = makeToken(_ttype);
			_token.setText(new String(text.getBuffer(), _begin, text.length()-_begin));
		}
		_returnToken = _token;
	}
	
	protected final void mPAGE_DIRECTIVE(boolean _createToken) throws RecognitionException, CharStreamException, TokenStreamException {
		int _ttype; Token _token=null; int _begin=text.length();
		_ttype = PAGE_DIRECTIVE;
		int _saveIndex;
		
		match("page");
		{
		int _cnt68=0;
		_loop68:
		do {
			if ((_tokenSet_4.member(LA(1)))) {
				mWS(false);
			}
			else {
				if ( _cnt68>=1 ) { break _loop68; } else {throw new NoViableAltForCharException((char)LA(1), getFilename(), getLine());}
			}
			
			_cnt68++;
		} while (true);
		}
		mPAGE_DIRECTIVE_BODY(false,false);
		match("%>");
		if ( _createToken && _token==null && _ttype!=Token.SKIP ) {
			_token = makeToken(_ttype);
			_token.setText(new String(text.getBuffer(), _begin, text.length()-_begin));
		}
		_returnToken = _token;
	}
	
	protected final void mINCLUDE_DIRECTIVE(boolean _createToken) throws RecognitionException, CharStreamException, TokenStreamException {
		int _ttype; Token _token=null; int _begin=text.length();
		_ttype = INCLUDE_DIRECTIVE;
		int _saveIndex;
		Token attVal=null;
		
		match("include");
		{
		int _cnt57=0;
		_loop57:
		do {
			if ((_tokenSet_4.member(LA(1)))) {
				mWS(false);
			}
			else {
				if ( _cnt57>=1 ) { break _loop57; } else {throw new NoViableAltForCharException((char)LA(1), getFilename(), getLine());}
			}
			
			_cnt57++;
		} while (true);
		}
		match("file");
		mWSEQ(false);
		mSTRING(true);
		attVal=_returnToken;
		{
		_loop59:
		do {
			if ((_tokenSet_4.member(LA(1)))) {
				mWS(false);
			}
			else {
				break _loop59;
			}
			
		} while (true);
		}
		match("%>");
		if ( inputState.guessing==0 ) {
			
			if (debug) p("matched INCLUDE_DIRECTIVE: " + attVal.getText());
			String attribute = attributeDequote(attVal.getText());
			if (getSaveJSP())
				saveJSPBegin("<%@ include file=\"" + attVal.getText() + "\" %>\n", "wl_jsp_directive_include");
			
			try {
			buildTimeInclude(attribute);
			} catch(IOException ioe) {
			throw new CharStreamException("Could not include " + attribute);
			}
			
			if (getSaveJSP())
				saveJSPEnd();
			
			
		}
		if ( _createToken && _token==null && _ttype!=Token.SKIP ) {
			_token = makeToken(_ttype);
			_token.setText(new String(text.getBuffer(), _begin, text.length()-_begin));
		}
		_returnToken = _token;
	}
	
	protected final void mWSEQ(boolean _createToken) throws RecognitionException, CharStreamException, TokenStreamException {
		int _ttype; Token _token=null; int _begin=text.length();
		_ttype = WSEQ;
		int _saveIndex;
		
		{
		_loop195:
		do {
			if ((_tokenSet_4.member(LA(1)))) {
				mWS(false);
			}
			else {
				break _loop195;
			}
			
		} while (true);
		}
		mEQ(false);
		{
		_loop197:
		do {
			if ((_tokenSet_4.member(LA(1)))) {
				mWS(false);
			}
			else {
				break _loop197;
			}
			
		} while (true);
		}
		if ( _createToken && _token==null && _ttype!=Token.SKIP ) {
			_token = makeToken(_ttype);
			_token.setText(new String(text.getBuffer(), _begin, text.length()-_begin));
		}
		_returnToken = _token;
	}
	
	protected final void mSTRING(boolean _createToken) throws RecognitionException, CharStreamException, TokenStreamException {
		int _ttype; Token _token=null; int _begin=text.length();
		_ttype = STRING;
		int _saveIndex;
		char  c1 = '\0';
		char  c2 = '\0';
		
		switch ( LA(1)) {
		case '"':
		{
			_saveIndex=text.length();
			match('"');
			text.setLength(_saveIndex);
			{
			_loop205:
			do {
				if ((LA(1)=='\\') && (LA(2)=='"') && ((LA(3) >= '\3' && LA(3) <= '\ufffe'))) {
					mESC_DOUBLE_QUOTE(false);
				}
				else if ((_tokenSet_7.member(LA(1))) && ((LA(2) >= '\3' && LA(2) <= '\ufffe')) && (true)) {
					{
					c1 = LA(1);
					match(_tokenSet_7);
					}
					if ( inputState.guessing==0 ) {
						if (c1 == '\n') newline();
					}
				}
				else {
					break _loop205;
				}
				
			} while (true);
			}
			_saveIndex=text.length();
			match('"');
			text.setLength(_saveIndex);
			break;
		}
		case '\'':
		{
			_saveIndex=text.length();
			match('\'');
			text.setLength(_saveIndex);
			{
			_loop208:
			do {
				if ((LA(1)=='\\') && (LA(2)=='\'') && ((LA(3) >= '\3' && LA(3) <= '\ufffe'))) {
					mESC_SINGLE_QUOTE(false);
				}
				else if ((_tokenSet_8.member(LA(1))) && ((LA(2) >= '\3' && LA(2) <= '\ufffe')) && (true)) {
					{
					c2 = LA(1);
					match(_tokenSet_8);
					}
					if ( inputState.guessing==0 ) {
						if (c2 == '\n') newline();
					}
				}
				else {
					break _loop208;
				}
				
			} while (true);
			}
			_saveIndex=text.length();
			match('\'');
			text.setLength(_saveIndex);
			break;
		}
		default:
		{
			throw new NoViableAltForCharException((char)LA(1), getFilename(), getLine());
		}
		}
		if ( _createToken && _token==null && _ttype!=Token.SKIP ) {
			_token = makeToken(_ttype);
			_token.setText(new String(text.getBuffer(), _begin, text.length()-_begin));
		}
		_returnToken = _token;
	}
	
	protected final void mTAGLIB_DIRECTIVE_BODY(boolean _createToken,
		boolean xmlSyntax
	) throws RecognitionException, CharStreamException, TokenStreamException {
		int _ttype; Token _token=null; int _begin=text.length();
		_ttype = TAGLIB_DIRECTIVE_BODY;
		int _saveIndex;
		
		Properties props = new Properties();
		
		
		{
		_loop65:
		do {
			if ((_tokenSet_1.member(LA(1)))) {
				mXML_ATTRIBUTES(false,props);
			}
			else {
				break _loop65;
			}
			
		} while (true);
		}
		if ( inputState.guessing==0 ) {
			
			if (debug) p("matched TAGLIB_DIRECTIVE: " + props);
			String prefix = props.getProperty("prefix");
			if (prefix == null) jspException("No prefix for taglib");
			String uri = props.getProperty("uri");
			if (uri == null) jspException("No URI for taglib");
			// Check that we are not already using this prefix
			if (getSaveJSP()) {
				if (xmlSyntax) {
				    saveJSPBegin("<jsp:directive.taglib uri=\"" + uri + "\" prefix=\"" + prefix + "\"%>", "wl_jsp_taglib");
				} else {
				    saveJSPBegin("<%@ taglib uri=\"" + uri + "\" prefix=\"" + prefix + "\"%>", "wl_jsp_taglib");
				}
				saveJSPEnd();
			}
			prefix = attributeDequote(prefix);
			if (taglibs.get(prefix) == null) {
			uri = attributeDequote(uri);
			try {
				TagLib tagLib = (TagLib) jspc.getAttribute("taglib." + uri);
			if(tagLib == null) {
				    tagLib = loadTagLib(uri, prefix, jspc.isVerbose());
				    jspc.setAttribute("taglib." + uri, tagLib);
			}
				taglibs.put(prefix, tagLib);
			} catch (RuntimeException re) {
				throw re;
			} catch (IOException ioe) {
				jspException("Could not parse deployment descriptor: " + ioe);
			} catch (SAXException saxe) {
				jspException("Could not parse deployment descriptor: " + saxe);
			}
			} else {
				if (jspc.isVerbose())
			Debug.say("Warning: A taglib for " + prefix + " has already been registered");
			}
			
		}
		if ( _createToken && _token==null && _ttype!=Token.SKIP ) {
			_token = makeToken(_ttype);
			_token.setText(new String(text.getBuffer(), _begin, text.length()-_begin));
		}
		_returnToken = _token;
	}
	
	protected final void mPAGE_DIRECTIVE_BODY(boolean _createToken,
		boolean xmlSyntax
	) throws RecognitionException, CharStreamException, TokenStreamException {
		int _ttype; Token _token=null; int _begin=text.length();
		_ttype = PAGE_DIRECTIVE_BODY;
		int _saveIndex;
		
		Properties props = new Properties();
		
		
		{
		_loop71:
		do {
			if ((_tokenSet_1.member(LA(1)))) {
				mXML_ATTRIBUTES(false,props);
			}
			else {
				break _loop71;
			}
			
		} while (true);
		}
		if ( inputState.guessing==0 ) {
			
			if (debug) p("matched PAGE_DIRECTIVE_BODY: " + props);
			Enumeration enum = props.keys();
			while (enum.hasMoreElements()) {
				String k = (String)enum.nextElement();
				if (k == null || k.length() == 0)
				    continue;
				String v = props.getProperty(k);
				if (v == null)
				    continue;
				
				if (k.equalsIgnoreCase("language")) {
				    languageDirective(v);
				} else if (k.equalsIgnoreCase("extends")) {
				    extendsDirective(v);
				} else if (k.equalsIgnoreCase("import")) {
				    addImportSections(v);
				} else if (k.equalsIgnoreCase("session")) {
				    sessionDirective(v);
				} else if (k.equalsIgnoreCase("buffer")) {
				    bufferDirective(v);
				} else if (k.equalsIgnoreCase("implements")) {
				    implementsDirective(v);
				} else if (k.equalsIgnoreCase("autoFlush")) {
				    autoflushDirective(v);
				} else if (k.equalsIgnoreCase("isThreadSafe")) {
				    if ("false".equalsIgnoreCase(v))
					javaSection("implements", "javax.servlet.SingleThreadModel");
				} else if (k.equalsIgnoreCase("info")) {
				    infoDirective(v);
				} else if (k.equalsIgnoreCase("isErrorPage")) {
				    if ("true".equalsIgnoreCase(v)) {
					/* this means the "exception" implicit object is available */
					iserrorpage = true;
				    }
				} else if (k.equalsIgnoreCase("errorPage")) {
				    errorpageDirective(v);
				} else if (k.equalsIgnoreCase("contentType")) {
				    contentTypeDirective(v);
				} else {
				    jspException("unrecognized JSP directive: '" + k + "'='" + v + "'");
				}
			}
			if (getSaveJSP()) {
				StringBuffer sb = new StringBuffer();
				if (xmlSyntax) {
				    sb.append("<jsp:directive.page ");
				} else {
				    sb.append("<%@ page ");
				}
				/* enumerate again */
				enum = props.keys();
				while (enum.hasMoreElements()) {
				    String k = (String)enum.nextElement();
				    String v = props.getProperty(k);
				    sb.append(k);
				    sb.append("=\"");
				    sb.append(v);
				    sb.append("\" ");
				}
				if (xmlSyntax) {
				    sb.append("/>");
				} else {
				    sb.append("%>");
				}
				saveJSPBegin(sb.toString(), "wl_jsp_directive_page");
				saveJSPEnd();
			}
			
		}
		if ( _createToken && _token==null && _ttype!=Token.SKIP ) {
			_token = makeToken(_ttype);
			_token.setText(new String(text.getBuffer(), _begin, text.length()-_begin));
		}
		_returnToken = _token;
	}
	
	protected final void mPLUGIN_PARAM(boolean _createToken,
		Properties params
	) throws RecognitionException, CharStreamException, TokenStreamException {
		int _ttype; Token _token=null; int _begin=text.length();
		_ttype = PLUGIN_PARAM;
		int _saveIndex;
		Token pname1=null;
		Token pval1=null;
		Token pname2=null;
		Token pval2=null;
		
		String name = null, value=null;
		
		
		{
		if ((LA(1)=='<') && (LA(2)=='p')) {
			{
			match("<param");
			{
			int _cnt111=0;
			_loop111:
			do {
				if ((_tokenSet_4.member(LA(1)))) {
					mWS(false);
				}
				else {
					if ( _cnt111>=1 ) { break _loop111; } else {throw new NoViableAltForCharException((char)LA(1), getFilename(), getLine());}
				}
				
				_cnt111++;
			} while (true);
			}
			match("name");
			mWSEQ(false);
			mSTRING(true);
			pname1=_returnToken;
			{
			int _cnt113=0;
			_loop113:
			do {
				if ((_tokenSet_4.member(LA(1)))) {
					mWS(false);
				}
				else {
					if ( _cnt113>=1 ) { break _loop113; } else {throw new NoViableAltForCharException((char)LA(1), getFilename(), getLine());}
				}
				
				_cnt113++;
			} while (true);
			}
			match("value");
			mWSEQ(false);
			mSTRING(true);
			pval1=_returnToken;
			{
			_loop115:
			do {
				if ((_tokenSet_4.member(LA(1)))) {
					mWS(false);
				}
				else {
					break _loop115;
				}
				
			} while (true);
			}
			match(">");
			{
			_loop117:
			do {
				if ((_tokenSet_4.member(LA(1)))) {
					mWS(false);
				}
				else {
					break _loop117;
				}
				
			} while (true);
			}
			}
			if ( inputState.guessing==0 ) {
				
				name = pname1!=null ? pname1.getText() : null;
				value = pval1!=null ? pval1.getText() : "";
				
			}
		}
		else if ((LA(1)=='<') && (LA(2)=='j')) {
			{
			match("<jsp:param");
			{
			int _cnt120=0;
			_loop120:
			do {
				if ((_tokenSet_4.member(LA(1)))) {
					mWS(false);
				}
				else {
					if ( _cnt120>=1 ) { break _loop120; } else {throw new NoViableAltForCharException((char)LA(1), getFilename(), getLine());}
				}
				
				_cnt120++;
			} while (true);
			}
			match("name");
			mWSEQ(false);
			mSTRING(true);
			pname2=_returnToken;
			{
			int _cnt122=0;
			_loop122:
			do {
				if ((_tokenSet_4.member(LA(1)))) {
					mWS(false);
				}
				else {
					if ( _cnt122>=1 ) { break _loop122; } else {throw new NoViableAltForCharException((char)LA(1), getFilename(), getLine());}
				}
				
				_cnt122++;
			} while (true);
			}
			match("value");
			mWSEQ(false);
			mSTRING(true);
			pval2=_returnToken;
			{
			_loop124:
			do {
				if ((_tokenSet_4.member(LA(1)))) {
					mWS(false);
				}
				else {
					break _loop124;
				}
				
			} while (true);
			}
			match("/>");
			{
			_loop126:
			do {
				if ((_tokenSet_4.member(LA(1)))) {
					mWS(false);
				}
				else {
					break _loop126;
				}
				
			} while (true);
			}
			}
			if ( inputState.guessing==0 ) {
				
				name = pname2!=null ? pname2.getText() : null;
				value = pval2!=null ? pval2.getText() : "";
				
			}
		}
		else {
			throw new NoViableAltForCharException((char)LA(1), getFilename(), getLine());
		}
		
		}
		if ( inputState.guessing==0 ) {
			
			if (debug) p("matched PLUGIN_PARAM");
			if (name!=null)
			params.put(name, value);
			
		}
		if ( _createToken && _token==null && _ttype!=Token.SKIP ) {
			_token = makeToken(_ttype);
			_token.setText(new String(text.getBuffer(), _begin, text.length()-_begin));
		}
		_returnToken = _token;
	}
	
	protected final void mPCDATA2(boolean _createToken) throws RecognitionException, CharStreamException, TokenStreamException {
		int _ttype; Token _token=null; int _begin=text.length();
		_ttype = PCDATA2;
		int _saveIndex;
		
		{
		_loop223:
		do {
			if ((((LA(1) >= '\3' && LA(1) <= '\uffff')) && (true) && (true))&&(! (LA(1) == '<' && LA(2) == '/' && LA(3) == 'j' &&
                         LA(4) == 's' && LA(5) == 'p' && LA(6) == ':' &&
                         LA(7) == 'f' && LA(8) == 'a' && LA(9) == 'l' &&
                         LA(10) == 'l' && LA(11) == 'b' && LA(12) == 'a' &&
                         LA(13) == 'c' && LA(14) == 'k' && LA(15) == '>' ) )) {
				mNEWLINE_COUNTER(false);
			}
			else {
				break _loop223;
			}
			
		} while (true);
		}
		if ( _createToken && _token==null && _ttype!=Token.SKIP ) {
			_token = makeToken(_ttype);
			_token.setText(new String(text.getBuffer(), _begin, text.length()-_begin));
		}
		_returnToken = _token;
	}
	
	protected final void mPCDATA(boolean _createToken) throws RecognitionException, CharStreamException, TokenStreamException {
		int _ttype; Token _token=null; int _begin=text.length();
		_ttype = PCDATA;
		int _saveIndex;
		
		{
		_loop220:
		do {
			if ((((LA(1) >= '\3' && LA(1) <= '\uffff')) && (true) && (true))&&(! (LA(1) == '<' && LA(2) == '/' && LA(3) == 'f' &&
                         LA(4) == 'a' && LA(5) == 'l' && LA(6) == 'l' &&
                         LA(7) == 'b' && LA(8) == 'a' && LA(9) == 'c' &&
                         LA(10) == 'k' && LA(11) == '>' ) )) {
				mNEWLINE_COUNTER(false);
			}
			else {
				break _loop220;
			}
			
		} while (true);
		}
		if ( _createToken && _token==null && _ttype!=Token.SKIP ) {
			_token = makeToken(_ttype);
			_token.setText(new String(text.getBuffer(), _begin, text.length()-_begin));
		}
		_returnToken = _token;
	}
	
	protected final void mPLUGIN_FALLBACK(boolean _createToken,
		String fbtxt
	) throws RecognitionException, CharStreamException, TokenStreamException {
		int _ttype; Token _token=null; int _begin=text.length();
		_ttype = PLUGIN_FALLBACK;
		int _saveIndex;
		Token fbtoken=null;
		
		mPCDATA(true);
		fbtoken=_returnToken;
		if ( inputState.guessing==0 ) {
			
			if (fbtoken != null)
			fbtxt = fbtoken.getText();
			
		}
		if ( _createToken && _token==null && _ttype!=Token.SKIP ) {
			_token = makeToken(_ttype);
			_token.setText(new String(text.getBuffer(), _begin, text.length()-_begin));
		}
		_returnToken = _token;
	}
	
	protected final void mPLUGIN_FALLBACK2(boolean _createToken,
		String fbtxt
	) throws RecognitionException, CharStreamException, TokenStreamException {
		int _ttype; Token _token=null; int _begin=text.length();
		_ttype = PLUGIN_FALLBACK2;
		int _saveIndex;
		Token fbtoken=null;
		
		mPCDATA2(true);
		fbtoken=_returnToken;
		if ( inputState.guessing==0 ) {
			
			if (fbtoken != null)
			fbtxt = fbtoken.getText();
			
		}
		if ( _createToken && _token==null && _ttype!=Token.SKIP ) {
			_token = makeToken(_ttype);
			_token.setText(new String(text.getBuffer(), _begin, text.length()-_begin));
		}
		_returnToken = _token;
	}
	
	protected final void mIMPORT_DIRECTIVE(boolean _createToken) throws RecognitionException, CharStreamException, TokenStreamException {
		int _ttype; Token _token=null; int _begin=text.length();
		_ttype = IMPORT_DIRECTIVE;
		int _saveIndex;
		Token pkgs=null;
		
		match("import");
		mWSEQ(false);
		mSTRING(true);
		pkgs=_returnToken;
		if ( inputState.guessing==0 ) {
			
			if (debug) p("matched IMPORT_DIRECTIVE");
			String attribute = attributeDequote(pkgs.getText());
			addImportSections(attribute);
			
		}
		if ( _createToken && _token==null && _ttype!=Token.SKIP ) {
			_token = makeToken(_ttype);
			_token.setText(new String(text.getBuffer(), _begin, text.length()-_begin));
		}
		_returnToken = _token;
	}
	
	protected final void mSTANDARD_CONTENT(boolean _createToken) throws RecognitionException, CharStreamException, TokenStreamException {
		int _ttype; Token _token=null; int _begin=text.length();
		_ttype = STANDARD_CONTENT;
		int _saveIndex;
		
		{
		_loop179:
		do {
			if ((((LA(1) >= '\3' && LA(1) <= '\uffff')) && ((LA(2) >= '\3' && LA(2) <= '\uffff')) && ((LA(3) >= '\3' && LA(3) <= '\uffff')))&&(! (LA(1) == '%' && LA(2) == '>') )) {
				mNEWLINE_COUNTER(false);
			}
			else {
				break _loop179;
			}
			
		} while (true);
		}
		if ( _createToken && _token==null && _ttype!=Token.SKIP ) {
			_token = makeToken(_ttype);
			_token.setText(new String(text.getBuffer(), _begin, text.length()-_begin));
		}
		_returnToken = _token;
	}
	
	protected final void mSCRIPT_CONTENT(boolean _createToken) throws RecognitionException, CharStreamException, TokenStreamException {
		int _ttype; Token _token=null; int _begin=text.length();
		_ttype = SCRIPT_CONTENT;
		int _saveIndex;
		
		{
		match(_tokenSet_3);
		}
		{
		_loop183:
		do {
			if ((((LA(1) >= '\3' && LA(1) <= '\uffff')) && ((LA(2) >= '\3' && LA(2) <= '\uffff')) && ((LA(3) >= '\3' && LA(3) <= '\uffff')))&&(! (LA(1) == '%' && LA(2) == '>') )) {
				mNEWLINE_COUNTER(false);
			}
			else {
				break _loop183;
			}
			
		} while (true);
		}
		if ( _createToken && _token==null && _ttype!=Token.SKIP ) {
			_token = makeToken(_ttype);
			_token.setText(new String(text.getBuffer(), _begin, text.length()-_begin));
		}
		_returnToken = _token;
	}
	
	protected final void mXML_PARAM(boolean _createToken,
		Vector params
	) throws RecognitionException, CharStreamException, TokenStreamException {
		int _ttype; Token _token=null; int _begin=text.length();
		_ttype = XML_PARAM;
		int _saveIndex;
		Token pname=null;
		Token pval=null;
		
		String name = null, value = "";
		
		
		match("<jsp:param");
		{
		int _cnt144=0;
		_loop144:
		do {
			if ((_tokenSet_4.member(LA(1)))) {
				mWS(false);
			}
			else {
				if ( _cnt144>=1 ) { break _loop144; } else {throw new NoViableAltForCharException((char)LA(1), getFilename(), getLine());}
			}
			
			_cnt144++;
		} while (true);
		}
		match("name");
		mWSEQ(false);
		mSTRING(true);
		pname=_returnToken;
		{
		int _cnt146=0;
		_loop146:
		do {
			if ((_tokenSet_4.member(LA(1)))) {
				mWS(false);
			}
			else {
				if ( _cnt146>=1 ) { break _loop146; } else {throw new NoViableAltForCharException((char)LA(1), getFilename(), getLine());}
			}
			
			_cnt146++;
		} while (true);
		}
		match("value");
		mWSEQ(false);
		mSTRING(true);
		pval=_returnToken;
		{
		_loop148:
		do {
			if ((_tokenSet_4.member(LA(1)))) {
				mWS(false);
			}
			else {
				break _loop148;
			}
			
		} while (true);
		}
		match("/>");
		{
		_loop150:
		do {
			if ((_tokenSet_4.member(LA(1)))) {
				mWS(false);
			}
			else {
				break _loop150;
			}
			
		} while (true);
		}
		if ( inputState.guessing==0 ) {
			
			String[] valPair= new String[2];
			valPair[0] = pname.getText(); // set the param name
			valPair[1] = attributeDequote(pval.getText()); // set the param value
			params.addElement(valPair);
			if (debug) {
			p("Found <jsp:param name = "+valPair[0]+", value = "+valPair[1]);
			}
			
		}
		if ( _createToken && _token==null && _ttype!=Token.SKIP ) {
			_token = makeToken(_ttype);
			_token.setText(new String(text.getBuffer(), _begin, text.length()-_begin));
		}
		_returnToken = _token;
	}
	
	protected final void mXML_CONTENT(boolean _createToken) throws RecognitionException, CharStreamException, TokenStreamException {
		int _ttype; Token _token=null; int _begin=text.length();
		_ttype = XML_CONTENT;
		int _saveIndex;
		
		{
		_loop186:
		do {
			if ((((LA(1) >= '\3' && LA(1) <= '\uffff')) && ((LA(2) >= '\3' && LA(2) <= '\uffff')) && ((LA(3) >= '\3' && LA(3) <= '\uffff')))&&(! (LA(1) == '<' && LA(2) == '/' && LA(3) == 'j' && LA(4) == 's' && LA(5) == 'p' && LA(6) == ':') )) {
				mNEWLINE_COUNTER(false);
			}
			else {
				break _loop186;
			}
			
		} while (true);
		}
		if ( _createToken && _token==null && _ttype!=Token.SKIP ) {
			_token = makeToken(_ttype);
			_token.setText(new String(text.getBuffer(), _begin, text.length()-_begin));
		}
		_returnToken = _token;
	}
	
	protected final void mNEWLINE_COUNTER(boolean _createToken) throws RecognitionException, CharStreamException, TokenStreamException {
		int _ttype; Token _token=null; int _begin=text.length();
		_ttype = NEWLINE_COUNTER;
		int _saveIndex;
		char  c = '\0';
		
		c = LA(1);
		matchNot(EOF_CHAR);
		if ( inputState.guessing==0 ) {
			if (c=='\n') newline();
		}
		if ( _createToken && _token==null && _ttype!=Token.SKIP ) {
			_token = makeToken(_ttype);
			_token.setText(new String(text.getBuffer(), _begin, text.length()-_begin));
		}
		_returnToken = _token;
	}
	
	protected final void mEQ(boolean _createToken) throws RecognitionException, CharStreamException, TokenStreamException {
		int _ttype; Token _token=null; int _begin=text.length();
		_ttype = EQ;
		int _saveIndex;
		
		match('=');
		if ( _createToken && _token==null && _ttype!=Token.SKIP ) {
			_token = makeToken(_ttype);
			_token.setText(new String(text.getBuffer(), _begin, text.length()-_begin));
		}
		_returnToken = _token;
	}
	
	protected final void mESC_QUOTE(boolean _createToken) throws RecognitionException, CharStreamException, TokenStreamException {
		int _ttype; Token _token=null; int _begin=text.length();
		_ttype = ESC_QUOTE;
		int _saveIndex;
		
		match('\\');
		{
		switch ( LA(1)) {
		case '"':
		{
			match('"');
			break;
		}
		case '\'':
		{
			match('\'');
			break;
		}
		default:
		{
			throw new NoViableAltForCharException((char)LA(1), getFilename(), getLine());
		}
		}
		}
		if ( _createToken && _token==null && _ttype!=Token.SKIP ) {
			_token = makeToken(_ttype);
			_token.setText(new String(text.getBuffer(), _begin, text.length()-_begin));
		}
		_returnToken = _token;
	}
	
	protected final void mESC_SINGLE_QUOTE(boolean _createToken) throws RecognitionException, CharStreamException, TokenStreamException {
		int _ttype; Token _token=null; int _begin=text.length();
		_ttype = ESC_SINGLE_QUOTE;
		int _saveIndex;
		
		match("\\'");
		if ( _createToken && _token==null && _ttype!=Token.SKIP ) {
			_token = makeToken(_ttype);
			_token.setText(new String(text.getBuffer(), _begin, text.length()-_begin));
		}
		_returnToken = _token;
	}
	
	protected final void mESC_DOUBLE_QUOTE(boolean _createToken) throws RecognitionException, CharStreamException, TokenStreamException {
		int _ttype; Token _token=null; int _begin=text.length();
		_ttype = ESC_DOUBLE_QUOTE;
		int _saveIndex;
		
		match("\\\"");
		if ( _createToken && _token==null && _ttype!=Token.SKIP ) {
			_token = makeToken(_ttype);
			_token.setText(new String(text.getBuffer(), _begin, text.length()-_begin));
		}
		_returnToken = _token;
	}
	
	protected final void mDOT(boolean _createToken) throws RecognitionException, CharStreamException, TokenStreamException {
		int _ttype; Token _token=null; int _begin=text.length();
		_ttype = DOT;
		int _saveIndex;
		
		match('.');
		if ( _createToken && _token==null && _ttype!=Token.SKIP ) {
			_token = makeToken(_ttype);
			_token.setText(new String(text.getBuffer(), _begin, text.length()-_begin));
		}
		_returnToken = _token;
	}
	
	protected final void mDASH(boolean _createToken) throws RecognitionException, CharStreamException, TokenStreamException {
		int _ttype; Token _token=null; int _begin=text.length();
		_ttype = DASH;
		int _saveIndex;
		
		match('-');
		if ( _createToken && _token==null && _ttype!=Token.SKIP ) {
			_token = makeToken(_ttype);
			_token.setText(new String(text.getBuffer(), _begin, text.length()-_begin));
		}
		_returnToken = _token;
	}
	
	protected final void mDIGIT(boolean _createToken) throws RecognitionException, CharStreamException, TokenStreamException {
		int _ttype; Token _token=null; int _begin=text.length();
		_ttype = DIGIT;
		int _saveIndex;
		
		{
		matchRange('0','9');
		}
		if ( _createToken && _token==null && _ttype!=Token.SKIP ) {
			_token = makeToken(_ttype);
			_token.setText(new String(text.getBuffer(), _begin, text.length()-_begin));
		}
		_returnToken = _token;
	}
	
	protected final void mLETTER(boolean _createToken) throws RecognitionException, CharStreamException, TokenStreamException {
		int _ttype; Token _token=null; int _begin=text.length();
		_ttype = LETTER;
		int _saveIndex;
		
		{
		switch ( LA(1)) {
		case 'a':  case 'b':  case 'c':  case 'd':
		case 'e':  case 'f':  case 'g':  case 'h':
		case 'i':  case 'j':  case 'k':  case 'l':
		case 'm':  case 'n':  case 'o':  case 'p':
		case 'q':  case 'r':  case 's':  case 't':
		case 'u':  case 'v':  case 'w':  case 'x':
		case 'y':  case 'z':
		{
			matchRange('a','z');
			break;
		}
		case 'A':  case 'B':  case 'C':  case 'D':
		case 'E':  case 'F':  case 'G':  case 'H':
		case 'I':  case 'J':  case 'K':  case 'L':
		case 'M':  case 'N':  case 'O':  case 'P':
		case 'Q':  case 'R':  case 'S':  case 'T':
		case 'U':  case 'V':  case 'W':  case 'X':
		case 'Y':  case 'Z':
		{
			matchRange('A','Z');
			break;
		}
		case '_':
		{
			match('_');
			break;
		}
		default:
		{
			throw new NoViableAltForCharException((char)LA(1), getFilename(), getLine());
		}
		}
		}
		if ( _createToken && _token==null && _ttype!=Token.SKIP ) {
			_token = makeToken(_ttype);
			_token.setText(new String(text.getBuffer(), _begin, text.length()-_begin));
		}
		_returnToken = _token;
	}
	
	protected final void mHTML(boolean _createToken) throws RecognitionException, CharStreamException, TokenStreamException {
		int _ttype; Token _token=null; int _begin=text.length();
		_ttype = HTML;
		int _saveIndex;
		char  c = '\0';
		
		c = LA(1);
		matchNot(EOF_CHAR);
		if ( inputState.guessing==0 ) {
			if (c=='\n') newline();  htmlBuf.append((char)c);
		}
		if ( _createToken && _token==null && _ttype!=Token.SKIP ) {
			_token = makeToken(_ttype);
			_token.setText(new String(text.getBuffer(), _begin, text.length()-_begin));
		}
		_returnToken = _token;
	}
	
	
	private static long[] make_tokenSet_0() { long[] data = { -35321811042312L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, 9223372036854775807L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L }; return data; }
	public static final BitSet _tokenSet_0 = new BitSet(make_tokenSet_0());
	private static long[] make_tokenSet_1() { long[] data = { 0L, 576460745995190270L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L }; return data; }
	public static final BitSet _tokenSet_1 = new BitSet(make_tokenSet_1());
	private static long[] make_tokenSet_2() { long[] data = { 576284830442979328L, 576460745995190270L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L }; return data; }
	public static final BitSet _tokenSet_2 = new BitSet(make_tokenSet_2());
	private static long[] make_tokenSet_3() { long[] data = { -2305878339614670856L, -2L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, 9223372036854775807L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L }; return data; }
	public static final BitSet _tokenSet_3 = new BitSet(make_tokenSet_3());
	private static long[] make_tokenSet_4() { long[] data = { 4294977024L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L }; return data; }
	public static final BitSet _tokenSet_4 = new BitSet(make_tokenSet_4());
	private static long[] make_tokenSet_5() { long[] data = { 4611826760210720256L, 274877906944L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L }; return data; }
	public static final BitSet _tokenSet_5 = new BitSet(make_tokenSet_5());
	private static long[] make_tokenSet_6() { long[] data = { 5764748264817567232L, 17867063951360L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L }; return data; }
	public static final BitSet _tokenSet_6 = new BitSet(make_tokenSet_6());
	private static long[] make_tokenSet_7() { long[] data = { -17179869192L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, 9223372036854775807L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L }; return data; }
	public static final BitSet _tokenSet_7 = new BitSet(make_tokenSet_7());
	private static long[] make_tokenSet_8() { long[] data = { -549755813896L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, 9223372036854775807L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L }; return data; }
	public static final BitSet _tokenSet_8 = new BitSet(make_tokenSet_8());
	
	}
